@@ -1,5 +1,5 @@
 /* dvdcpy - A DVD backup tool
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "config.h"
 
+#include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include <getopt.h>
@@ -225,8 +226,10 @@ make_pathes (const char *path1, ...)
 {
   va_list ap;
   char path[FILENAME_MAX];
+  size_t len;
 
   strncpy (path, path1, FILENAME_MAX);
+  len = strlen(path);
 
   va_start (ap, path1);
   while (path1)
@@ -240,8 +243,9 @@ make_pathes (const char *path1, ...)
     path1 = va_arg (ap, const char *);
     if (path1)
     {
-      strncat (path, "/", FILENAME_MAX);
-      strncat (path, path1, FILENAME_MAX);
+      strncat (path, "/", FILENAME_MAX - len - 1);
+      strncat (path, path1, FILENAME_MAX - len - 2);
+      len += strlen (path1) + 1;
     }
   }
   va_end (ap);
@@ -269,27 +273,49 @@ get_space_left (const char *path)
   return (long long) buf.f_bsize * (long long) buf.f_bavail / DVD_VIDEO_LB_LEN;
 }
 
+static ssize_t
+write_blocks (int fd, const void *buffer, size_t nblocks)
+{
+  ssize_t written, total_written;
+  size_t nbytes;
+
+  total_written = 0;
+  nbytes = nblocks * DVD_VIDEO_LB_LEN;
+
+  while (total_written != nbytes)
+  {
+    written = write (fd, buffer + total_written, nbytes - total_written);
+    if (written < 0)
+      return -1;
+    total_written += written;
+  }
+
+  return nblocks;
+}
+
 static ssize_t
 dvd_copy_blocks (dvd_file_t *file, size_t offset, size_t size, int fd)
 {
   unsigned char buffer[512 * DVD_VIDEO_LB_LEN];
   unsigned int start;
-  size_t count;
+  size_t count, len;
 
   for (count = 512, start = offset; offset < start + size; offset += count)
   {
     if (offset + count > start + size)
       count = start + size - offset;
+    len = count;
 
-    if (DVDReadBlocks (file, offset, count, buffer) != count)
+    count = DVDReadBlocks (file, offset, len, buffer);
+    if (!count)
     {
       fprintf (stderr, "Error: Cannot read data\n");
       return -1;
     }
 
-    if (write (fd, buffer, count * DVD_VIDEO_LB_LEN) != count * DVD_VIDEO_LB_LEN)
+    if (write_blocks (fd, buffer, count) < 0)
     {
-      fprintf (stderr, "Error: Cannot write data\n");
+      fprintf (stderr, "Error: Cannot write data: %s\n", strerror (errno));
       return -1;
     }
 
@@ -811,7 +837,7 @@ main (int argc, char *argv[])
 
   if (total_size > get_space_left (output))
   {
-    fprintf (stderr, "Error: Not enough space left on device (%zd bytes needed)\n", total_size);
+    fprintf (stderr, "Error: Not enough space left on device (%zd KB needed)\n", total_size * 2);
     ifoClose (vmg_file);
     DVDClose (reader);
     return EXIT_FAILURE;
@@ -819,7 +845,7 @@ main (int argc, char *argv[])
 
   if ((dvd_copy (reader, vmg_file, vmg, vtss, output)) < 0)
   {
-    fprintf (stderr, "Error: Failed to copy the DVD\n");
+    /* fprintf (stderr, "Error: Failed to copy the DVD\n"); */
     ifoClose (vmg_file);
     DVDClose (reader);
     return EXIT_FAILURE;
