@@ -1,5 +1,5 @@
 /* OGMDvd - A wrapper library around libdvdread
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -273,6 +273,34 @@ ogmdvd_disc_get_label (OGMDvdDisc *disc)
   return g_convert (label, -1, "UTF8", "LATIN1", NULL, NULL, NULL);
 }
 
+/**
+ * ogmdvd_disc_get_id:
+ * @disc: An #OGMDvdDisc
+ *
+ * Returns a unique 128 bit disc identifier.
+ *
+ * Returns: The identifier, or NULL
+ */
+gchar *
+ogmdvd_disc_get_id (OGMDvdDisc *disc)
+{
+  GString *str;
+  gchar id[16];
+  gint i;
+
+  g_return_val_if_fail (disc != NULL, NULL);
+
+  if (DVDDiscID (disc->reader, (guchar *) id) < 0)
+    return NULL;
+
+  str = g_string_new (NULL);
+
+  for (i = 0; i < 16; i++)
+    g_string_append_printf (str, "%x", id[i]);
+
+  return g_string_free (str, FALSE);
+}
+
 /**
  * ogmdvd_disc_get_device:
  * @disc: An #OGMDvdDisc
@@ -351,10 +379,7 @@ ogmdvd_disc_get_nth_title (OGMDvdDisc *disc, guint nr)
   g_return_val_if_fail (disc != NULL, NULL);
 
   g_return_val_if_fail (nr == 0 || (disc->vmg_file && nr < disc->vmg_file->tt_srpt->nr_of_srpts), NULL);
-/*
-  if (nr >= disc->vmg_file->tt_srpt->nr_of_srpts)
-    return NULL;
-*/
+
   link = g_slist_find_custom (disc->titles, GUINT_TO_POINTER (nr), (GCompareFunc) ogmdvd_title_find_by_nr);
   if (link)
   {
@@ -386,6 +411,14 @@ ogmdvd_disc_get_nth_title (OGMDvdDisc *disc, guint nr)
   return title;
 }
 
+/**
+ * ogmdvd_disc_get_titles:
+ * @disc: An #OGMDvdDisc
+ *
+ * Returns a list of all the titles of @disc.
+ *
+ * Returns: A #GList, or NULL
+ */
 GList *
 ogmdvd_disc_get_titles (OGMDvdDisc *disc)
 {
