@@ -1,5 +1,5 @@
 /* OGMDvd - A wrapper library around libdvdread
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -66,6 +66,15 @@ struct _OGMDvdTitle
 
   GSList *audio_streams;
   GSList *subp_streams;
+
+  gint *bitrates;
+
+  OGMDvdReader *reader;
+  OGMDvdParser *parser;
+
+  gint block_len;
+  guchar *buffer;
+  guchar *ptr;
 };
 
 /**
@@ -103,6 +112,69 @@ struct _OGMDvdSubpStream
   subp_attr_t *attr;
 };
 
+/**
+ * OGMDvdReader:
+ *
+ * An opaque structure to read the content of a DVD
+ */
+struct _OGMDvdReader
+{
+  gint ref;
+
+  dvd_file_t *file;
+  pgc_t *pgc;
+
+  guint8 angle;
+
+  guint8 first_cell;
+  guint8 last_cell;
+
+  /* private */
+
+  guint8 cur_cell;
+
+  guint32 cell_first_pack;
+  guint32 cell_cur_pack;
+  guint32 packs_left;
+
+  guint32 pack_next_vobu;
+};
+
+/**
+ * OGMDvdParser:
+ *
+ * An opaque structure to parse the content of a DVD
+ */
+struct _OGMDvdParser
+{
+  gint ref;
+  gint max_frames;
+
+  glong progressive_frames;
+  glong video_frames;
+  
+  gint *bitrates;
+  gint nbitrates;
+  gint naudio_streams;
+  
+  gboolean *forced_subs;
+  gint nforced_subs;
+  gint nsubp_streams;
+  
+  /* SPU specific */
+  int size_sub;
+  int size_rle;
+  int size_got;
+  int pts_forced;
+  int64_t pts;
+  unsigned char *data;
+  
+  /* mpeg2 specific */
+  // mpeg2dec_t *mpeg2;
+  // const mpeg2_info_t *info;
+  guint width, height;
+};
+
 gint64 _ogmdvd_get_ifo_size  (OGMDvdDisc *disc, guint vts);
 gint64 _ogmdvd_get_bup_size  (OGMDvdDisc *disc, guint vts);
 gint64 _ogmdvd_get_menu_size (OGMDvdDisc *disc, guint vts);
