@@ -1,5 +1,5 @@
 /* OGMDvd - A wrapper library around libdvdread
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -105,3 +105,19 @@ ogmdvd_stream_get_nr (OGMDvdStream *stream)
   return stream->nr;
 }
 
+/**
+ * ogmdvd_stream_get_id:
+ * @stream: An #OGMDvdStream
+ *
+ * Returns the stream identifier.
+ *
+ * Returns: The stream identifier, or -1
+ */
+gint
+ogmdvd_stream_get_id (OGMDvdStream *stream)
+{
+  g_return_val_if_fail (stream != NULL, -1);
+
+  return stream->id;
+}
+
