@@ -1,5 +1,5 @@
 /* OGMDvd - A wrapper library around libdvdread
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,8 +30,12 @@
 #include "ogmdvd-disc.h"
 #include "ogmdvd-enums.h"
 #include "ogmdvd-title.h"
+#include "ogmdvd-stream.h"
 #include "ogmdvd-priv.h"
 
+#include "ogmdvd-reader.h"
+#include "ogmdvd-parser.h"
+
 static glong
 ogmdvd_time_to_msec (dvd_time_t *dtime)
 {
@@ -101,6 +105,10 @@ ogmdvd_title_unref (OGMDvdTitle *title)
         ogmdvd_disc_unref (title->disc);
       title->disc = NULL;
 
+      if (title->bitrates)
+        g_free (title->bitrates);
+      title->bitrates = NULL;
+
       g_free (title);
     }
   }
@@ -544,10 +552,7 @@ ogmdvd_title_get_nth_audio_stream (OGMDvdTitle *title, guint nr)
 
   g_return_val_if_fail (title != NULL, NULL);
   g_return_val_if_fail (nr < title->vts_file->vtsi_mat->nr_of_vts_audio_streams, NULL);
-/*
-  if (!(title->vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->audio_control[nr] & 0x8000))
-    return NULL;
-*/
+
   link = g_slist_find_custom (title->audio_streams, GUINT_TO_POINTER (nr), (GCompareFunc) ogmdvd_stream_find_by_nr);
   if (link)
   {
@@ -565,14 +570,13 @@ ogmdvd_title_get_nth_audio_stream (OGMDvdTitle *title, guint nr)
     ogmdvd_title_ref (title);
 
     audio = g_new0 (OGMDvdAudioStream, 1);
-    /*
-    audio->attr = &title->vts_file->vtsi_mat->vts_audio_attr[nr];
-    */
     audio->attr = &title->vts_file->vtsi_mat->vts_audio_attr[real_nr];
     audio->stream.title = title;
     audio->stream.nr = nr;
     audio->stream.ref = 1;
 
+    audio->stream.id = title->vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->audio_control[real_nr] >> 8 & 7;
+
     title->audio_streams = g_slist_append (title->audio_streams, audio);
   }
 
@@ -663,10 +667,6 @@ ogmdvd_title_get_nth_subp_stream (OGMDvdTitle *title, guint nr)
 
   g_return_val_if_fail (title != NULL, NULL);
   g_return_val_if_fail (nr < title->vts_file->vtsi_mat->nr_of_vts_subp_streams, NULL);
-/*
-  if (!(title->vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->subp_control[nr] & 0x80000000))
-    return NULL;
-*/
 
   link = g_slist_find_custom (title->subp_streams, GUINT_TO_POINTER (nr), (GCompareFunc) ogmdvd_stream_find_by_nr);
   if (link)
@@ -685,14 +685,17 @@ ogmdvd_title_get_nth_subp_stream (OGMDvdTitle *title, guint nr)
     ogmdvd_title_ref (title);
 
     subp = g_new0 (OGMDvdSubpStream, 1);
-    /*
-    subp->attr = &title->vts_file->vtsi_mat->vts_subp_attr[nr];
-    */
     subp->attr = &title->vts_file->vtsi_mat->vts_subp_attr[real_nr];
     subp->stream.title = title;
     subp->stream.ref = 1;
     subp->stream.nr = nr;
 
+    subp->stream.id = nr;
+    if (title->vts_file->vtsi_mat->vts_video_attr.display_aspect_ratio == 0) /* 4:3 */
+      subp->stream.id = title->vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->subp_control[real_nr] >> 24 & 31;
+    else if (title->vts_file->vtsi_mat->vts_video_attr.display_aspect_ratio == 3) /* 16:9 */
+      subp->stream.id = title->vts_file->vts_pgcit->pgci_srp[title->ttn - 1].pgc->subp_control[real_nr] >> 8 & 31;
+
     title->subp_streams = g_slist_append (title->subp_streams, subp);
   }
 
@@ -726,3 +729,79 @@ ogmdvd_title_get_subp_streams (OGMDvdTitle *title)
   return list;
 }
 
+/**
+ * ogmdvd_title_analyze:
+ * @title: An #OGMDvdTitle
+ *
+ * Performs a depper analysis of the title to get more information about it and
+ * its audio and subtitle streams. This function should be called multipled timeѕ
+ * until the analysis is complete.
+ *
+ * Returns: FALSE if the analysis if complete, TRUE otherwise
+ */
+gboolean
+ogmdvd_title_analyze (OGMDvdTitle *title)
+{
+  gint status;
+
+  g_return_val_if_fail (title != NULL, FALSE);
+
+  if (!title->reader)
+    title->reader = ogmdvd_reader_new (title, 0, -1, 0);
+
+  if (!title->reader)
+    return FALSE;
+
+  if (!title->parser)
+  {
+    title->parser = ogmdvd_parser_new (title);
+    title->buffer = g_new0 (guchar, 1024 * DVD_VIDEO_LB_LEN);
+    title->block_len = 0;
+  }
+
+  if (!title->parser)
+    return FALSE;
+
+  if (title->block_len > 0)
+  {
+    title->ptr += DVD_VIDEO_LB_LEN;
+    title->block_len --;
+  }
+
+  if (!title->block_len)
+  {
+    title->block_len = ogmdvd_reader_get_block (title->reader, 1024, title->buffer);
+    if (title->block_len <= 0)
+    {
+      /* ERROR */
+    }
+    title->ptr = title->buffer;
+  }
+
+  status = ogmdvd_parser_analyze (title->parser, title->ptr);
+
+  if (status)
+  {
+    gint i, n;
+
+    n = ogmdvd_title_get_n_audio_streams (title);
+    title->bitrates = g_new0 (gint, n);
+    for (i = 0; i < n; i ++)
+      title->bitrates[i] = ogmdvd_parser_get_audio_bitrate (title->parser, i);
+
+    ogmdvd_parser_unref (title->parser);
+    title->parser = NULL;
+
+    ogmdvd_reader_unref (title->reader);
+    title->reader = NULL;
+
+    g_free (title->buffer);
+    title->buffer = NULL;
+    title->ptr = NULL;
+
+    return FALSE;
+  }
+
+  return TRUE;
+}
+
