@@ -1,5 +1,5 @@
 /* OGMDvd - A wrapper library around libdvdread
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,8 @@
 #include <ogmdvd-disc.h>
 #include <ogmdvd-enums.h>
 #include <ogmdvd-labels.h>
+#include <ogmdvd-parser.h>
+#include <ogmdvd-reader.h>
 #include <ogmdvd-stream.h>
 #include <ogmdvd-subp.h>
 #include <ogmdvd-title.h>
