@@ -1,5 +1,5 @@
 /* OGMJob - A library to spawn processes
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -76,11 +76,10 @@ ogmjob_exec_class_init (OGMJobExecClass *klass)
   OGMJobSpawnClass *spawn_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
-  spawn_class = OGMJOB_SPAWN_CLASS (klass);
-
   gobject_class->dispose = ogmjob_exec_dispose;
   gobject_class->finalize = ogmjob_exec_finalize;
 
+  spawn_class = OGMJOB_SPAWN_CLASS (klass);
   spawn_class->run = ogmjob_exec_run;
   spawn_class->cancel = ogmjob_exec_cancel;
   spawn_class->suspend = ogmjob_exec_suspend;
@@ -134,7 +133,7 @@ ogmjob_exec_finalize (GObject *gobject)
   if (exec->priv->error)
   {
 #ifdef G_ENABLE_DEBUG
-    g_warning (exec->priv->error->message);
+    g_warning ("%s", exec->priv->error->message);
 #endif
     g_error_free (exec->priv->error);
   }
@@ -224,9 +223,9 @@ ogmjob_exec_watch (GIOChannel *channel, GIOCondition condition, OGMJobExec *exec
         gdouble fraction;
 
         fraction = exec->priv->watch_func (exec, vline[i], exec->priv->watch_data);
-        fraction = CLAMP (fraction, 0.0, 1.0);
+        fraction = MIN (fraction, 1.0);
 
-        if (fraction > 0.0 && fraction > exec->priv->fraction)
+        if (fraction > 0.0 && fraction > exec->priv->fraction + 0.001)
         {
           exec->priv->fraction = fraction;
           if (exec->priv->swapped)
@@ -265,13 +264,13 @@ ogmjob_exec_run (OGMJobSpawn *spawn)
   flags = G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD;
 
   ptrout = NULL;
-  if (exec->priv->watch_func && exec->priv->watch_out)
+  if (exec->priv->watch_out)
     ptrout = &fdout;
   else
     flags |= G_SPAWN_STDOUT_TO_DEV_NULL;
 
   ptrerr = NULL;
-  if (exec->priv->watch_func && exec->priv->watch_err)
+  if (exec->priv->watch_err)
     ptrerr = &fderr;
   else
     flags |= G_SPAWN_STDERR_TO_DEV_NULL;
@@ -370,7 +369,7 @@ ogmjob_exec_construct (OGMJobExec *exec, const gchar *command_line)
   if (!g_shell_parse_argv (command_line, &argc, &argv, &error))
   {
 #ifdef G_ENABLE_DEBUG
-    g_warning (error->message);
+    g_warning ("%s", error->message);
 #endif
     g_error_free (error);
     return;
