@@ -1,5 +1,5 @@
 /* OGMJob - A library to spawn processes
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -48,10 +48,9 @@ ogmjob_pipeline_class_init (OGMJobPipelineClass *klass)
   OGMJobContainerClass *container_class;
 
   spawn_class = OGMJOB_SPAWN_CLASS (klass);
-  container_class = OGMJOB_CONTAINER_CLASS (klass);
-
   spawn_class->run = ogmjob_pipeline_run;
 
+  container_class = OGMJOB_CONTAINER_CLASS (klass);
   container_class->add = ogmjob_pipeline_add;
   container_class->remove = ogmjob_pipeline_remove;
 
@@ -97,7 +96,9 @@ ogmjob_pipeline_run (OGMJobSpawn *spawn)
 static void
 ogmjob_pipeline_child_progress (OGMJobPipeline *pipeline, gdouble fraction, OGMJobSpawn *child)
 {
-  if (fraction > pipeline->priv->fraction)
+  if (fraction < 0.0)
+    g_signal_emit_by_name (pipeline, "progress", fraction);
+  else if (fraction > pipeline->priv->fraction)
   {
     pipeline->priv->fraction = fraction;
     g_signal_emit_by_name (pipeline, "progress", fraction);
