@@ -1,5 +1,5 @@
 /* OGMJob - A library to spawn processes
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -53,10 +53,9 @@ ogmjob_queue_class_init (OGMJobQueueClass *klass)
   OGMJobContainerClass *container_class;
 
   spawn_class = OGMJOB_SPAWN_CLASS (klass);
-  container_class = OGMJOB_CONTAINER_CLASS (klass);
-
   spawn_class->run = ogmjob_queue_run;
 
+  container_class = OGMJOB_CONTAINER_CLASS (klass);
   container_class->add = ogmjob_queue_add;
   container_class->remove = ogmjob_queue_remove;
 
@@ -104,6 +103,9 @@ ogmjob_queue_run (OGMJobSpawn *spawn)
 static void
 ogmjob_queue_child_progress (OGMJobQueue *queue, gdouble fraction, OGMJobSpawn *child)
 {
+  if (fraction < 0.0)
+    g_signal_emit_by_name (queue, "progress", fraction);
+
   fraction = (queue->priv->completed + fraction) / (gdouble) queue->priv->nchildren;
   g_signal_emit_by_name (queue, "progress", fraction);
 }
