@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@ typedef struct
 } OGMRipPrefData;
 
 static GConfClient *client;
+static gchar *default_dir;
 
 /**
  * ogmrip_preferences_init:
@@ -52,7 +53,10 @@ ogmrip_preferences_init (const gchar *dir)
   client = gconf_client_get_default ();
 
   if (dir)
+  {
+    ogmrip_preferences_set_default_dir (dir);
     gconf_client_add_dir (client, dir, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+  }
 }
 
 /**
@@ -68,6 +72,35 @@ ogmrip_preferences_uninit (void)
     g_object_unref (client);
     client = NULL;
   }
+
+  if (default_dir)
+    g_free (default_dir);
+}
+
+/**
+ * ogmrip_preferences_set_default_dir:
+ * @dir: A preferences directory
+ *
+ * Sets the default preferences directory.
+ */
+void
+ogmrip_preferences_set_default_dir (const gchar *dir)
+{
+  if (default_dir)
+    g_free (default_dir);
+  default_dir = NULL;
+
+  if (dir)
+    default_dir = g_strdup (dir);
+}
+
+static gchar *
+ogmrip_preferences_get_key (const gchar *key)
+{
+  if (!default_dir || key[0] == '/')
+    return g_strdup (key);
+  else
+    return g_strconcat (default_dir, "/", key, NULL);
 }
 
 /**
@@ -81,7 +114,31 @@ ogmrip_preferences_uninit (void)
 GConfValue *
 ogmrip_preferences_get (const gchar *key)
 {
-  return gconf_client_get (client, key, NULL);
+  GConfValue *value;
+  gchar *real_key;
+
+  real_key = ogmrip_preferences_get_key (key);
+  value = gconf_client_get (client, real_key, NULL);
+  g_free (real_key);
+
+  return value;
+}
+
+/**
+ * ogmrip_preferences_set:
+ * @key: key to set
+ * @value: new value
+ *
+ * Sets the value of a configuration key.
+ */
+void
+ogmrip_preferences_set (const gchar *key, GConfValue *value)
+{
+  gchar *real_key;
+
+  real_key = ogmrip_preferences_get_key (key);
+  gconf_client_set (client, real_key, value, NULL);
+  g_free (real_key);
 }
 
 /**
@@ -97,16 +154,21 @@ gboolean
 ogmrip_preferences_get_bool (const gchar *key, gboolean def)
 {
   GConfValue* val;
+  gchar *real_key;
 
-  val = gconf_client_get (client, key, NULL);
+  real_key = ogmrip_preferences_get_key (key);
+
+  val = gconf_client_get (client, real_key, NULL);
   if (!val)
-    gconf_client_set_bool (client, key, def, NULL);
+    gconf_client_set_bool (client, real_key, def, NULL);
   else
   {
     def = gconf_value_get_bool (val);
     gconf_value_free (val);
   }
 
+  g_free (real_key);
+
   return def;
 }
 
@@ -121,7 +183,11 @@ ogmrip_preferences_get_bool (const gchar *key, gboolean def)
 void
 ogmrip_preferences_set_bool (const gchar *key, gboolean value)
 {
-  gconf_client_set_bool (client, key, value, NULL);
+  gchar *real_key;
+
+  real_key = ogmrip_preferences_get_key (key);
+  gconf_client_set_bool (client, real_key, value, NULL);
+  g_free (real_key);
 }
 
 /**
@@ -137,16 +203,21 @@ gint
 ogmrip_preferences_get_int (const gchar *key, gint def)
 {
   GConfValue* val;
+  gchar *real_key;
 
-  val = gconf_client_get (client, key, NULL);
+  real_key = ogmrip_preferences_get_key (key);
+
+  val = gconf_client_get (client, real_key, NULL);
   if (!val)
-    gconf_client_set_int (client, key, def, NULL);
+    gconf_client_set_int (client, real_key, def, NULL);
   else
   {
     def = gconf_value_get_int (val);
     gconf_value_free (val);
   }
 
+  g_free (real_key);
+
   return def;
 }
 
@@ -161,7 +232,60 @@ ogmrip_preferences_get_int (const gchar *key, gint def)
 void
 ogmrip_preferences_set_int (const gchar *key, gint value)
 {
-  gconf_client_set_int (client, key, value, NULL);
+  gchar *real_key;
+
+  real_key = ogmrip_preferences_get_key (key);
+  gconf_client_set_int (client, real_key, value, NULL);
+  g_free (real_key);
+}
+
+/**
+ * ogmrip_preferences_get_double:
+ * @key: key to get
+ * @def: default value
+ *
+ * Requests the double value stored at @key.
+ *
+ * Returns: the value of @key, or @def if no value was stored
+ */
+gdouble
+ogmrip_preferences_get_double (const gchar *key, gdouble def)
+{
+  GConfValue* val;
+  gchar *real_key;
+
+  real_key = ogmrip_preferences_get_key (key);
+
+  val = gconf_client_get (client, real_key, NULL);
+  if (!val)
+    gconf_client_set_float (client, real_key, def, NULL);
+  else
+  {
+    def = gconf_value_get_float (val);
+    gconf_value_free (val);
+  }
+
+  g_free (real_key);
+
+  return def;
+}
+
+/**
+ * ogmrip_preferences_set_double:
+ * @key: key you want to set the value of
+ * @value: new value of @key
+ *
+ * Change the value of @key to @val. Automatically creates the key if it didn't
+ * exist before.
+ */
+void
+ogmrip_preferences_set_double (const gchar *key, gdouble value)
+{
+  gchar *real_key;
+
+  real_key = ogmrip_preferences_get_key (key);
+  gconf_client_set_float (client, real_key, value, NULL);
+  g_free (real_key);
 }
 
 /**
@@ -177,13 +301,18 @@ gchar *
 ogmrip_preferences_get_string (const gchar *key, const gchar *def)
 {
   GConfValue* val;
-  gchar *str;
+  gchar *real_key, *str = NULL;
 
-  val = gconf_client_get (client, key, NULL);
+  real_key = ogmrip_preferences_get_key (key);
+
+  val = gconf_client_get (client, real_key, NULL);
   if (!val)
   {
-    gconf_client_set_string (client, key, def, NULL);
-    str = g_strdup (def);
+    if (def)
+    {
+      gconf_client_set_string (client, real_key, def, NULL);
+      str = g_strdup (def);
+    }
   }
   else
   {
@@ -191,6 +320,8 @@ ogmrip_preferences_get_string (const gchar *key, const gchar *def)
     gconf_value_free (val);
   }
 
+  g_free (real_key);
+
   return str;
 }
 
@@ -205,7 +336,11 @@ ogmrip_preferences_get_string (const gchar *key, const gchar *def)
 void
 ogmrip_preferences_set_string (const gchar *key, const gchar *value)
 {
-  gconf_client_set_string (client, key, value, NULL);
+  gchar *real_key;
+
+  real_key = ogmrip_preferences_get_key (key);
+  gconf_client_set_string (client, real_key, value, NULL);
+  g_free (real_key);
 }
 
 /**
@@ -220,9 +355,15 @@ ogmrip_preferences_set_string (const gchar *key, const gchar *value)
 gchar *
 ogmrip_preferences_get_filename (const gchar *key, const gchar *def)
 {
-  gchar *utf8, *path;
+  gchar *real_key, *utf8, *path;
+
+  real_key = ogmrip_preferences_get_key (key);
+  utf8 = ogmrip_preferences_get_string (real_key, def);
+  g_free (real_key);
+
+  if (!utf8)
+    return NULL;
 
-  utf8 = ogmrip_preferences_get_string (key, def);
   path = g_filename_from_utf8 (utf8, -1, NULL, NULL, NULL);
   g_free (utf8);
 
@@ -240,7 +381,85 @@ ogmrip_preferences_get_filename (const gchar *key, const gchar *def)
 void
 ogmrip_preferences_set_filename (const gchar *key, const gchar *value)
 {
+  gchar *real_key;
+
+  real_key = ogmrip_preferences_get_key (key);
   gconf_client_set_string (client, key, value, NULL);
+  g_free (real_key);
+}
+
+/**
+ * ogmrip_preferences_unset:
+ * @key: key to unset
+ *
+ * Unsets the value of @key; if @key is already unset, has no effect.
+ */
+void
+ogmrip_preferences_unset (const gchar *key)
+{
+  gconf_client_unset (client, key, NULL);
+}
+
+/**
+ * ogmrip_preferences_recursive_unset:
+ * @key: a key or directory name to be unset
+ *
+ * Unsets all keys below @key, including @key itself. If any unset fails,
+ * continues on to unset as much as it can.
+ */
+void
+ogmrip_preferences_recursive_unset (const gchar *key)
+{
+  gconf_client_recursive_unset (client, key, 0, NULL);
+  gconf_client_suggest_sync (client, NULL);
+}
+
+/**
+ * ogmrip_preferences_dir_exists:
+ * @dir: directory to check for
+ *
+ * Queries whether the directory @dir exists in the database.
+ *
+ * Returns: TRUE or FALSE
+ */
+gboolean
+ogmrip_preferences_dir_exists (const gchar *dir)
+{
+  return gconf_client_dir_exists (client, dir, NULL);
+}
+
+/**
+ * ogmrip_preferences_all_dirs:
+ * @dir: directory to get subdirectories from
+ *
+ * Lists the subdirectories in @dir. The returned list contains allocated
+ * strings. Each string is the absolute path of a subdirectory. You should
+ * g_free() each string in the list, then g_slist_free() the list itself.
+ *
+ * Returns: List of allocated subdirectory names
+ */
+GSList *
+ogmrip_preferences_all_dirs (const gchar *dir)
+{
+  return gconf_client_all_dirs (client, dir, NULL);
+}
+
+/**
+ * ogmrip_preferences_all_entries:
+ * @dir: directory to get entries from
+ *
+ * Lists the key-value pairs in @dir. Does not list subdirectories; for that use
+ * ogmrip_preferences_all_dirs(). The returned list contains GConfEntry objects.
+ * A GConfEntry contains an absolute key and a value. The list is not recursive,
+ * it contains only the immediate children of dir. To free the returned list,
+ * gconf_entry_free() each list element, then g_slist_free() the list itself.
+ *
+ * Returns: List of GConfEntry
+ */
+GSList *
+ogmrip_preferences_all_entries (const gchar *dir)
+{
+  return gconf_client_all_entries (client, dir, NULL);
 }
 
 /*
@@ -257,9 +476,12 @@ static guint
 gconf_client_notify_add_while_alive (GConfClient *client, const gchar *key,
     GConfClientNotifyFunc func, gpointer user_data, GFreeFunc destroy_notify, GtkWidget *widget)
 {
+  gchar *real_key;
   guint handler_id;
 
-  handler_id = gconf_client_notify_add (client, key, func, user_data, destroy_notify, NULL);
+  real_key = ogmrip_preferences_get_key (key);
+  handler_id = gconf_client_notify_add (client, real_key, func, user_data, destroy_notify, NULL);
+  g_free (real_key);
 
   g_object_weak_ref (G_OBJECT (widget),
       gconf_client_notify_while_alive_disconnector,
@@ -298,6 +520,7 @@ ogmrip_preferences_add_notify_while_alive (const gchar *key, GFunc func, gpointe
 {
   OGMRipPrefNotification *notification;
   guint handler_id;
+  gchar *real_key;
 
   g_return_val_if_fail (key != NULL, 0);
   g_return_val_if_fail (func != NULL, 0);
@@ -307,13 +530,17 @@ ogmrip_preferences_add_notify_while_alive (const gchar *key, GFunc func, gpointe
   notification->func = func;
   notification->user_data = data;
 
+  real_key = ogmrip_preferences_get_key (key);
+
   if (GTK_IS_WIDGET (widget))
-    handler_id = gconf_client_notify_add_while_alive (client, key,
+    handler_id = gconf_client_notify_add_while_alive (client, real_key,
         (GConfClientNotifyFunc) ogmrip_preferences_notified, notification, (GFreeFunc) g_free, widget);
   else
-    handler_id = gconf_client_notify_add (client, key,
+    handler_id = gconf_client_notify_add (client, real_key,
         (GConfClientNotifyFunc) ogmrip_preferences_notified, notification, (GFreeFunc) g_free, NULL);
 
+  g_free (real_key);
+
   if (!handler_id)
     g_free (notification);
 
@@ -347,7 +574,7 @@ ogmrip_preferences_data_new (const gchar *key, OGMRipPrefGetFunc get_func, OGMRi
   OGMRipPrefData *data;
 
   data = g_new0 (OGMRipPrefData, 1);
-  data->key = g_strdup (key);
+  data->key = ogmrip_preferences_get_key (key);
   data->get_func = get_func;
   data->set_func = set_func;
 
@@ -430,7 +657,7 @@ ogmrip_preferences_connect_toggle_custom (GtkWidget *toggle, const gchar *key,
   g_object_set_data_full (G_OBJECT (toggle),
       OGMRIP_PREF_KEY, data, (GDestroyNotify) ogmrip_preferences_data_free);
 
-  ogmrip_preferences_add_notify_while_alive (key,
+  ogmrip_preferences_add_notify_while_alive (data->key,
       (GFunc) ogmrip_preferences_widget_update, toggle, toggle);
 
   g_signal_connect (toggle, "toggled",
@@ -508,7 +735,7 @@ ogmrip_preferences_connect_combo_custom (GtkWidget *combo, const gchar *key,
   g_object_set_data_full (G_OBJECT (combo),
       OGMRIP_PREF_KEY, data, (GDestroyNotify) ogmrip_preferences_data_free);
 
-  ogmrip_preferences_add_notify_while_alive (key,
+  ogmrip_preferences_add_notify_while_alive (data->key,
       (GFunc) ogmrip_preferences_widget_update, combo, combo);
 
   g_signal_connect (combo, "changed",
@@ -595,7 +822,7 @@ ogmrip_preferences_connect_spin_custom (GtkWidget *spin, const gchar *key,
   g_object_set_data_full (G_OBJECT (spin),
       OGMRIP_PREF_KEY, data, (GDestroyNotify) ogmrip_preferences_data_free);
 
-  ogmrip_preferences_add_notify_while_alive (key,
+  ogmrip_preferences_add_notify_while_alive (data->key,
       (GFunc) ogmrip_preferences_widget_update, spin, spin);
 
   g_signal_connect (spin, "value-changed",
@@ -727,7 +954,7 @@ ogmrip_preferences_connect_radio_custom (GtkWidget *radio, const gchar *key,
   g_object_set_data_full (G_OBJECT (radio),
       OGMRIP_PREF_KEY, data, (GDestroyNotify) ogmrip_preferences_data_free);
 
-  ogmrip_preferences_add_notify_while_alive (key,
+  ogmrip_preferences_add_notify_while_alive (data->key,
       (GFunc) ogmrip_preferences_radio_update, radio, radio);
 
   g_signal_connect (radio, "toggled",
@@ -826,7 +1053,7 @@ ogmrip_preferences_connect_chooser_custom (GtkWidget *chooser, const gchar *key,
   g_object_set_data_full (G_OBJECT (chooser),
       OGMRIP_PREF_KEY, data, (GDestroyNotify) ogmrip_preferences_data_free);
 
-  ogmrip_preferences_add_notify_while_alive (key,
+  ogmrip_preferences_add_notify_while_alive (data->key,
       (GFunc) ogmrip_preferences_widget_update, chooser, chooser);
 
   g_signal_connect (chooser, "current-folder-changed",
