@@ -1,5 +1,5 @@
 /* OGMRip - A wrapper library around libdvdread
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -585,7 +585,7 @@ ogmrip_source_chooser_widget_add_audio_streams (OGMRipSourceChooserWidget *choos
 {
   GtkTreeIter iter;
   OGMDvdAudioStream *astream;
-  gint aid, naid, channels, format, lang, content;
+  gint aid, naid, channels, format, lang, content, bitrate;
   gchar *str;
 
   gtk_list_store_append (GTK_LIST_STORE (model), &iter);
@@ -598,19 +598,35 @@ ogmrip_source_chooser_widget_add_audio_streams (OGMRipSourceChooserWidget *choos
     astream = ogmdvd_title_get_nth_audio_stream (title, aid);
     if (astream)
     {
+      bitrate = ogmdvd_audio_stream_get_bitrate (astream);
       channels = ogmdvd_audio_stream_get_channels (astream);
       content = ogmdvd_audio_stream_get_content (astream);
       format = ogmdvd_audio_stream_get_format (astream);
       lang = ogmdvd_audio_stream_get_language (astream);
 
       if (content > 0)
-        str = g_strdup_printf ("%s %02d: %s (%s, %s, %s)", _("Track"), aid + 1, 
-            ogmdvd_get_audio_content_label (content), ogmdvd_get_language_label (lang), 
-            ogmdvd_get_audio_format_label (format), ogmdvd_get_audio_channels_label (channels));
+      {
+        if (bitrate > 0)
+          str = g_strdup_printf ("%s %02d: %s (%s, %s, %s, %d kbps)", _("Track"), aid + 1, 
+              ogmdvd_get_audio_content_label (content), ogmdvd_get_language_label (lang), 
+              ogmdvd_get_audio_format_label (format), ogmdvd_get_audio_channels_label (channels),
+              bitrate / 1000);
+        else
+          str = g_strdup_printf ("%s %02d: %s (%s, %s, %s)", _("Track"), aid + 1, 
+              ogmdvd_get_audio_content_label (content), ogmdvd_get_language_label (lang), 
+              ogmdvd_get_audio_format_label (format), ogmdvd_get_audio_channels_label (channels));
+      }
       else
-        str = g_strdup_printf ("%s %02d (%s, %s, %s)", _("Track"), aid + 1, 
-            ogmdvd_get_language_label (lang), ogmdvd_get_audio_format_label (format), 
-            ogmdvd_get_audio_channels_label (channels));
+      {
+        if (bitrate > 0)
+          str = g_strdup_printf ("%s %02d (%s, %s, %s, %d kbps)", _("Track"), aid + 1, 
+              ogmdvd_get_language_label (lang), ogmdvd_get_audio_format_label (format), 
+              ogmdvd_get_audio_channels_label (channels), bitrate / 1000);
+        else
+          str = g_strdup_printf ("%s %02d (%s, %s, %s)", _("Track"), aid + 1, 
+              ogmdvd_get_language_label (lang), ogmdvd_get_audio_format_label (format), 
+              ogmdvd_get_audio_channels_label (channels));
+      }
 
       gtk_list_store_append (GTK_LIST_STORE (model), &iter);
       gtk_list_store_set (GTK_LIST_STORE (model), &iter,
