@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,7 +19,7 @@
 #ifndef __OGMRIP_AAC_H__
 #define __OGMRIP_AAC_H__
 
-#include <ogmrip-audio.h>
+#include <ogmrip-audio-codec.h>
 
 G_BEGIN_DECLS
 
@@ -30,19 +30,16 @@ G_BEGIN_DECLS
 #define OGMRIP_IS_AAC_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_AAC))
 
 typedef struct _OGMRipAac      OGMRipAac;
-typedef struct _OGMRipAacPriv  OGMRipAacPriv;
 typedef struct _OGMRipAacClass OGMRipAacClass;
 
 struct _OGMRipAac
 {
-  OGMRipAudio parent_instance;
-
-  OGMRipAacPriv *priv;
+  OGMRipAudioCodec parent_instance;
 };
 
 struct _OGMRipAacClass
 {
-  OGMRipAudioClass parent_class;
+  OGMRipAudioCodecClass parent_class;
 };
 
 GType         ogmrip_aac_get_type  (void);
