@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,29 +22,30 @@
 
 #include "ogmrip-acopy.h"
 #include "ogmrip-mplayer.h"
-#include "ogmrip-version.h"
 #include "ogmrip-plugin.h"
+#include "ogmrip-version.h"
 
 #include "ogmjob-exec.h"
 
 #include <stdio.h>
 #include <glib/gi18n-lib.h>
 
-#define ACOPY_SPF 768
+#define ACOPY_SPF 1536
 
 static gint ogmrip_audio_copy_run (OGMJobSpawn *spawn);
-static gint ogmrip_audio_copy_get_samples_per_frame (OGMRipAudio *audio);
+static gint ogmrip_audio_copy_get_samples_per_frame (OGMRipAudioCodec *audio);
 
 gchar **
-ogmrip_audio_copy_command (OGMRipAudio *audio, const gchar *input, const gchar *output)
+ogmrip_audio_copy_command (OGMRipAudioCodec *audio, const gchar *input, const gchar *output)
 {
   OGMDvdTitle *title;
+/*
   OGMDvdAudioStream *astream;
-
+*/
   GPtrArray *argv;
   gint vid;
 
-  g_return_val_if_fail (OGMRIP_IS_AUDIO (audio), NULL);
+  g_return_val_if_fail (OGMRIP_IS_AUDIO_CODEC (audio), NULL);
 
   if (!output)
     output = ogmrip_codec_get_output (OGMRIP_CODEC (audio));
@@ -52,50 +53,52 @@ ogmrip_audio_copy_command (OGMRipAudio *audio, const gchar *input, const gchar *
 
   title = ogmrip_codec_get_input (OGMRIP_CODEC (audio));
   g_return_val_if_fail (title != NULL, NULL);
-
-  astream = ogmrip_audio_get_dvd_audio_stream (audio);
+/*
+  astream = ogmrip_audio_codec_get_dvd_audio_stream (audio);
   g_return_val_if_fail (astream != NULL, NULL);
-
-  argv = ogmrip_mencoder_audio_command (audio, title, astream, output);
+*/
+  argv = ogmrip_mencoder_audio_command (audio, /*title, astream,*/ output);
 
   g_ptr_array_add (argv, g_strdup ("-ovc"));
-#if MPLAYER_CHECK_VERSION(1,0,0,8)
-  g_ptr_array_add (argv, g_strdup ("copy"));
-  g_ptr_array_add (argv, g_strdup ("-of"));
-  g_ptr_array_add (argv, g_strdup ("rawaudio"));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,8) */
-  g_ptr_array_add (argv, g_strdup ("frameno"));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
+  if (MPLAYER_CHECK_VERSION (1,0,0,8))
+  {
+    g_ptr_array_add (argv, g_strdup ("copy"));
+    g_ptr_array_add (argv, g_strdup ("-of"));
+    g_ptr_array_add (argv, g_strdup ("rawaudio"));
+  }
+  else
+    g_ptr_array_add (argv, g_strdup ("frameno"));
 
   g_ptr_array_add (argv, g_strdup ("-oac"));
   g_ptr_array_add (argv, g_strdup ("copy"));
 
   vid = ogmdvd_title_get_nr (title);
 
-#if MPLAYER_CHECK_VERSION(1,0,0,1)
-  g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,1) */
-  g_ptr_array_add (argv, g_strdup ("-dvd"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,1) */
+  if (MPLAYER_CHECK_VERSION (1,0,0,1))
+    g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
+  else
+  {
+    g_ptr_array_add (argv, g_strdup ("-dvd"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
+  }
 
   g_ptr_array_add (argv, NULL);
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
 
-G_DEFINE_TYPE (OGMRipAudioCopy, ogmrip_audio_copy, OGMRIP_TYPE_AUDIO)
+G_DEFINE_TYPE (OGMRipAudioCopy, ogmrip_audio_copy, OGMRIP_TYPE_AUDIO_CODEC)
 
 static void
 ogmrip_audio_copy_class_init (OGMRipAudioCopyClass *klass)
 {
   OGMJobSpawnClass *spawn_class;
-  OGMRipAudioClass *audio_class;
+  OGMRipAudioCodecClass *audio_class;
 
   spawn_class = OGMJOB_SPAWN_CLASS (klass);
   spawn_class->run = ogmrip_audio_copy_run;
 
-  audio_class = OGMRIP_AUDIO_CLASS (klass);
+  audio_class = OGMRIP_AUDIO_CODEC_CLASS (klass);
   audio_class->get_samples_per_frame = ogmrip_audio_copy_get_samples_per_frame;
 }
 
@@ -111,7 +114,7 @@ ogmrip_audio_copy_run (OGMJobSpawn *spawn)
   gchar **argv;
   gint result;
 
-  argv = ogmrip_audio_copy_command (OGMRIP_AUDIO (spawn), NULL, NULL);
+  argv = ogmrip_audio_copy_command (OGMRIP_AUDIO_CODEC (spawn), NULL, NULL);
   if (!argv)
     return OGMJOB_RESULT_ERROR;
 
@@ -128,7 +131,7 @@ ogmrip_audio_copy_run (OGMJobSpawn *spawn)
 }
 
 gint
-ogmrip_audio_copy_get_samples_per_frame (OGMRipAudio *audio)
+ogmrip_audio_copy_get_samples_per_frame (OGMRipAudioCodec *audio)
 {
   return ACOPY_SPF;
 }
@@ -148,7 +151,7 @@ ogmrip_audio_copy_new (OGMDvdAudioStream *audio, const gchar *output)
   return g_object_new (OGMRIP_TYPE_AUDIO_COPY, "stream", audio, "output", output, NULL);
 }
 
-static OGMRipPluginAudioCodec acopy_plugin =
+static OGMRipAudioPlugin acopy_plugin =
 {
   NULL,
   G_TYPE_NONE,
@@ -157,9 +160,12 @@ static OGMRipPluginAudioCodec acopy_plugin =
   OGMRIP_FORMAT_COPY
 };
 
-OGMRipPluginAudioCodec *
+OGMRipAudioPlugin *
 ogmrip_init_plugin (void)
 {
+  if (!ogmrip_check_mencoder ())
+    return NULL;
+
   acopy_plugin.type = OGMRIP_TYPE_AUDIO_COPY;
 
   return &acopy_plugin;
