@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,7 @@
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
 #include "ogmrip-fs.h"
+#include "ogmrip-version.h"
 
 #include "ogmjob-exec.h"
 #include "ogmjob-queue.h"
@@ -42,7 +43,7 @@ static gchar **
 ogmrip_avi_command (OGMRipContainer *avi)
 {
   GPtrArray *argv;
-  OGMRipVideo *video;
+  OGMRipVideoCodec *video;
   const gchar *output, *filename;
 
   g_return_val_if_fail (OGMRIP_IS_AVI (avi), NULL);
@@ -62,36 +63,23 @@ ogmrip_avi_command (OGMRipContainer *avi)
 }
 
 static gchar **
-ogmrip_copy_command (OGMRipContainer *container, const gchar *input, const gchar *output)
+ogmrip_copy_command (OGMRipContainer *container, const gchar *input, const gchar *ext)
 {
   GPtrArray *argv;
-  gchar *real_output;
+  const gchar *filename;
+  gchar *output;
 
   g_return_val_if_fail (OGMRIP_IS_CONTAINER (container), NULL);
   g_return_val_if_fail (input != NULL, NULL);
 
-  if (output)
-    real_output = g_strdup (output);
-  else
-  {
-    const gchar *ext;
-
-    output = ogmrip_container_get_output (container);
-    g_return_val_if_fail (output != NULL, NULL);
-
-    ext = ogmrip_fs_get_extension (input);
-
-    if (ext && strcmp (ext, "idx") == 0)
-      real_output = ogmrip_fs_set_extension (output, ext);
-    else
-      real_output = ogmrip_fs_set_extension (output, "sub");
-  }
+  filename = ogmrip_container_get_output (container);
+  output = ogmrip_fs_set_extension (filename, ext);
 
   argv = g_ptr_array_new ();
   g_ptr_array_add (argv, g_strdup ("cp"));
   g_ptr_array_add (argv, g_strdup ("-f"));
   g_ptr_array_add (argv, g_strdup (input));
-  g_ptr_array_add (argv, real_output);
+  g_ptr_array_add (argv, output);
   g_ptr_array_add (argv, NULL);
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
@@ -125,35 +113,45 @@ ogmrip_avi_foreach_subp (OGMRipContainer *avi,
 
   const gchar *filename;
   gchar *input, **argv = NULL;
+  gint format;
 
   filename = ogmrip_codec_get_output (codec);
 
-  if (demuxer == OGMRIP_SUBP_DEMUXER_VOBSUB)
-    input = g_strconcat (filename, ".sub", NULL);
-  else
-    input = g_strdup (filename);
+  format = ogmrip_plugin_get_subp_codec_format (G_TYPE_FROM_INSTANCE (codec));
 
-  argv = ogmrip_copy_command (avi, input, NULL);
-  if (argv)
+  if (format == OGMRIP_FORMAT_SRT)
   {
-    child = ogmjob_exec_newv (argv);
-    ogmjob_container_add (OGMJOB_CONTAINER (queue), child);
-    g_object_unref (child);
-  }
-  g_free (input);
-
-  if (demuxer == OGMRIP_SUBP_DEMUXER_VOBSUB)
-  {
-    input = g_strconcat (filename, ".idx", NULL);
-
-    argv = ogmrip_copy_command (avi, input, NULL);
+    argv = ogmrip_copy_command (avi, filename, "srt");
     if (argv)
     {
       child = ogmjob_exec_newv (argv);
       ogmjob_container_add (OGMJOB_CONTAINER (queue), child);
       g_object_unref (child);
     }
+  }
+  else if (format == OGMRIP_FORMAT_VOBSUB)
+  {
+    input = g_strconcat (filename, ".sub", NULL);
+    argv = ogmrip_copy_command (avi, input, "sub");
     g_free (input);
+
+    if (argv)
+    {
+      child = ogmjob_exec_newv (argv);
+      ogmjob_container_add (OGMJOB_CONTAINER (queue), child);
+      g_object_unref (child);
+    }
+
+    input = g_strconcat (filename, ".idx", NULL);
+    argv = ogmrip_copy_command (avi, input, "idx");
+    g_free (input);
+
+    if (argv)
+    {
+      child = ogmjob_exec_newv (argv);
+      ogmjob_container_add (OGMJOB_CONTAINER (queue), child);
+      g_object_unref (child);
+    }
   }
 }
 
@@ -211,12 +209,12 @@ ogmrip_avi_new (const gchar *output)
   return g_object_new (OGMRIP_TYPE_AVI, "output", output, NULL);
 }
 
-static OGMRipPluginContainer avi_plugin =
+static OGMRipContainerPlugin avi_plugin =
 {
   NULL,
   G_TYPE_NONE,
   "avi",
-  N_("Avi Media (DivX)"),
+  N_("Audio-Video Interlace (AVI)"),
   TRUE,
   1,
   1,
@@ -225,6 +223,8 @@ static OGMRipPluginContainer avi_plugin =
 
 static gint formats[] = 
 {
+  OGMRIP_FORMAT_MPEG1,
+  OGMRIP_FORMAT_MPEG2,
   OGMRIP_FORMAT_MPEG4,
   OGMRIP_FORMAT_H264,
   OGMRIP_FORMAT_THEORA,
@@ -239,9 +239,12 @@ static gint formats[] =
   -1
 };
 
-OGMRipPluginContainer *
+OGMRipContainerPlugin *
 ogmrip_init_plugin (void)
 {
+  if (!ogmrip_check_mencoder ())
+    return NULL;
+
   avi_plugin.type = OGMRIP_TYPE_AVI;
   avi_plugin.formats = formats;
 
