@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -43,8 +43,11 @@ struct _OGMRipCodecPriv
 
   OGMRipEdl *edl;
 
+  gboolean telecine;
+  gboolean progressive;
   gboolean do_unlink;
   gboolean dirty;
+
   gdouble length;
 
   guint start;
@@ -59,9 +62,13 @@ enum
   PROP_LENGTH,
   PROP_START_CHAPTER,
   PROP_END_CHAPTER,
+/*
   PROP_FRAMERATE_NUMERATOR,
   PROP_FRAMERATE_DENOMINATOR,
-  PROP_FRAMESTEP
+*/
+  PROP_FRAMESTEP,
+  PROP_PROGRESSIVE,
+  PROP_TELECINE
 };
 
 static void ogmrip_codec_dispose      (GObject      *gobject);
@@ -108,7 +115,7 @@ ogmrip_codec_class_init (OGMRipCodecClass *klass)
   g_object_class_install_property (gobject_class, PROP_END_CHAPTER, 
         g_param_spec_int ("end-chapter", "End chapter property", "Set end chapter", 
            -1, G_MAXINT, -1, G_PARAM_READWRITE));
-
+/*
   g_object_class_install_property (gobject_class, PROP_FRAMERATE_NUMERATOR, 
         g_param_spec_uint ("framerate-numerator", "Framerate numerator property", "Set framerate numerator", 
            0, G_MAXUINT, 25, G_PARAM_READWRITE));
@@ -116,11 +123,19 @@ ogmrip_codec_class_init (OGMRipCodecClass *klass)
   g_object_class_install_property (gobject_class, PROP_FRAMERATE_DENOMINATOR, 
         g_param_spec_uint ("framerate-denominator", "Framerate denominator property", "Set framerate denominator", 
            0, G_MAXUINT, 1, G_PARAM_READWRITE));
-
+*/
   g_object_class_install_property (gobject_class, PROP_FRAMESTEP, 
         g_param_spec_uint ("framestep", "Framestep property", "Set framestep", 
            0, G_MAXUINT, 1, G_PARAM_READWRITE));
 
+  g_object_class_install_property (gobject_class, PROP_PROGRESSIVE, 
+        g_param_spec_boolean ("progressive", "Progressive property", "Set progressive", 
+           FALSE, G_PARAM_READWRITE));
+
+  g_object_class_install_property (gobject_class, PROP_TELECINE, 
+        g_param_spec_boolean ("telecine", "Telecine property", "Set telecine", 
+           FALSE, G_PARAM_READWRITE));
+
   g_type_class_add_private (klass, sizeof (OGMRipCodecPriv));
 }
 
@@ -190,15 +205,23 @@ ogmrip_codec_set_property (GObject *gobject, guint property_id, const GValue *va
     case PROP_END_CHAPTER: 
       ogmrip_codec_set_chapters (codec, codec->priv->start, g_value_get_int (value));
       break;
+/*
     case PROP_FRAMERATE_NUMERATOR: 
       ogmrip_codec_set_framerate (codec, g_value_get_uint (value), codec->priv->framerate_numerator);
       break;
     case PROP_FRAMERATE_DENOMINATOR: 
       ogmrip_codec_set_framerate (codec, codec->priv->framerate_denominator, g_value_get_uint (value));
       break;
+*/
     case PROP_FRAMESTEP: 
       ogmrip_codec_set_framestep (codec, g_value_get_uint (value));
       break;
+    case PROP_PROGRESSIVE: 
+      ogmrip_codec_set_progressive (codec, g_value_get_boolean (value));
+      break;
+    case PROP_TELECINE: 
+      ogmrip_codec_set_telecine (codec, g_value_get_boolean (value));
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, property_id, pspec);
       break;
@@ -229,15 +252,23 @@ ogmrip_codec_get_property (GObject *gobject, guint property_id, GValue *value, G
     case PROP_END_CHAPTER: 
       g_value_set_int (value, codec->priv->end);
       break;
+/*
     case PROP_FRAMERATE_NUMERATOR: 
       g_value_set_uint (value, codec->priv->framerate_numerator);
       break;
     case PROP_FRAMERATE_DENOMINATOR: 
       g_value_set_uint (value, codec->priv->framerate_denominator);
       break;
+*/
     case PROP_FRAMESTEP: 
       g_value_set_uint (value, codec->priv->framestep);
       break;
+    case PROP_PROGRESSIVE: 
+      g_value_set_boolean (value, codec->priv->progressive);
+      break;
+    case PROP_TELECINE: 
+      g_value_set_boolean (value, codec->priv->telecine);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, property_id, pspec);
       break;
@@ -321,6 +352,68 @@ ogmrip_codec_get_input (OGMRipCodec *codec)
   return codec->priv->title;
 }
 
+/**
+ * ogmrip_codec_set_progressive:
+ * @codec: an #OGMRipCodec
+ * @progressive: %TRUE to inverse progressive
+ *
+ * Sets whether an inverse progressive filter will be applied
+ */
+void
+ogmrip_codec_set_progressive (OGMRipCodec *codec, gboolean progressive)
+{
+  g_return_if_fail (OGMRIP_IS_CODEC (codec));
+
+  codec->priv->progressive = progressive;
+}
+
+/**
+ * ogmrip_codec_get_progressive:
+ * @codec: an #OGMRipCodec
+ *
+ * Gets whether an inverse progressive filter will be applied
+ *
+ * Returns: %TRUE if inverse progressive
+ */
+gboolean
+ogmrip_codec_get_progressive (OGMRipCodec *codec)
+{
+  g_return_val_if_fail (OGMRIP_IS_CODEC (codec), FALSE);
+
+  return codec->priv->progressive;
+}
+
+/**
+ * ogmrip_codec_set_telecine:
+ * @codec: an #OGMRipCodec
+ * @telecine: %TRUE to inverse telecine
+ *
+ * Sets whether an inverse telecine filter will be applied
+ */
+void
+ogmrip_codec_set_telecine (OGMRipCodec *codec, gboolean telecine)
+{
+  g_return_if_fail (OGMRIP_IS_CODEC (codec));
+
+  codec->priv->telecine = telecine;
+}
+
+/**
+ * ogmrip_codec_get_telecine:
+ * @codec: an #OGMRipCodec
+ *
+ * Gets whether an inverse telecine filter will be applied
+ *
+ * Returns: %TRUE if inverse telecine
+ */
+gboolean
+ogmrip_codec_get_telecine (OGMRipCodec *codec)
+{
+  g_return_val_if_fail (OGMRIP_IS_CODEC (codec), FALSE);
+
+  return codec->priv->telecine;
+}
+
 /**
  * ogmrip_codec_set_edl:
  * @codec: an #OGMRipCodec
