@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -59,6 +59,13 @@ gdouble       ogmrip_codec_get_length          (OGMRipCodec *codec,
                                                 OGMDvdTime  *length);
 glong         ogmrip_codec_get_frames          (OGMRipCodec *codec);
 
+void          ogmrip_codec_set_telecine        (OGMRipCodec *codec,
+                                                gboolean    telecine);
+gboolean      ogmrip_codec_get_telecine        (OGMRipCodec *codec);
+void          ogmrip_codec_set_progressive     (OGMRipCodec *codec,
+                                                gboolean    progressive);
+gboolean      ogmrip_codec_get_progressive     (OGMRipCodec *codec);
+
 void          ogmrip_codec_set_edl             (OGMRipCodec *codec,
                                                 OGMRipEdl   *edl);
 OGMRipEdl *   ogmrip_codec_get_edl             (OGMRipCodec *codec);
