@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -50,7 +50,7 @@ struct _OGMRipContainerPriv
   GSList *chapters;
   GSList *files;
 
-  OGMRipVideo *video;
+  OGMRipVideoCodec *video;
 };
 
 typedef struct
@@ -460,9 +460,9 @@ ogmrip_container_get_overhead (OGMRipContainer *container)
  *
  * Gets the video codec of the rip.
  *
- * Returns: An #OGMRipVideo, or NULL
+ * Returns: An #OGMRipVideoCodec, or NULL
  */
-OGMRipVideo *
+OGMRipVideoCodec *
 ogmrip_container_get_video (OGMRipContainer *container)
 {
   g_return_val_if_fail (OGMRIP_IS_CONTAINER (container), NULL);
@@ -473,15 +473,15 @@ ogmrip_container_get_video (OGMRipContainer *container)
 /**
  * ogmrip_container_set_video:
  * @container: An #OGMRipContainer
- * @video: An #OGMRipVideo
+ * @video: An #OGMRipVideoCodec
  *
  * Sets the video codec of the rip.
  */
 void
-ogmrip_container_set_video (OGMRipContainer *container, OGMRipVideo *video)
+ogmrip_container_set_video (OGMRipContainer *container, OGMRipVideoCodec *video)
 {
   g_return_if_fail (OGMRIP_IS_CONTAINER (container));
-  g_return_if_fail (OGMRIP_IS_VIDEO (video));
+  g_return_if_fail (OGMRIP_IS_VIDEO_CODEC (video));
 
   g_object_ref (video);
   if (container->priv->video)
@@ -489,25 +489,25 @@ ogmrip_container_set_video (OGMRipContainer *container, OGMRipVideo *video)
   container->priv->video = video;
 
   if (!ogmrip_plugin_get_container_bframes (G_TYPE_FROM_INSTANCE (container)))
-    ogmrip_video_set_max_b_frames (video, 0);
+    ogmrip_video_codec_set_max_b_frames (video, 0);
 }
 
 /**
  * ogmrip_container_add_audio:
  * @container: An #OGMRipContainer
- * @audio: An #OGMRipAudio
+ * @audio: An #OGMRipAudioCodec
  * @demuxer: The demuxer to be used
  * @language: The language of the stream
  *
  * Adds an audio codec to the rip.
  */
 void
-ogmrip_container_add_audio (OGMRipContainer *container, OGMRipAudio *audio, OGMRipAudioDemuxer demuxer, gint language)
+ogmrip_container_add_audio (OGMRipContainer *container, OGMRipAudioCodec *audio, OGMRipAudioDemuxer demuxer, gint language)
 {
   OGMRipContainerChild *child;
 
   g_return_if_fail (OGMRIP_IS_CONTAINER (container));
-  g_return_if_fail (OGMRIP_IS_AUDIO (audio));
+  g_return_if_fail (OGMRIP_IS_AUDIO_CODEC (audio));
 
   child = g_new0 (OGMRipContainerChild, 1);
 
@@ -543,9 +543,9 @@ ogmrip_container_get_audio (OGMRipContainer *container)
  *
  * Gets the audio codec at the given position.
  *
- * Returns: An #OGMRipAudio, or NULL
+ * Returns: An #OGMRipAudioCodec, or NULL
  */
-OGMRipAudio *
+OGMRipAudioCodec *
 ogmrip_container_get_nth_audio (OGMRipContainer *container, gint n)
 {
   OGMRipContainerChild *child;
@@ -563,7 +563,7 @@ ogmrip_container_get_nth_audio (OGMRipContainer *container, gint n)
 
   child = link->data;
 
-  return OGMRIP_AUDIO (child->codec);
+  return OGMRIP_AUDIO_CODEC (child->codec);
 }
 
 /**
@@ -602,19 +602,19 @@ ogmrip_container_foreach_audio (OGMRipContainer *container, OGMRipContainerCodec
 /**
  * ogmrip_container_add_subp:
  * @container: An #OGMRipContainer
- * @subp: An #OGMRipSubp
+ * @subp: An #OGMRipSubpCodec
  * @demuxer: The demuxer to be used
  * @language: The language of the stream
  *
  * Adds a subtitle codec to the rip.
  */
 void
-ogmrip_container_add_subp (OGMRipContainer *container, OGMRipSubp *subp, OGMRipSubpDemuxer demuxer, gint language)
+ogmrip_container_add_subp (OGMRipContainer *container, OGMRipSubpCodec *subp, OGMRipSubpDemuxer demuxer, gint language)
 {
   OGMRipContainerChild *child;
 
   g_return_if_fail (OGMRIP_IS_CONTAINER (container));
-  g_return_if_fail (OGMRIP_IS_SUBP (subp));
+  g_return_if_fail (OGMRIP_IS_SUBP_CODEC (subp));
 
   child = g_new0 (OGMRipContainerChild, 1);
 
@@ -650,9 +650,9 @@ ogmrip_container_get_subp (OGMRipContainer *container)
  *
  * Gets the subtitle codec at the given position.
  *
- * Returns: An #OGMRipSubp, or NULL
+ * Returns: An #OGMRipSubpCodec, or NULL
  */
-OGMRipSubp *
+OGMRipSubpCodec *
 ogmrip_container_get_nth_subp (OGMRipContainer *container, gint n)
 {
   OGMRipContainerChild *child;
@@ -670,7 +670,7 @@ ogmrip_container_get_nth_subp (OGMRipContainer *container, gint n)
 
   child = link->data;
 
-  return OGMRIP_SUBP (child->codec);
+  return OGMRIP_SUBP_CODEC (child->codec);
 }
 
 /**
@@ -943,17 +943,49 @@ ogmrip_container_get_split (OGMRipContainer *container, guint *number, guint *si
 }
 
 static gint64
-ogmrip_container_get_audio_overhead (OGMRipContainer *container, OGMRipContainerChild *child)
+ogmrip_container_get_video_overhead (OGMRipContainer *container)
 {
-  gdouble length;
-  gint samples_per_frame, sample_rate, overhead;
+  gdouble framerate, length, video_frames;
+  guint num, denom;
+  gint overhead;
+
+  if (!container->priv->video)
+    return 0;
+
+  ogmrip_codec_get_framerate (OGMRIP_CODEC (container->priv->video), &num, &denom);
+  framerate = num / (gdouble) denom;
+
+  length = ogmrip_codec_get_length (OGMRIP_CODEC (container->priv->video), NULL);
+  video_frames = length * framerate;
 
-  length = ogmrip_codec_get_length (child->codec, NULL);
-  sample_rate = ogmrip_audio_get_sample_rate (OGMRIP_AUDIO (child->codec));
-  samples_per_frame = ogmrip_audio_get_samples_per_frame (OGMRIP_AUDIO (child->codec));
   overhead = ogmrip_container_get_overhead (container);
 
-  return (gint64) (length * sample_rate * overhead / (gdouble) samples_per_frame);
+  return (gint64) (video_frames * overhead);
+}
+
+static gint64
+ogmrip_container_get_audio_overhead (OGMRipContainer *container, OGMRipContainerChild *child)
+{
+  gdouble length, audio_frames;
+  gint samples_per_frame, sample_rate, channels, overhead;
+
+  length = ogmrip_codec_get_length (child->codec, NULL);
+  samples_per_frame = ogmrip_audio_codec_get_samples_per_frame (OGMRIP_AUDIO_CODEC (child->codec));
+
+  sample_rate = 48000;
+  channels = 1;
+
+  if (ogmrip_plugin_get_audio_codec_format (G_OBJECT_TYPE (child->codec)) != OGMRIP_FORMAT_COPY)
+  {
+    sample_rate = ogmrip_audio_codec_get_sample_rate (OGMRIP_AUDIO_CODEC (child->codec));
+    channels = ogmrip_audio_codec_get_channels (OGMRIP_AUDIO_CODEC (child->codec));
+  }
+
+  audio_frames = length * sample_rate * (channels + 1) / samples_per_frame;
+
+  overhead = ogmrip_container_get_overhead (container);
+
+  return (gint64) (audio_frames * overhead);
 }
 
 static gint64
@@ -965,8 +997,8 @@ ogmrip_container_get_subp_overhead (OGMRipContainer *container, OGMRipContainerC
 static gint64
 ogmrip_container_get_file_overhead (OGMRipContainer *container, OGMRipFile *file)
 {
-  glong length;
-  gint samples_per_frame, sample_rate, overhead;
+  glong length, audio_frames;
+  gint samples_per_frame, sample_rate, channels, overhead;
 
   if (ogmrip_file_get_type (file) == OGMRIP_FILE_TYPE_SUBP)
     return 0;
@@ -974,9 +1006,16 @@ ogmrip_container_get_file_overhead (OGMRipContainer *container, OGMRipFile *file
   length = ogmrip_audio_file_get_length (OGMRIP_AUDIO_FILE (file));
   sample_rate = ogmrip_audio_file_get_sample_rate (OGMRIP_AUDIO_FILE (file));
   samples_per_frame = ogmrip_audio_file_get_samples_per_frame (OGMRIP_AUDIO_FILE (file));
+
+  channels = 1;
+  if (ogmrip_file_get_format (file) != OGMRIP_FORMAT_COPY)
+    channels = ogmrip_audio_file_get_channels (OGMRIP_AUDIO_FILE (file));
+
+  audio_frames = length * sample_rate * (channels + 1) / samples_per_frame;
+
   overhead = ogmrip_container_get_overhead (container);
 
-  return (gint64) length * sample_rate * overhead / (gdouble) samples_per_frame;
+  return (gint64) (audio_frames * overhead);
 }
 
 /**
@@ -993,15 +1032,10 @@ ogmrip_container_get_overhead_size (OGMRipContainer *container)
 {
   GSList *link;
   gint64 overhead = 0;
-  gdouble length;
 
   g_return_val_if_fail (OGMRIP_IS_CONTAINER (container), -1);
 
-  if (container->priv->video)
-  {
-    length = ogmrip_codec_get_length (OGMRIP_CODEC (container->priv->video), NULL);
-    overhead = (gint64) length * ogmrip_container_get_overhead (container);
-  }
+  overhead = ogmrip_container_get_video_overhead (container);
 
   for (link = container->priv->audio; link; link = link->next)
     overhead += ogmrip_container_get_audio_overhead (container, link->data);
