@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -35,7 +35,7 @@
 static gint ogmrip_dvdcpy_run (OGMJobSpawn *spawn);
 
 static gdouble
-ogmrip_dvdcpy_watch (OGMJobExec *exec, const gchar *buffer, OGMRipVideo *video)
+ogmrip_dvdcpy_watch (OGMJobExec *exec, const gchar *buffer, OGMRipVideoCodec *video)
 {
   guint bytes, total, percent;
 
