@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,7 +19,7 @@
 #ifndef __OGMRIP_DVDCPY_H__
 #define __OGMRIP_DVDCPY_H__
 
-#include <ogmrip-video.h>
+#include <ogmrip-video-codec.h>
 
 G_BEGIN_DECLS
 
@@ -30,14 +30,11 @@ G_BEGIN_DECLS
 #define OGMRIP_IS_DVDCPY_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_DVDCPY))
 
 typedef struct _OGMRipDvdCpy      OGMRipDvdCpy;
-typedef struct _OGMRipDvdCpyPriv  OGMRipDvdCpyPriv;
 typedef struct _OGMRipDvdCpyClass OGMRipDvdCpyClass;
 
 struct _OGMRipDvdCpy
 {
   OGMRipCodec parent_instance;
-
-  OGMRipDvdCpyPriv *priv;
 };
 
 struct _OGMRipDvdCpyClass
