@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -72,6 +72,7 @@ struct _OGMRipAudioFile
 
   gint  rate;
   gint  bitrate;
+  gint channels;
   gdouble length;
 };
 
@@ -415,7 +416,7 @@ ogmrip_audio_file_new (const gchar *filename, GError **error)
   gboolean is_video = FALSE;
 
   GError *tmp_error = NULL;
-  gint i, rate = -1, bitrate = -1, format = -1;
+  gint i, rate = -1, bitrate = -1, format = -1, channels = -1;
   gdouble length = -1.0;
 
   g_return_val_if_fail (filename != NULL, NULL);
@@ -455,6 +456,8 @@ ogmrip_audio_file_new (const gchar *filename, GError **error)
       rate = strtoul (lines[i] + 14, NULL, 10);
     else if (g_str_has_prefix (lines[i], "ID_LENGTH="))
       length = strtod (lines[i] + 10, NULL);
+    else if (g_str_has_prefix (lines[i], "ID_AUDIO_NCH="))
+      channels = strtoul (lines[i] + 13, NULL, 10);
     else if (g_str_has_prefix (lines[i], "ID_AUDIO_FORMAT="))
     {
       if (strncmp (lines[i] + 16, "vrbs", 4) == 0)
@@ -505,6 +508,13 @@ ogmrip_audio_file_new (const gchar *filename, GError **error)
     return NULL;
   }
 
+  if (channels < 0)
+  {
+    g_set_error (error, OGMRIP_FILE_ERROR, OGMRIP_FILE_ERROR_FORMAT,
+        _("Cannot get number of channels of file '%s'"), filename);
+    return NULL;
+  }
+
   if (is_video)
   {
     g_set_error (error, OGMRIP_FILE_ERROR, OGMRIP_FILE_ERROR_FORMAT,
@@ -560,6 +570,7 @@ ogmrip_audio_file_new (const gchar *filename, GError **error)
   audio->rate = rate;
   audio->length = length;
   audio->bitrate = bitrate;
+  audio->channels = channels;
 
   return OGMRIP_FILE (audio);
 }
@@ -628,15 +639,31 @@ ogmrip_audio_file_get_samples_per_frame (OGMRipAudioFile *audio)
   switch (audio->file.format)
   {
     case OGMRIP_FORMAT_MP3:
-      return 576;
+      return 1152;
       break;
     case OGMRIP_FORMAT_AC3:
     case OGMRIP_FORMAT_DTS:
-      return 768;
+      return 1536;
       break;
   }
 
-  return 512;
+  return 1024;
+}
+
+/**
+ * ogmrip_audio_file_get_channels:
+ * @audio: An #OGMRipAudioFile
+ *
+ * Gets the number of channels of an audio file.
+ *
+ * Returns: an #OGMDvdAudioChannels, or -1
+ */
+gint
+ogmrip_audio_file_get_channels (OGMRipAudioFile *audio)
+{
+  g_return_val_if_fail (audio != NULL, -1);
+
+  return audio->channels - 1;
 }
 
 static OGMRipSubpFile *
@@ -916,6 +943,10 @@ ogmrip_video_file_new (const gchar *filename, GError **error)
         format = OGMRIP_FORMAT_H264;
       else if (strncmp (lines[i] + 16, "theo", 4) == 0)
         format = OGMRIP_FORMAT_THEORA;
+      else if (strncmp (lines[i] + 16, "0x10000001", 10) == 0)
+        format = OGMRIP_FORMAT_MPEG1;
+      else if (strncmp (lines[i] + 16, "0x10000002", 10) == 0)
+        format = OGMRIP_FORMAT_MPEG2;
     }
 
     if (errno != 0)
