@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -44,24 +44,6 @@
 
 static gchar *ogmrip_tmp_dir = NULL;
 
-/**
- * OGMRIP_FS_ERROR:
- *
- * Error domain for fs operations. Errors in this domain will be from the
- * #OGMRipFsError enumeration. See #GError for information on error domains.
- */
-
-GQuark
-ogmrip_fs_error_quark (void)
-{
-  static GQuark quark = 0;
-
-  if (quark == 0)
-    quark = g_quark_from_static_string ("ogmrip-fs-error-quark");
-
-  return quark;
-}
-
 /**
  * ogmrip_fs_get_tmp_dir:
  *
@@ -103,7 +85,7 @@ ogmrip_fs_set_tmp_dir (const gchar *dir)
  * ogmrip_fs_mkdir:
  * @path: A path of directories
  * @mode: The file mode
- * @error: A location to return an error of type #OGMRIP_FS_ERROR
+ * @error: A location to return an error of type #G_FILE_ERROR
  *
  * Create the all the directories in @path, if they do not already exist.
  *
@@ -112,32 +94,16 @@ ogmrip_fs_set_tmp_dir (const gchar *dir)
 gboolean
 ogmrip_fs_mkdir (const gchar *path, mode_t mode, GError **error)
 {
-  const gchar *sep;
-  gchar *current;
-
   g_return_val_if_fail (path && *path, FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-  for (sep = path; *sep; sep ++)
+  if (g_mkdir_with_parents (path, mode) < 0)
   {
-    for (; *sep; sep ++)
-      if (*sep == G_DIR_SEPARATOR)
-        break;
-
-    if (sep - path > 0)
-    {
-      current = g_strndup (path, sep - path);
-
-      if (g_mkdir (current, mode) < 0)
-      {
-        g_set_error (error, OGMRIP_FS_ERROR, OGMRIP_FS_ERROR_INTERNAL, 
-            _("Could not create directory %s: %s"), path, g_strerror (errno));
-        g_free (current);
-        return FALSE;
-      }
-      g_free (current);
-    }
+    g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno),
+        _("Failed to create directory '%s': %s"), path, g_strerror (errno));
+    return FALSE;
   }
+
   return TRUE;
 }
 
@@ -158,11 +124,6 @@ ogmrip_fs_rmdir (const gchar *path, gboolean recursive, GError **error)
   g_return_val_if_fail (path && *path, FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-  if (!g_file_test (path, G_FILE_TEST_EXISTS))
-    return TRUE;
-
-  g_return_val_if_fail (g_file_test (path, G_FILE_TEST_IS_DIR), FALSE);
-
   if (recursive)
   {
     GDir *dir;
@@ -195,6 +156,8 @@ ogmrip_fs_rmdir (const gchar *path, gboolean recursive, GError **error)
       {
         if (g_unlink (filename) != 0)
         {
+          g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno),
+              _("Failed to unlink file '%s': %s"), filename, g_strerror (errno));
           g_free (filename);
           return FALSE;
         }
@@ -206,7 +169,11 @@ ogmrip_fs_rmdir (const gchar *path, gboolean recursive, GError **error)
   }
 
   if (g_rmdir (path) != 0)
+  {
+    g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno),
+        _("Failed to remove directory '%s': %s"), path, g_strerror (errno));
     return FALSE;
+  }
 
   return TRUE;
 }
@@ -278,9 +245,9 @@ ogmrip_fs_mkftemp (const gchar *tmpl, GError **error)
 
   if (mkfifo (name, 0666) < 0)
   {
-    g_free (name);
     g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno), 
         _("Failed to create fifo '%s': %s"), name, g_strerror (errno));
+    g_free (name);
     return NULL;
   }
 
@@ -309,8 +276,8 @@ ogmrip_fs_mkdtemp (const gchar *tmpl, GError **error)
 
   if (!mkdtemp (path))
   {
-    g_set_error (error, OGMRIP_FS_ERROR, OGMRIP_FS_ERROR_INTERNAL, 
-        _("Could not create directory %s: %s"), path, g_strerror (errno));
+    g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno), 
+        _("Failed to create directory '%s': %s"), path, g_strerror (errno));
     g_free (path);
     return NULL;
   }
@@ -436,13 +403,14 @@ ogmrip_fs_open_tmp (const gchar *tmpl, gchar **name_used, GError **error)
 /**
  * ogmrip_fs_get_left_space:
  * @filename: A path to a filename
+ * @error: A location to return an error of type #G_FILE_ERROR
  *
  * Returns the space left in bytes on the device containing @filename.
  *
  * Returns: The space left in bytes, or -1
  */
 gint64
-ogmrip_fs_get_left_space (const gchar *filename)
+ogmrip_fs_get_left_space (const gchar *filename, GError **error)
 {
   gint status;
   gchar *dirname;
@@ -453,18 +421,19 @@ ogmrip_fs_get_left_space (const gchar *filename)
 #endif
 
   g_return_val_if_fail (filename && *filename, -1);
+  g_return_val_if_fail (error == NULL || *error == NULL, -1);
 
   if (g_file_test (filename, G_FILE_TEST_IS_DIR))
     dirname = g_strdup (filename);
   else
     dirname = g_path_get_dirname (filename);
-
+/*
   if (!g_file_test (dirname, G_FILE_TEST_EXISTS))
   {
     g_free (dirname);
     return -1;
   }
-
+*/
 #ifdef HAVE_STATVFS
   status = statvfs (dirname, &statfs_buf);
 #else
@@ -474,10 +443,14 @@ ogmrip_fs_get_left_space (const gchar *filename)
   g_free (dirname);
 
   if (status < 0)
+  {
+    g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno),
+	_("Failed to stat the file system containing '%s': %s"), dirname, g_strerror (errno));
     return -1;
+  }
 
 #ifdef G_ENABLE_DEBUG
-  ogmjob_log_printf ("Space left on device containing '%s': %" G_GINT64_FORMAT " bytes", 
+  ogmjob_log_printf ("Space left on device containing '%s': %" G_GINT64_FORMAT " bytes\n", 
       filename, (gint64) statfs_buf.f_bsize * (gint64) statfs_buf.f_bavail);
 #endif
 
@@ -487,45 +460,63 @@ ogmrip_fs_get_left_space (const gchar *filename)
 /**
  * ogmrip_fs_get_mount_point:
  * @filename: A path to a filename
+ * @error: A location to return an error of type #G_FILE_ERROR
  *
  * Returns the mount point of the device containing @filename.
  *
  * Returns: The moint point, or NULL
  */
 gchar *
-ogmrip_fs_get_mount_point (const gchar *filename)
+ogmrip_fs_get_mount_point (const gchar *filename, GError **error)
 {
-  gchar *cwd, *dirname, *mp = NULL;
+  gchar *dirname, *cwd = NULL, *mp = NULL;
   struct stat cur_stat, last_stat;
 
   g_return_val_if_fail (filename && *filename, NULL);
-
-  cwd = g_get_current_dir ();
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
   if (g_file_test (filename, G_FILE_TEST_IS_DIR))
     dirname = g_strdup (filename);
   else
     dirname = g_path_get_dirname (filename);
-
+/*
   if (!g_file_test (dirname, G_FILE_TEST_EXISTS))
     goto done;
-
+*/
   if (g_stat (dirname, &last_stat) < 0)
+  {
+    g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno), 
+        _("Failed to stat '%s': %s"), dirname, g_strerror (errno));
     goto done;
+  }
 
   if (g_chdir (dirname) < 0)
+  {
+    g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno), 
+        _("Failed to change to directory '%s': %s"), dirname, g_strerror (errno));
     goto done;
+  }
+
+  cwd = g_get_current_dir ();
 
   for (;;)
   {
     if (g_stat ("..", &cur_stat) < 0)
+    {
+      g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno), 
+	  _("Failed to stat '..': %s"), g_strerror (errno));
       goto done;
+    }
 
     if (cur_stat.st_dev != last_stat.st_dev || cur_stat.st_ino == last_stat.st_ino)
       break;
 
     if (g_chdir ("..") < 0)
+    {
+      g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno), 
+	  _("Failed to change to directory '..': %s"), g_strerror (errno));
       goto done;
+    }
 
     last_stat = cur_stat;
   }
@@ -533,8 +524,11 @@ ogmrip_fs_get_mount_point (const gchar *filename)
   mp = g_get_current_dir ();
 
 done:
-  g_chdir (cwd);
-  g_free (cwd);
+  if (cwd)
+  {
+    g_chdir (cwd);
+    g_free (cwd);
+  }
   g_free (dirname);
 
   return mp;
@@ -599,6 +593,14 @@ ogmrip_fs_rename (const gchar *old_name, const gchar *new_name, GError **error)
   return TRUE;
 }
 
+/**
+ * ogmrip_fs_get_extension:
+ * @filename: The path to an existing filename
+ *
+ * Returns the extension of @filename.
+ * 
+ * Returns: The extension, or NULL
+ */
 G_CONST_RETURN gchar *
 ogmrip_fs_get_extension (const gchar *filename)
 {
