@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,27 +26,10 @@
 
 G_BEGIN_DECLS
 
-#define OGMRIP_FS_ERROR ogmrip_fs_error_quark ()
-
 #if ! GLIB_CHECK_VERSION(2,8,0)
 #define g_chdir chdir
 #endif
 
-/**
- * OGMRipFsError:
- * @OGMRIP_FS_ERROR_NONE: No error
- * @OGMRIP_FS_ERROR_INTERNAL: Unknown error
- *
- * Error codes returned by OGMRipFs functions.
- */
-typedef enum
-{
-  OGMRIP_FS_ERROR_NONE,
-  OGMRIP_FS_ERROR_INTERNAL
-} OGMRipFsError;
-
-GQuark   ogmrip_fs_error_quark      (void);
-
 G_CONST_RETURN
 gchar *  ogmrip_fs_get_tmp_dir      (void);
 void     ogmrip_fs_set_tmp_dir      (const gchar  *dir);
@@ -73,8 +56,10 @@ gint     ogmrip_fs_open_tmp         (const gchar  *tmpl,
                                      gchar        **name_used,
                                      GError       **error);
 
-gint64   ogmrip_fs_get_left_space   (const gchar  *filename);
-gchar *  ogmrip_fs_get_mount_point  (const gchar  *filename);
+gint64   ogmrip_fs_get_left_space   (const gchar  *filename,
+                                     GError       **error);
+gchar *  ogmrip_fs_get_mount_point  (const gchar  *filename,
+                                     GError       **error);
 
 
 void     ogmrip_fs_unref            (gchar        *filename,
