@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,20 +20,25 @@
 #include "config.h"
 #endif
 
+#include "ogmrip-fs.h"
 #include "ogmrip-mkv.h"
 #include "ogmrip-version.h"
 #include "ogmrip-plugin.h"
 #include "ogmjob-exec.h"
 
-#include <string.h>
 #include <stdio.h>
+#include <string.h>
+#include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#define PROGRAM "mkvmerge"
 #define MKV_OVERHEAD 4
 
 static gint ogmrip_matroska_run          (OGMJobSpawn     *spawn);
 static gint ogmrip_matroska_get_overhead (OGMRipContainer *container);
 
+static gint major_version = 0;
+
 static gdouble
 ogmrip_matroska_watch (OGMJobExec *exec, const gchar *buffer, OGMRipContainer *matroska)
 {
@@ -56,15 +61,18 @@ ogmrip_matroska_get_sync (OGMRipContainer *container)
   start_delay = ogmrip_container_get_start_delay (container);
   if (start_delay > 0)
   {
-    OGMDvdTitle *title;
-    OGMRipVideo *video;
+    OGMRipVideoCodec *video;
     guint num, denom;
     gchar *buf;
 
     video = ogmrip_container_get_video (container);
-
-    title = ogmrip_codec_get_input (OGMRIP_CODEC (video));
-    ogmdvd_title_get_framerate (title, &num, &denom);
+    if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)) || ogmrip_codec_get_progressive (OGMRIP_CODEC (video)))
+    {
+      num = 24000;
+      denom = 1001;
+    }
+    else
+      ogmrip_codec_get_framerate (OGMRIP_CODEC (video), &num, &denom);
 
     buf = g_new0 (gchar, G_ASCII_DTOSTR_BUF_SIZE);
     g_ascii_formatd (buf, G_ASCII_DTOSTR_BUF_SIZE, "%.0f", (start_delay * denom * 1000) / (gdouble) num);
@@ -79,79 +87,124 @@ static void
 ogmrip_matroska_append_audio_file (OGMRipContainer *matroska,
     const gchar *filename, gint language, GPtrArray *argv)
 {
-  gchar *sync;
+  struct stat buf;
 
-  if (language > -1)
+  if (g_stat (filename, &buf) == 0 && buf.st_size > 0)
   {
-    const gchar *iso639_2;
+    gchar *sync;
 
-    iso639_2 = ogmdvd_get_language_iso639_2 (language);
-    if (iso639_2)
+    if (language > -1)
     {
-      g_ptr_array_add (argv, g_strdup ("--language"));
-      g_ptr_array_add (argv, g_strconcat ("0:", iso639_2, NULL));
-#if MPLAYER_CHECK_VERSION(1,0,0,8)
-      g_ptr_array_add (argv, g_strdup ("--language"));
-      g_ptr_array_add (argv, g_strconcat ("1:", iso639_2, NULL));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
+      const gchar *iso639_2;
+
+      iso639_2 = ogmdvd_get_language_iso639_2 (language);
+      if (iso639_2)
+      {
+        g_ptr_array_add (argv, g_strdup ("--language"));
+        g_ptr_array_add (argv, g_strconcat ("0:", iso639_2, NULL));
+        if (MPLAYER_CHECK_VERSION (1,0,0,8))
+        {
+          g_ptr_array_add (argv, g_strdup ("--language"));
+          g_ptr_array_add (argv, g_strconcat ("1:", iso639_2, NULL));
+        }
+      }
     }
+
+    sync = ogmrip_matroska_get_sync (matroska);
+    if (sync)
+    {
+      g_ptr_array_add (argv, g_strdup ("--sync"));
+      g_ptr_array_add (argv, g_strdup_printf ("0:%s", sync));
+      g_free (sync);
+    }
+
+    g_ptr_array_add (argv, g_strdup ("-D"));
+    g_ptr_array_add (argv, g_strdup ("-S"));
+
+    g_ptr_array_add (argv, g_strdup (filename));
   }
-
-  sync = ogmrip_matroska_get_sync (matroska);
-  if (sync)
-  {
-    g_ptr_array_add (argv, g_strdup ("--sync"));
-    g_ptr_array_add (argv, g_strdup_printf ("0:%s", sync));
-    g_free (sync);
-  }
-
-  g_ptr_array_add (argv, g_strdup ("-D"));
-  g_ptr_array_add (argv, g_strdup ("-S"));
-
-  g_ptr_array_add (argv, g_strdup (filename));
 }
 
 static void
 ogmrip_matroska_append_subp_file (OGMRipContainer *matroska, const gchar *filename,
     gint demuxer, gint charset, gint language, GPtrArray *argv)
 {
-  if (language > -1)
-  {
-    const gchar *iso639_2;
+  gchar *real_filename;
+  gboolean do_merge;
+  struct stat buf;
 
-    iso639_2 = ogmdvd_get_language_iso639_2 (language);
-    if (iso639_2)
+  if (demuxer == OGMRIP_SUBP_DEMUXER_VOBSUB)
+  {
+    if (!g_str_has_suffix (filename, ".idx"))
     {
-      g_ptr_array_add (argv, g_strdup ("--language"));
-      g_ptr_array_add (argv, g_strconcat ("0:", iso639_2, NULL));
+      real_filename = g_strconcat (filename, ".sub", NULL);
+      do_merge = (g_stat (real_filename, &buf) == 0 && buf.st_size != 0);
+
+      if (do_merge)
+      {
+        g_free (real_filename);
+        real_filename = g_strconcat (filename, ".idx", NULL);
+        do_merge = (g_stat (real_filename, &buf) == 0 && buf.st_size != 0);
+      }
+    }
+    else
+    {
+      real_filename = ogmrip_fs_set_extension (filename, "sub");
+      do_merge = (g_stat (real_filename, &buf) == 0 && buf.st_size != 0);
+
+      if (do_merge)
+      {
+        g_free (real_filename);
+        real_filename = g_strdup (filename);
+        do_merge = (g_stat (real_filename, &buf) == 0 && buf.st_size != 0);
+      }
     }
   }
-
-  switch (charset)
+  else
   {
-    case OGMRIP_CHARSET_UTF8:
-      g_ptr_array_add (argv, g_strdup ("--sub-charset"));
-      g_ptr_array_add (argv, g_strdup ("0:UTF-8"));
-      break;
-    case OGMRIP_CHARSET_ISO8859_1:
-      g_ptr_array_add (argv, g_strdup ("--sub-charset"));
-      g_ptr_array_add (argv, g_strdup ("0:ISO-8859-1"));
-      break;
-    case OGMRIP_CHARSET_ASCII:
-      g_ptr_array_add (argv, g_strdup ("--sub-charset"));
-      g_ptr_array_add (argv, g_strdup ("0:ASCII"));
-      break;
+    real_filename = g_strdup (filename);
+    do_merge = (g_stat (real_filename, &buf) == 0 && buf.st_size != 0);
   }
 
-  g_ptr_array_add (argv, g_strdup ("-s"));
-  g_ptr_array_add (argv, g_strdup ("0"));
-  g_ptr_array_add (argv, g_strdup ("-D"));
-  g_ptr_array_add (argv, g_strdup ("-A"));
-
-  if (demuxer == OGMRIP_SUBP_DEMUXER_VOBSUB && !g_str_has_suffix (filename, ".idx"))
-    g_ptr_array_add (argv, g_strconcat (filename, ".idx", NULL));
+  if (!do_merge)
+    g_free (real_filename);
   else
-    g_ptr_array_add (argv, g_strdup (filename));
+  {
+    if (language > -1)
+    {
+      const gchar *iso639_2;
+
+      iso639_2 = ogmdvd_get_language_iso639_2 (language);
+      if (iso639_2)
+      {
+        g_ptr_array_add (argv, g_strdup ("--language"));
+        g_ptr_array_add (argv, g_strconcat ("0:", iso639_2, NULL));
+      }
+    }
+
+    switch (charset)
+    {
+      case OGMRIP_CHARSET_UTF8:
+        g_ptr_array_add (argv, g_strdup ("--sub-charset"));
+        g_ptr_array_add (argv, g_strdup ("0:UTF-8"));
+        break;
+      case OGMRIP_CHARSET_ISO8859_1:
+        g_ptr_array_add (argv, g_strdup ("--sub-charset"));
+        g_ptr_array_add (argv, g_strdup ("0:ISO-8859-1"));
+        break;
+      case OGMRIP_CHARSET_ASCII:
+        g_ptr_array_add (argv, g_strdup ("--sub-charset"));
+        g_ptr_array_add (argv, g_strdup ("0:ASCII"));
+        break;
+    }
+
+    g_ptr_array_add (argv, g_strdup ("-s"));
+    g_ptr_array_add (argv, g_strdup ("0"));
+    g_ptr_array_add (argv, g_strdup ("-D"));
+    g_ptr_array_add (argv, g_strdup ("-A"));
+
+    g_ptr_array_add (argv, real_filename);
+  }
 }
 
 static void
@@ -172,7 +225,7 @@ ogmrip_matroska_foreach_subp (OGMRipContainer *matroska,
   gint charset;
 
   input = ogmrip_codec_get_output (codec);
-  charset = ogmrip_subp_get_charset (OGMRIP_SUBP (codec));
+  charset = ogmrip_subp_codec_get_charset (OGMRIP_SUBP_CODEC (codec));
   ogmrip_matroska_append_subp_file (matroska, input, demuxer, charset, language, argv);
 }
 
@@ -181,25 +234,29 @@ ogmrip_matroska_foreach_chapters (OGMRipContainer *matroska,
     OGMRipCodec *codec, guint demuxer, gint language, GPtrArray *argv)
 {
   const gchar *input;
-
-  if (language > -1)
-  {
-    const gchar *iso639_2;
-
-    iso639_2 = ogmdvd_get_language_iso639_2 (language);
-    if (iso639_2)
-    {
-      g_ptr_array_add (argv, g_strdup ("--chapter-language"));
-      g_ptr_array_add (argv, g_strdup (iso639_2));
-    }
-  }
-
-  g_ptr_array_add (argv, g_strdup ("--chapter-charset"));
-  g_ptr_array_add (argv, g_strdup ("UTF-8"));
-  g_ptr_array_add (argv, g_strdup ("--chapters"));
+  struct stat buf;
 
   input = ogmrip_codec_get_output (codec);
-  g_ptr_array_add (argv, g_strdup (input));
+  if (g_stat (input, &buf) == 0 && buf.st_size > 0)
+  {
+    if (language > -1)
+    {
+      const gchar *iso639_2;
+
+      iso639_2 = ogmdvd_get_language_iso639_2 (language);
+      if (iso639_2)
+      {
+        g_ptr_array_add (argv, g_strdup ("--chapter-language"));
+        g_ptr_array_add (argv, g_strdup (iso639_2));
+      }
+    }
+
+    g_ptr_array_add (argv, g_strdup ("--chapter-charset"));
+    g_ptr_array_add (argv, g_strdup ("UTF-8"));
+    g_ptr_array_add (argv, g_strdup ("--chapters"));
+
+    g_ptr_array_add (argv, g_strdup (input));
+  }
 }
 
 static void
@@ -235,14 +292,14 @@ gchar **
 ogmrip_matroska_command (OGMRipContainer *matroska)
 {
   GPtrArray *argv;
-  OGMRipVideo *video;
+  OGMRipVideoCodec *video;
   const gchar *output, *label, *filename, *fourcc;
   guint tsize, tnumber;
 
   g_return_val_if_fail (OGMRIP_IS_MATROSKA (matroska), NULL);
 
   argv = g_ptr_array_new ();
-  g_ptr_array_add (argv, g_strdup ("mkvmerge"));
+  g_ptr_array_add (argv, g_strdup (PROGRAM));
 
   output = ogmrip_container_get_output (matroska);
   g_ptr_array_add (argv, g_strdup ("-o"));
@@ -255,18 +312,22 @@ ogmrip_matroska_command (OGMRipContainer *matroska)
     g_ptr_array_add (argv, g_strconcat ("0:", fourcc, NULL));
   }
 
-#if defined(HAVE_X264_SUPPORT) && MKVMERGE_MAJOR_VERSION < 2
-  /*
-   * Option to merge h264 streams
-   */
-  g_ptr_array_add (argv, g_strdup ("--engage"));
-  g_ptr_array_add (argv, g_strdup ("allow_avc_in_vfw_mode"));
-#endif /* HAVE_X264_SUPPORT */
+  video = ogmrip_container_get_video (matroska);
+  if (major_version == 1)
+  {
+    if (ogmrip_plugin_get_video_codec_format (G_TYPE_FROM_INSTANCE (video)) == OGMRIP_FORMAT_H264)
+    {
+      /*
+       * Option to merge h264 streams
+       */
+      g_ptr_array_add (argv, g_strdup ("--engage"));
+      g_ptr_array_add (argv, g_strdup ("allow_avc_in_vfw_mode"));
+    }
+  }
 
   g_ptr_array_add (argv, g_strdup ("--command-line-charset"));
   g_ptr_array_add (argv, g_strdup ("UTF-8"));
 
-  video = ogmrip_container_get_video (matroska);
   filename = ogmrip_codec_get_output (OGMRIP_CODEC (video));
 
   g_ptr_array_add (argv, g_strdup ("-d"));
@@ -374,7 +435,7 @@ ogmrip_matroska_new (const gchar *output)
   return g_object_new (OGMRIP_TYPE_MATROSKA, "output", output, NULL);
 }
 
-static OGMRipPluginContainer mkv_plugin =
+static OGMRipContainerPlugin mkv_plugin =
 {
   NULL,
   G_TYPE_NONE,
@@ -388,6 +449,8 @@ static OGMRipPluginContainer mkv_plugin =
 
 static gint formats[] =
 {
+  OGMRIP_FORMAT_MPEG1,
+  OGMRIP_FORMAT_MPEG2,
   OGMRIP_FORMAT_MPEG4,
   OGMRIP_FORMAT_H264,
   OGMRIP_FORMAT_THEORA,
@@ -404,9 +467,17 @@ static gint formats[] =
   -1
 };
 
-OGMRipPluginContainer *
+OGMRipContainerPlugin *
 ogmrip_init_plugin (void)
 {
+  gchar *output;
+
+  if (!g_spawn_command_line_sync ("mkvmerge --version", &output, NULL, NULL, NULL))
+    return NULL;
+
+  if (strncmp (output, "mkvmerge v1", 11) == 0)
+    major_version = 1;
+
   mkv_plugin.type = OGMRIP_TYPE_MATROSKA;
   mkv_plugin.formats = formats;
 
