@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,7 @@
 
 #include "ogmrip-mov.h"
 #include "ogmrip-mplayer.h"
+#include "ogmrip-version.h"
 #include "ogmrip-plugin.h"
 #include "ogmjob-exec.h"
 
@@ -34,7 +35,7 @@ gchar **
 ogmrip_mov_command (OGMRipContainer *mov)
 {
   GPtrArray *argv;
-  OGMRipVideo *video;
+  OGMRipVideoCodec *video;
   const gchar *output, *filename;
 
   g_return_val_if_fail (OGMRIP_IS_MOV (mov), NULL);
@@ -44,7 +45,11 @@ ogmrip_mov_command (OGMRipContainer *mov)
   g_ptr_array_add (argv, g_strdup ("-of"));
   g_ptr_array_add (argv, g_strdup ("lavf"));
   g_ptr_array_add (argv, g_strdup ("-lavfopts"));
-  g_ptr_array_add (argv, g_strdup ("format=mov:i_certify_that_my_video_stream_does_not_use_b_frames"));
+
+  if (MPLAYER_CHECK_VERSION (1,0,2,0))
+    g_ptr_array_add (argv, g_strdup ("format=mov"));
+  else
+    g_ptr_array_add (argv, g_strdup ("format=mov:i_certify_that_my_video_stream_does_not_use_b_frames"));
 
   output = ogmrip_container_get_output (mov);
   g_ptr_array_add (argv, g_strdup ("-o"));
@@ -117,7 +122,7 @@ ogmrip_mov_new (const gchar *output)
   return g_object_new (OGMRIP_TYPE_MOV, "output", output, NULL);
 }
 
-static OGMRipPluginContainer mov_plugin =
+static OGMRipContainerPlugin mov_plugin =
 {
   NULL,
   G_TYPE_NONE,
@@ -146,9 +151,21 @@ static gint formats[] =
   -1
 };
 
-OGMRipPluginContainer *
+OGMRipContainerPlugin *
 ogmrip_init_plugin (void)
 {
+  gchar *output;
+  gboolean match;
+
+  if (!g_spawn_command_line_sync ("mencoder -of help", &output, NULL, NULL, NULL))
+    return NULL;
+
+  match = g_regex_match_simple ("^ *lavf *- .*$", output, G_REGEX_MULTILINE, 0);
+  g_free (output);
+
+  if (!match)
+    return NULL;
+
   mov_plugin.type = OGMRIP_TYPE_MOV;
   mov_plugin.formats = formats;
 
