@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,10 +31,13 @@ G_BEGIN_DECLS
 
 typedef struct _OGMRipMp4      OGMRipMp4;
 typedef struct _OGMRipMp4Class OGMRipMp4Class;
+typedef struct _OGMRipMp4Priv  OGMRipMp4Priv;
 
 struct _OGMRipMp4
 {
   OGMRipContainer parent_instance;
+
+  OGMRipMp4Priv *priv;
 };
 
 struct _OGMRipMp4Class
