@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,6 +16,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
+/**
+ * SECTION:ogmrip-mplayer
+ * @title: Mplayer
+ * @short_description: Common wrapper functions for mplayer and mencoder
+ * @include: ogmrip-mplayer.h
+ */
+
 #include "ogmrip-mplayer.h"
 #include "ogmrip-version.h"
 #include "ogmrip-plugin.h"
@@ -27,6 +34,8 @@
 #include <string.h>
 #include <unistd.h>
 
+#include <glib/gstdio.h>
+
 // static const gchar *deinterlacer[] = { "lb", "li", "ci", "md", "fd", "l5", "kerndeint", "yadif=3,mcdeint=2:1:10" };
 static const gchar *deinterlacer[] = { "lb", "li", "ci", "md", "fd", "l5", "kerndeint", "yadif=0" };
 
@@ -35,7 +44,7 @@ ogmrip_mplayer_map_audio_id (OGMDvdAudioStream *astream)
 {
   gint aid;
 
-  aid = ogmdvd_stream_get_nr (OGMDVD_STREAM (astream));
+  aid = ogmdvd_stream_get_id (OGMDVD_STREAM (astream));
 
   switch (ogmdvd_audio_stream_get_format (astream))
   {
@@ -63,7 +72,7 @@ ogmrip_mplayer_get_output_fps (OGMRipCodec *codec, OGMDvdTitle *title)
   guint output_rate_numerator, output_rate_denominator;
   gint step;
 
-  if (OGMRIP_IS_VIDEO (codec) && ogmrip_video_get_pullup (OGMRIP_VIDEO (codec)))
+  if (ogmrip_codec_get_telecine (codec) || ogmrip_codec_get_progressive (codec))
   {
     output_rate_numerator = 24000;
     output_rate_denominator = 1001;
@@ -149,6 +158,17 @@ ogmrip_mplayer_audio_file_get_demuxer (OGMRipAudioFile *audio)
   return demuxer;
 }
 
+/**
+ * ogmrip_mencoder_codec_watch:
+ * @exec: An #OGMJobExec
+ * @buffer: The buffer to parse
+ * @codec: An #OGMRipCodec
+ *
+ * This function parses the output of mencoder when encoding a stream and
+ * returns the progress made.
+ *
+ * Returns: The progress made, or -1.0
+ */
 gdouble
 ogmrip_mencoder_codec_watch (OGMJobExec *exec, const gchar *buffer, OGMRipCodec *codec)
 {
@@ -165,6 +185,17 @@ ogmrip_mencoder_codec_watch (OGMJobExec *exec, const gchar *buffer, OGMRipCodec
   return -1.0;
 }
 
+/**
+ * ogmrip_mencoder_container_watch:
+ * @exec: An #OGMJobExec
+ * @buffer: The buffer to parse
+ * @container: An #OGMRipContainer
+ *
+ * This function parses the output of mencoder when merging streams and returns
+ * the progress made.
+ *
+ * Returns: The progress made, or -1.0
+ */
 gdouble
 ogmrip_mencoder_container_watch (OGMJobExec *exec, const gchar *buffer, OGMRipContainer *container)
 {
@@ -177,8 +208,19 @@ ogmrip_mencoder_container_watch (OGMJobExec *exec, const gchar *buffer, OGMRipCo
   return -1.0;
 }
 
+/**
+ * ogmrip_mplayer_wav_command:
+ * @audio: An #OGMRipAudioCodec
+ * @header: Whether to add the PCM header
+ * @output: The output file, or NULL
+ *
+ * This function creates the command line for encoding an audio stream in PCM
+ * or WAV.
+ *
+ * Returns: A new #GPtrArray, or NULL
+ */
 GPtrArray *
-ogmrip_mplayer_wav_command (OGMRipAudio *audio, gboolean header, const gchar *input, const gchar *output)
+ogmrip_mplayer_wav_command (OGMRipAudioCodec *audio, gboolean header, const gchar *output)
 {
   OGMDvdTitle *title;
   OGMDvdAudioStream *astream;
@@ -188,13 +230,9 @@ ogmrip_mplayer_wav_command (OGMRipAudio *audio, gboolean header, const gchar *in
 
   const gchar *device;
   gchar *chap, *ofps;
-  gint vid, aid;
+  gint vid;
 
-#if MPLAYER_CHECK_VERSION(1,0,0,6)
-  gint srate;
-#endif /* MPLAYER_CHECK_VERSION */
-
-  g_return_val_if_fail (OGMRIP_IS_AUDIO (audio), NULL);
+  g_return_val_if_fail (OGMRIP_IS_AUDIO_CODEC (audio), NULL);
 
   if (!output)
     output = ogmrip_codec_get_output (OGMRIP_CODEC (audio));
@@ -203,7 +241,7 @@ ogmrip_mplayer_wav_command (OGMRipAudio *audio, gboolean header, const gchar *in
   title = ogmrip_codec_get_input (OGMRIP_CODEC (audio));
   g_return_val_if_fail (title != NULL, NULL);
 
-  astream = ogmrip_audio_get_dvd_audio_stream (audio);
+  astream = ogmrip_audio_codec_get_dvd_audio_stream (audio);
   g_return_val_if_fail (astream != NULL, NULL);
 
   argv = g_ptr_array_new ();
@@ -212,6 +250,12 @@ ogmrip_mplayer_wav_command (OGMRipAudio *audio, gboolean header, const gchar *in
   g_ptr_array_add (argv, g_strdup ("-nocache"));
   g_ptr_array_add (argv, g_strdup ("-noframedrop"));
 
+  if (MPLAYER_CHECK_VERSION (1,0,3,0))
+  {
+    g_ptr_array_add (argv, g_strdup ("-noconfig"));
+    g_ptr_array_add (argv, g_strdup ("all"));
+  }
+
   ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (audio), title);
   if (ofps)
     g_free (ofps);
@@ -227,75 +271,80 @@ ogmrip_mplayer_wav_command (OGMRipAudio *audio, gboolean header, const gchar *in
   g_ptr_array_add (argv, g_strdup ("null"));
   g_ptr_array_add (argv, g_strdup ("-ao"));
 
-#if MPLAYER_CHECK_VERSION(1,0,0,8)
-  options = g_string_new ("pcm");
+  if (MPLAYER_CHECK_VERSION (1,0,0,8))
+  {
+    options = g_string_new ("pcm");
 
-  if (ogmrip_audio_get_fast (audio))
-    g_string_append (options, ":fast");
+    if (ogmrip_audio_codec_get_fast (audio))
+      g_string_append (options, ":fast");
 
-  if (header)
-    g_string_append (options, ":waveheader");
+    if (header)
+      g_string_append (options, ":waveheader");
+    else
+      g_string_append (options, ":nowaveheader");
+
+    g_string_append_printf (options, ":file=%s", output);
+
+    g_ptr_array_add (argv, g_string_free (options, FALSE));
+  }
+  else if (MPLAYER_CHECK_VERSION (1,0,0,7))
+  {
+    if (header)
+      g_ptr_array_add (argv, g_strdup_printf ("pcm:waveheader:file=%s", output));
+    else
+      g_ptr_array_add (argv, g_strdup_printf ("pcm:nowaveheader:file=%s", output));
+  }
   else
-    g_string_append (options, ":nowaveheader");
-
-  g_string_append_printf (options, ":file=%s", output);
-
-  g_ptr_array_add (argv, g_string_free (options, FALSE));
-#elif MPLAYER_CHECK_VERSION(1,0,0,7)
-  if (header)
-    g_ptr_array_add (argv, g_strdup_printf ("pcm:waveheader:file=%s", output));
-  else
-    g_ptr_array_add (argv, g_strdup_printf ("pcm:nowaveheader:file=%s", output));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,7) 7 */
-  g_ptr_array_add (argv, g_strdup ("pcm"));
-  if (header)
-    g_ptr_array_add (argv, g_strdup ("-waveheader"));
-  else
-    g_ptr_array_add (argv, g_strdup ("-nowaveheader"));
-  g_ptr_array_add (argv, g_strdup ("-aofile"));
-  g_ptr_array_add (argv, g_strdup (output));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
+  {
+    g_ptr_array_add (argv, g_strdup ("pcm"));
+    if (header)
+      g_ptr_array_add (argv, g_strdup ("-waveheader"));
+    else
+      g_ptr_array_add (argv, g_strdup ("-nowaveheader"));
+    g_ptr_array_add (argv, g_strdup ("-aofile"));
+    g_ptr_array_add (argv, g_strdup (output));
+  }
 
   options = g_string_new (NULL);
 
-  if (ogmrip_audio_get_normalize (audio))
+  if (ogmrip_audio_codec_get_normalize (audio))
   {
-#if MPLAYER_CHECK_VERSION(1,0,0,8)
-    g_string_append (options, "volnorm=1");
-#elif MPLAYER_CHECK_VERSION(1,0,0,6)
-    g_string_append (options, "volnorm");
-#else /* MPLAYER_CHECK_VERSION(1,0,0,6) */
-    g_string_append (options, "list=volnorm");
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
+    if (MPLAYER_CHECK_VERSION (1,0,0,8))
+      g_string_append (options, "volnorm=1");
+    else if (MPLAYER_CHECK_VERSION (1,0,0,6))
+      g_string_append (options, "volnorm");
+    else
+      g_string_append (options, "list=volnorm");
   }
 
-#if MPLAYER_CHECK_VERSION(1,0,0,6)
-  srate = ogmrip_audio_get_sample_rate (audio);
-  if (srate != 48000)
+  if (MPLAYER_CHECK_VERSION (1,0,0,6))
   {
-    g_ptr_array_add (argv, g_strdup ("-srate"));
-    g_ptr_array_add (argv, g_strdup_printf ("%d", srate));
+    gint srate = ogmrip_audio_codec_get_sample_rate (audio);
+    if (srate != 48000)
+    {
+      g_ptr_array_add (argv, g_strdup ("-srate"));
+      g_ptr_array_add (argv, g_strdup_printf ("%d", srate));
 
-    if (options->len > 0)
-      g_string_append_c (options, ',');
-    g_string_append_printf (options, "lavcresample=%d", srate);
+      if (options->len > 0)
+        g_string_append_c (options, ',');
+      g_string_append_printf (options, "lavcresample=%d", srate);
+    }
   }
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,6) */
 
   if (options->len == 0)
     g_string_free (options, TRUE);
   else
   {
-#if MPLAYER_CHECK_VERSION(1,0,0,6)
-    g_ptr_array_add (argv, g_strdup ("-af"));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,6) */
-    g_ptr_array_add (argv, g_strdup ("-aop"));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,6) */
+    if (MPLAYER_CHECK_VERSION (1,0,0,6))
+      g_ptr_array_add (argv, g_strdup ("-af"));
+    else
+      g_ptr_array_add (argv, g_strdup ("-aop"));
+
     g_ptr_array_add (argv, g_string_free (options, FALSE));
   }
 
   g_ptr_array_add (argv, g_strdup ("-channels"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_audio_get_channels (audio) + 1));
+  g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_audio_codec_get_channels (audio) + 1));
 
   chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (audio), title);
   if (chap)
@@ -306,7 +355,6 @@ ogmrip_mplayer_wav_command (OGMRipAudio *audio, gboolean header, const gchar *in
 
   ogmrip_mplayer_append_edl (OGMRIP_CODEC (audio), argv, FALSE);
 
-  aid = ogmdvd_stream_get_nr (OGMDVD_STREAM (astream));
   g_ptr_array_add (argv, g_strdup ("-aid"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_mplayer_map_audio_id (astream)));
 
@@ -316,18 +364,32 @@ ogmrip_mplayer_wav_command (OGMRipAudio *audio, gboolean header, const gchar *in
 
   vid = ogmdvd_title_get_nr (title);
 
-#if MPLAYER_CHECK_VERSION(1,0,0,1)
-  g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,1) */
-  g_ptr_array_add (argv, g_strdup ("-dvd"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,1) */
+  if (MPLAYER_CHECK_VERSION (1,0,0,1))
+    g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
+  else
+  {
+    g_ptr_array_add (argv, g_strdup ("-dvd"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
+  }
+
+  g_ptr_array_add (argv, NULL);
 
   return argv;
 }
 
+/**
+ * ogmrip_mplayer_wav_watch:
+ * @exec: An #OGMJobExec
+ * @buffer: The buffer to parse
+ * @audio: An #OGMRipAudioCodec
+ *
+ * This function parses the output of mplayer when encoding an audio stream in
+ * WAV or PCM and returns the progress made.
+ *
+ * Returns: The progress made, or -1.0
+ */
 gdouble
-ogmrip_mplayer_wav_watch (OGMJobExec *exec, const gchar *buffer, OGMRipAudio *audio)
+ogmrip_mplayer_wav_watch (OGMJobExec *exec, const gchar *buffer, OGMRipAudioCodec *audio)
 {
   gchar a[10], v[10], av[15], ct[15];
   gint frame, decoded;
@@ -338,21 +400,42 @@ ogmrip_mplayer_wav_watch (OGMJobExec *exec, const gchar *buffer, OGMRipAudio *au
   return -1.0;
 }
 
+/**
+ * ogmrip_mencoder_audio_command:
+ * @audio: An #OGMRipAudioCodec
+ * @output: The output file, or NULL
+ *
+ * This function creates the common part of the command line when using mencoder
+ * to encode an audio stream.
+ *
+ * Returns: A new #GPtrArray, or NULL
+ */
 GPtrArray *
-ogmrip_mencoder_audio_command (OGMRipAudio *audio, OGMDvdTitle *title, OGMDvdAudioStream *astream, const gchar *output)
+ogmrip_mencoder_audio_command (OGMRipAudioCodec *audio, const gchar *output)
 {
   GPtrArray *argv;
   const gchar *device;
   gchar *ofps, *chap;
-  gint vid, aid;
+  gint vid;
 
-  g_return_val_if_fail (OGMRIP_IS_AUDIO (audio), NULL);
+  OGMDvdTitle *title;
+  OGMDvdAudioStream *astream;
+
+  g_return_val_if_fail (OGMRIP_IS_AUDIO_CODEC (audio), NULL);
+
+  title = ogmrip_codec_get_input (OGMRIP_CODEC (audio));
 
   argv = g_ptr_array_new ();
 
   g_ptr_array_add (argv, g_strdup ("mencoder"));
   g_ptr_array_add (argv, g_strdup ("-nocache"));
 
+  if (MPLAYER_CHECK_VERSION (1,0,3,0))
+  {
+    g_ptr_array_add (argv, g_strdup ("-noconfig"));
+    g_ptr_array_add (argv, g_strdup ("all"));
+  }
+
   ofps = ogmrip_mplayer_get_output_fps (OGMRIP_CODEC (audio), title);
   if (ofps)
   {
@@ -374,8 +457,8 @@ ogmrip_mencoder_audio_command (OGMRipAudio *audio, OGMDvdTitle *title, OGMDvdAud
 
   ogmrip_mplayer_append_edl (OGMRIP_CODEC (audio), argv, TRUE);
 
-  aid = ogmdvd_stream_get_nr (OGMDVD_STREAM (astream));
   g_ptr_array_add (argv, g_strdup ("-aid"));
+  astream = ogmrip_audio_codec_get_dvd_audio_stream (audio);
   g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_mplayer_map_audio_id (astream)));
 
   g_ptr_array_add (argv, g_strdup ("-o"));
@@ -390,28 +473,49 @@ ogmrip_mencoder_audio_command (OGMRipAudio *audio, OGMDvdTitle *title, OGMDvdAud
   return argv;
 }
 
+/**
+ * ogmrip_mencoder_video_command:
+ * @video: An #OGMRipVideoCodec
+ * @output: The output file, or NULL
+ * @pass: The number of passes
+ *
+ * This function creates the common part of the command line when using mencoder
+ * to encode a video stream.
+ *
+ * Returns: A new #GPtrArray, or NULL
+ */
 GPtrArray *
-ogmrip_mencoder_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gchar *output)
+ogmrip_mencoder_video_command (OGMRipVideoCodec *video, const gchar *output, guint pass)
 {
   GPtrArray *argv;
+  OGMDvdTitle *title;
   OGMRipScalerType scaler;
   OGMRipDeintType deint;
   OGMDvdAudioStream *astream;
   GString *options, *pp;
 
   const gchar *device;
+  guint max_width, max_height;
   guint crop_x, crop_y, crop_width, crop_height;
   guint scale_width, scale_height;
-  gboolean crop, scale;
+  gboolean crop, scale, expand;
   gchar *ofps, *chap;
 
+  title = ogmrip_codec_get_input (OGMRIP_CODEC (video));
+
   argv = g_ptr_array_new ();
 
   g_ptr_array_add (argv, g_strdup ("mencoder"));
   g_ptr_array_add (argv, g_strdup ("-nocache"));
   g_ptr_array_add (argv, g_strdup ("-noslices"));
 
-  astream = ogmrip_video_get_ensure_sync (video);
+  if (MPLAYER_CHECK_VERSION (1,0,3,0))
+  {
+    g_ptr_array_add (argv, g_strdup ("-noconfig"));
+    g_ptr_array_add (argv, g_strdup ("all"));
+  }
+
+  astream = ogmrip_video_codec_get_ensure_sync (video);
   if (astream)
   {
     g_ptr_array_add (argv, g_strdup ("-oac"));
@@ -430,11 +534,11 @@ ogmrip_mencoder_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gch
   else
     g_ptr_array_add (argv, g_strdup ("-nosound"));
 
-  scaler = ogmrip_video_get_scaler (video);
+  scaler = ogmrip_video_codec_get_scaler (video);
   g_ptr_array_add (argv, g_strdup ("-sws"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", MAX (scaler, 0)));
 
-  scale = ogmrip_video_get_scale_size (video, &scale_width, &scale_height);
+  scale = ogmrip_video_codec_get_scale_size (video, &scale_width, &scale_height);
   g_ptr_array_add (argv, g_strdup (scale ? "-zoom": "-nozoom"));
 
   chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (video), title);
@@ -449,28 +553,28 @@ ogmrip_mencoder_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gch
   options = g_string_new (NULL);
   pp = g_string_new (NULL);
 
-  if (ogmrip_video_get_deblock (video))
+  if (ogmrip_video_codec_get_deblock (video))
   {
     if (pp->len > 0)
       g_string_append_c (pp, '/');
     g_string_append (pp, "ha/va");
   }
 
-  if (ogmrip_video_get_dering (video))
+  if (ogmrip_video_codec_get_dering (video))
   {
     if (pp->len > 0)
       g_string_append_c (pp, '/');
     g_string_append (pp, "dr");
   }
 
-  if (ogmrip_video_get_pullup (video))
+  if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)))
   {
     if (options->len > 0)
       g_string_append_c (options, ',');
     g_string_append (options, "pullup,softskip");
   }
 
-  crop = ogmrip_video_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height);
+  crop = ogmrip_video_codec_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height);
   if (crop)
   {
     if (options->len > 0)
@@ -478,7 +582,7 @@ ogmrip_mencoder_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gch
     g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
   }
 
-  deint = ogmrip_video_get_deinterlacer (video);
+  deint = ogmrip_video_codec_get_deinterlacer (video);
   if (deint != OGMRIP_DEINT_NONE)
   {
     if (deint == OGMRIP_DEINT_KERNEL || deint == OGMRIP_DEINT_YADIF)
@@ -510,7 +614,14 @@ ogmrip_mencoder_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gch
     g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
   }
 
-  if (ogmrip_video_get_denoise (video))
+  if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
+  {
+    if (options->len > 0)
+      g_string_append_c (options, ',');
+    g_string_append_printf (options, "expand=%u:%u", max_width, max_height);
+  }
+
+  if (ogmrip_video_codec_get_denoise (video))
   {
     if (options->len > 0)
       g_string_append_c (options, ',');
@@ -542,7 +653,7 @@ ogmrip_mencoder_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gch
   }
 
   g_ptr_array_add (argv, g_strdup ("-dvdangle"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_video_get_angle (video)));
+  g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_video_codec_get_angle (video)));
 
   g_ptr_array_add (argv, g_strdup ("-o"));
   g_ptr_array_add (argv, g_strdup (output));
@@ -554,8 +665,19 @@ ogmrip_mencoder_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gch
   return argv;
 }
 
+/**
+ * ogmrip_mplayer_video_watch:
+ * @exec: An #OGMJobExec
+ * @buffer: The buffer to parse
+ * @video: An #OGMRipVideoCodec
+ *
+ * This function parses the output of mplayer when encoding a video stream and
+ * returns the progress made.
+ *
+ * Returns: The progress made, or -1.0
+ */
 gdouble
-ogmrip_mplayer_video_watch (OGMJobExec *exec, const gchar *buffer, OGMRipVideo *video)
+ogmrip_mplayer_video_watch (OGMJobExec *exec, const gchar *buffer, OGMRipVideoCodec *video)
 {
   gchar v[10];
   gint frame, decoded;
@@ -566,26 +688,40 @@ ogmrip_mplayer_video_watch (OGMJobExec *exec, const gchar *buffer, OGMRipVideo *
   return -1.0;
 }
 
+/**
+ * ogmrip_mplayer_video_command:
+ * @video: An #OGMRipVideoCodec
+ * @output: The output file, or NULL
+ *
+ * This function creates the common part of the command line when using mplayer
+ * to encode a video stream.
+ *
+ * Returns: A new #GPtrArray, or NULL
+ */
 GPtrArray *
-ogmrip_mplayer_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gchar *output)
+ogmrip_mplayer_video_command (OGMRipVideoCodec *video, const gchar *output)
 {
+  OGMDvdTitle *title;
   OGMRipScalerType scaler;
   OGMRipDeintType deint;
   GString *options, *pp;
   GPtrArray *argv;
 
   const gchar *device;
-  gboolean crop, scale;
+  guint max_width, max_height;
   guint crop_x, crop_y, crop_width, crop_height;
   guint scale_width, scale_height;
+  gboolean crop, scale, expand;
   gchar *chap, *ofps;
 
-  g_return_val_if_fail (OGMRIP_IS_VIDEO (video), NULL);
+  g_return_val_if_fail (OGMRIP_IS_VIDEO_CODEC (video), NULL);
 
   if (!output)
     output = ogmrip_codec_get_output (OGMRIP_CODEC (video));
   g_return_val_if_fail (output != NULL, NULL);
 
+  title = ogmrip_codec_get_input (OGMRIP_CODEC (video));
+
   argv = g_ptr_array_new ();
 
   g_ptr_array_add (argv, g_strdup ("mplayer"));
@@ -595,38 +731,44 @@ ogmrip_mplayer_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gcha
   g_ptr_array_add (argv, g_strdup ("-nosound"));
   g_ptr_array_add (argv, g_strdup ("-noslices"));
 
-  scaler = ogmrip_video_get_scaler (video);
+  if (MPLAYER_CHECK_VERSION (1,0,3,0))
+  {
+    g_ptr_array_add (argv, g_strdup ("-noconfig"));
+    g_ptr_array_add (argv, g_strdup ("all"));
+  }
+
+  scaler = ogmrip_video_codec_get_scaler (video);
   g_ptr_array_add (argv, g_strdup ("-sws"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", MAX (scaler, 0)));
 
-  scale = ogmrip_video_get_scale_size (video, &scale_width, &scale_height);
+  scale = ogmrip_video_codec_get_scale_size (video, &scale_width, &scale_height);
   g_ptr_array_add (argv, g_strdup (scale ? "-zoom" : "-nozoom"));
 
   options = g_string_new (NULL);
   pp = g_string_new (NULL);
 
-  if (ogmrip_video_get_deblock (video))
+  if (ogmrip_video_codec_get_deblock (video))
   {
     if (pp->len > 0)
       g_string_append_c (pp, '/');
     g_string_append (pp, "ha/va");
   }
 
-  if (ogmrip_video_get_dering (video))
+  if (ogmrip_video_codec_get_dering (video))
   {
     if (pp->len > 0)
       g_string_append_c (pp, '/');
     g_string_append (pp, "dr");
   }
 
-  if (ogmrip_video_get_pullup (video))
+  if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)))
   {
     if (options->len > 0)
       g_string_append_c (options, ',');
     g_string_append (options, "pullup,softskip");
   }
 
-  crop = ogmrip_video_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height);
+  crop = ogmrip_video_codec_get_crop_size (video, &crop_x, &crop_y, &crop_width, &crop_height);
   if (crop)
   {
     if (options->len > 0)
@@ -634,7 +776,7 @@ ogmrip_mplayer_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gcha
     g_string_append_printf (options, "crop=%u:%u:%u:%u", crop_width, crop_height, crop_x, crop_y);
   }
 
-  deint = ogmrip_video_get_deinterlacer (video);
+  deint = ogmrip_video_codec_get_deinterlacer (video);
   if (deint != OGMRIP_DEINT_NONE)
   {
     if (deint == OGMRIP_DEINT_KERNEL || deint == OGMRIP_DEINT_YADIF)
@@ -666,7 +808,14 @@ ogmrip_mplayer_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gcha
     g_string_append_printf (options, "scale=%u:%u", scale_width, scale_height);
   }
 
-  if (ogmrip_video_get_denoise (video))
+  if (ogmrip_video_codec_get_max_size (video, &max_width, &max_height, &expand) && expand)
+  {
+    if (options->len > 0)
+      g_string_append_c (options, ',');
+    g_string_append_printf (options, "expand=%u:%u", max_width, max_height);
+  }
+
+  if (ogmrip_video_codec_get_denoise (video))
   {
     if (options->len > 0)
       g_string_append_c (options, ',');
@@ -698,7 +847,7 @@ ogmrip_mplayer_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gcha
   }
 
   g_ptr_array_add (argv, g_strdup ("-dvdangle"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_video_get_angle (video)));
+  g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_video_codec_get_angle (video)));
 
   chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (video), title);
   if (chap)
@@ -716,8 +865,19 @@ ogmrip_mplayer_video_command (OGMRipVideo *video, OGMDvdTitle *title, const gcha
   return argv;
 }
 
+/**
+ * ogmrip_mencoder_vobsub_watch:
+ * @exec: An #OGMJobExec
+ * @buffer: The buffer to parse
+ * @subp: An #OGMRipSubpCodec
+ *
+ * This function parses the output of mencoder when extracting VobSub subtitles
+ * and returns the progress made.
+ *
+ * Returns: The progress made, or -1.0
+ */
 gdouble
-ogmrip_mencoder_vobsub_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSubp *subp)
+ogmrip_mencoder_vobsub_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSubpCodec *subp)
 {
   gint frames, progress;
   gdouble seconds;
@@ -732,8 +892,18 @@ ogmrip_mencoder_vobsub_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSubp
   return -1.0;
 }
 
+/**
+ * ogmrip_mencoder_vobsub_command:
+ * @subp: An #OGMRipSubpCodec
+ * @output: The output file, or NULL
+ *
+ * This function creates the command line for extracting VobSub subtitles
+ * using mencoder.
+ *
+ * Returns: A new #GPtrArray, or NULL
+ */
 GPtrArray *
-ogmrip_mencoder_vobsub_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
+ogmrip_mencoder_vobsub_command (OGMRipSubpCodec *subp, const gchar *output)
 {
   OGMDvdTitle *title;
   OGMDvdSubpStream *sstream;
@@ -743,7 +913,7 @@ ogmrip_mencoder_vobsub_command (OGMRipSubp *subp, const gchar *input, const gcha
   gchar *ofps, *chap;
   gint vid, sid;
 
-  g_return_val_if_fail (OGMRIP_IS_SUBP (subp), NULL);
+  g_return_val_if_fail (OGMRIP_IS_SUBP_CODEC (subp), NULL);
 
   if (!output)
     output = ogmrip_codec_get_output (OGMRIP_CODEC (subp));
@@ -752,7 +922,7 @@ ogmrip_mencoder_vobsub_command (OGMRipSubp *subp, const gchar *input, const gcha
   title = ogmrip_codec_get_input (OGMRIP_CODEC (subp));
   g_return_val_if_fail (title != NULL, NULL);
 
-  sstream = ogmrip_subp_get_dvd_subp_stream (OGMRIP_SUBP (subp));
+  sstream = ogmrip_subp_codec_get_dvd_subp_stream (OGMRIP_SUBP_CODEC (subp));
   g_return_val_if_fail (sstream != NULL, NULL);
 
   argv = g_ptr_array_new ();
@@ -760,10 +930,17 @@ ogmrip_mencoder_vobsub_command (OGMRipSubp *subp, const gchar *input, const gcha
   g_ptr_array_add (argv, g_strdup ("-nocache"));
   g_ptr_array_add (argv, g_strdup ("-nosound"));
 
-#if MPLAYER_CHECK_VERSION(1,0,0,8)
-  g_ptr_array_add (argv, g_strdup ("-of"));
-  g_ptr_array_add (argv, g_strdup ("rawaudio"));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
+  if (MPLAYER_CHECK_VERSION (1,0,3,0))
+  {
+    g_ptr_array_add (argv, g_strdup ("-noconfig"));
+    g_ptr_array_add (argv, g_strdup ("all"));
+  }
+
+  if (MPLAYER_CHECK_VERSION (1,0,0,8))
+  {
+    g_ptr_array_add (argv, g_strdup ("-of"));
+    g_ptr_array_add (argv, g_strdup ("rawaudio"));
+  }
 
   g_ptr_array_add (argv, g_strdup ("-ovc"));
   g_ptr_array_add (argv, g_strdup ("copy"));
@@ -778,7 +955,7 @@ ogmrip_mencoder_vobsub_command (OGMRipSubp *subp, const gchar *input, const gcha
   g_ptr_array_add (argv, g_strdup ("-o"));
   g_ptr_array_add (argv, g_strdup ("/dev/null"));
 
-  sid = ogmdvd_stream_get_nr (OGMDVD_STREAM (sstream));
+  sid = ogmdvd_stream_get_id (OGMDVD_STREAM (sstream));
   g_ptr_array_add (argv, g_strdup ("-vobsubout"));
   g_ptr_array_add (argv, g_strdup (output));
   g_ptr_array_add (argv, g_strdup ("-vobsuboutindex"));
@@ -786,7 +963,7 @@ ogmrip_mencoder_vobsub_command (OGMRipSubp *subp, const gchar *input, const gcha
   g_ptr_array_add (argv, g_strdup ("-sid"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", sid));
 /*
-  if (ogmrip_subp_get_forced_only (subp))
+  if (ogmrip_subp_codec_get_forced_only (subp))
     g_ptr_array_add (argv, g_strdup ("-forcedsubsonly"));
 */
   chap = ogmrip_mplayer_get_chapters (OGMRIP_CODEC (subp), title);
@@ -804,47 +981,63 @@ ogmrip_mencoder_vobsub_command (OGMRipSubp *subp, const gchar *input, const gcha
 
   vid = ogmdvd_title_get_nr (title);
 
-#if MPLAYER_CHECK_VERSION(1,0,0,1)
-  g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,1) */
-  g_ptr_array_add (argv, g_strdup ("-dvd"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,1) */
+  if (MPLAYER_CHECK_VERSION (1,0,0,1))
+    g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
+  else
+  {
+    g_ptr_array_add (argv, g_strdup ("-dvd"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
+  }
+
+  g_ptr_array_add (argv, NULL);
 
   return argv;
 }
 
 static void
 ogmrip_mencoder_container_append_audio_file (OGMRipContainer *container, 
-    const gchar *filename, guint demuxer, gint language, GPtrArray *argv)
+    const gchar *filename, guint demuxer, gint format, gint language, GPtrArray *argv)
 {
-#if MPLAYER_CHECK_VERSION(1,0,0,8)
-  g_ptr_array_add (argv, g_strdup ("-audiofile"));
-  g_ptr_array_add (argv, g_strdup (filename));
+  if (filename)
+  {
+    struct stat buf;
 
-  if (demuxer != OGMRIP_AUDIO_DEMUXER_AUTO)
-  {
-    g_ptr_array_add (argv, g_strdup ("-audio-demuxer"));
-    g_ptr_array_add (argv, g_strdup ("rawaudio"));
-    g_ptr_array_add (argv, g_strdup ("-rawaudio"));
-    g_ptr_array_add (argv, g_strdup_printf ("format=0x%x", demuxer));
-  }
-#else /* MPLAYER_CHECK_VERSION(1,0,0,8) */
-  if (demuxer == OGMRIP_AUDIO_DEMUXER_AUTO)
-  {
-    g_ptr_array_add (argv, g_strdup ("-audiofile"));
-    g_ptr_array_add (argv, g_strdup (filename));
-  }
-  else
-  {
-    gchar *dirname, *new_name;
+    if (g_stat (filename, &buf) == 0 && buf.st_size > 0)
+    {
+      if (format == OGMRIP_FORMAT_AAC)
+      {
+        g_ptr_array_add (argv, g_strdup ("-fafmttag"));
+        g_ptr_array_add (argv, g_strdup ("0x706D"));
+      }
+      else if (demuxer == OGMRIP_AUDIO_DEMUXER_AUTO)
+      {
+        g_ptr_array_add (argv, g_strdup ("-audio-demuxer"));
+        if (MPLAYER_CHECK_VERSION (1,0,1,0))
+          g_ptr_array_add (argv, g_strdup ("audio"));
+        else
+          g_ptr_array_add (argv, g_strdup ("17"));
+      }
 
-    dirname = g_path_get_dirname (filename);
-    new_name = g_build_filename (dirname, "frameno.avi", NULL);
-    ogmrip_fs_rename (filename, new_name, NULL);
-    strcpy ((gchar *) filename, new_name);
+      if (MPLAYER_CHECK_VERSION (1,0,0,8))
+      {
+        g_ptr_array_add (argv, g_strdup ("-audiofile"));
+        g_ptr_array_add (argv, g_strdup (filename));
+
+        if (demuxer != OGMRIP_AUDIO_DEMUXER_AUTO)
+        {
+          g_ptr_array_add (argv, g_strdup ("-audio-demuxer"));
+          g_ptr_array_add (argv, g_strdup ("rawaudio"));
+          g_ptr_array_add (argv, g_strdup ("-rawaudio"));
+          g_ptr_array_add (argv, g_strdup_printf ("format=0x%x", demuxer));
+        }
+      }
+      else if (demuxer == OGMRIP_AUDIO_DEMUXER_AUTO)
+      {
+        g_ptr_array_add (argv, g_strdup ("-audiofile"));
+        g_ptr_array_add (argv, g_strdup (filename));
+      }
+    }
   }
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
 }
 
 static void
@@ -852,23 +1045,38 @@ ogmrip_mencoder_container_foreach_audio (OGMRipContainer *container,
     OGMRipCodec *codec, guint demuxer, gint language, GPtrArray *argv)
 {
   gchar *input;
+  gint format;
 
-  input = (gchar *) ogmrip_codec_get_output (codec);
+  input = g_strdup (ogmrip_codec_get_output (codec));
 
-  if (ogmrip_plugin_get_audio_codec_format (G_OBJECT_TYPE (codec)) == OGMRIP_FORMAT_AAC)
+  format =ogmrip_plugin_get_audio_codec_format (G_OBJECT_TYPE (codec));
+
+  if (!MPLAYER_CHECK_VERSION (1,0,0,8) && demuxer != OGMRIP_AUDIO_DEMUXER_AUTO && format != OGMRIP_FORMAT_AAC)
   {
-    gchar *str;
+    gchar *filename;
 
-    str = g_strconcat (input, ".aac", NULL);
-    ogmrip_fs_rename (input, str, NULL);
+    filename = g_path_get_basename (input);
+    if (!g_str_equal (filename, "frameno.avi"))
+    {
+      gchar *dirname, *new_name;
 
-    ogmrip_codec_set_output (codec, str);
-    input = str;
+      dirname = g_path_get_dirname (input);
+      new_name = g_build_filename (dirname, "frameno.avi", NULL);
+      g_free (dirname);
+
+      ogmrip_fs_rename (input, new_name, NULL);
+      ogmrip_codec_set_output (codec, new_name);
+      g_free (new_name);
+
+      g_free (input);
+      input = NULL;
+    }
+    g_free (filename);
   }
 
-  ogmrip_mencoder_container_append_audio_file (container, input, demuxer, language, argv);
+  ogmrip_mencoder_container_append_audio_file (container, input, demuxer, format, language, argv);
 
-  if (ogmrip_plugin_get_audio_codec_format (G_OBJECT_TYPE (codec)) == OGMRIP_FORMAT_AAC)
+  if (input)
     g_free (input);
 }
 
@@ -906,26 +1114,38 @@ ogmrip_mencoder_container_foreach_file (OGMRipContainer *container, OGMRipFile *
       }
 
       demuxer = ogmrip_mplayer_audio_file_get_demuxer (OGMRIP_AUDIO_FILE (file));
-      ogmrip_mencoder_container_append_audio_file (container, filename, demuxer, -1, argv);
+      ogmrip_mencoder_container_append_audio_file (container, filename, demuxer, format, -1, argv);
     }
   }
   g_free (filename);
 }
 
+/**
+ * ogmrip_mencoder_container_command:
+ * @container: An #OGMRipContainer
+ *
+ * This function creates the common part of the command line to merge streams
+ * using mencoder.
+ *
+ * Returns: A new #GPtrArray, or NULL
+ */
 GPtrArray *
 ogmrip_mencoder_container_command (OGMRipContainer *container)
 {
   GPtrArray *argv;
   const gchar *fourcc;
 
-#if MPLAYER_CHECK_VERSION(1,0,0,8)
-  const gchar *label;
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
-
   argv = g_ptr_array_new ();
   g_ptr_array_add (argv, g_strdup ("mencoder"));
   g_ptr_array_add (argv, g_strdup ("-nocache"));
   g_ptr_array_add (argv, g_strdup ("-noskip"));
+
+  if (MPLAYER_CHECK_VERSION (1,0,3,0))
+  {
+    g_ptr_array_add (argv, g_strdup ("-noconfig"));
+    g_ptr_array_add (argv, g_strdup ("all"));
+  }
+
   g_ptr_array_add (argv, g_strdup ("-mc"));
   g_ptr_array_add (argv, g_strdup ("0"));
 
@@ -941,14 +1161,17 @@ ogmrip_mencoder_container_command (OGMRipContainer *container)
     g_ptr_array_add (argv, g_strdup (fourcc));
   }
 
-#if MPLAYER_CHECK_VERSION(1,0,0,8)
-  label = ogmrip_container_get_label (container);
-  if (label)
+  if (MPLAYER_CHECK_VERSION (1,0,0,8))
   {
-    g_ptr_array_add (argv, g_strdup ("-info"));
-    g_ptr_array_add (argv, g_strdup_printf ("name=%s", label));
+    const gchar *label;
+
+    label = ogmrip_container_get_label (container);
+    if (label)
+    {
+      g_ptr_array_add (argv, g_strdup ("-info"));
+      g_ptr_array_add (argv, g_strdup_printf ("name=%s", label));
+    }
   }
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
 
   ogmrip_container_foreach_audio (container, 
       (OGMRipContainerCodecFunc) ogmrip_mencoder_container_foreach_audio, argv);
