@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -68,15 +68,18 @@ ogmrip_ogg_get_sync (OGMRipContainer *container)
   start_delay = ogmrip_container_get_start_delay (container);
   if (start_delay > 0)
   {
-    OGMDvdTitle *title;
-    OGMRipVideo *video;
+    OGMRipVideoCodec *video;
     guint num, denom;
     gchar *buf;
 
     video = ogmrip_container_get_video (container);
-
-    title = ogmrip_codec_get_input (OGMRIP_CODEC (video));
-    ogmdvd_title_get_framerate (title, &num, &denom);
+    if (ogmrip_codec_get_telecine (OGMRIP_CODEC (video)) || ogmrip_codec_get_progressive (OGMRIP_CODEC (video)))
+    {
+      num = 24000;
+      denom = 1001;
+    }
+    else
+      ogmrip_codec_get_framerate (OGMRIP_CODEC (video), &num, &denom);
 
     buf = g_new0 (gchar, G_ASCII_DTOSTR_BUF_SIZE);
     g_ascii_formatd (buf, G_ASCII_DTOSTR_BUF_SIZE, "%.0f", (start_delay * denom * 1000) / (gdouble) num);
@@ -91,46 +94,56 @@ static void
 ogmrip_ogg_merge_append_audio_file (OGMRipContainer *ogg, 
     const char *filename, gint language, GPtrArray *argv)
 {
-  gchar *sync;
+  struct stat buf;
 
-  if (language > -1)
+  if (g_stat (filename, &buf) == 0 && buf.st_size > 0)
   {
-    g_ptr_array_add (argv, g_strdup ("-c"));
-    g_ptr_array_add (argv, g_strdup_printf ("LANGUAGE=%s", 
-          g_strdup (ogmdvd_get_language_label (language))));
+    gchar *sync;
+
+    if (language > -1)
+    {
+      g_ptr_array_add (argv, g_strdup ("-c"));
+      g_ptr_array_add (argv, g_strdup_printf ("LANGUAGE=%s", 
+            g_strdup (ogmdvd_get_language_label (language))));
+    }
+
+    sync = ogmrip_ogg_get_sync (ogg);
+    if (sync)
+    {
+      g_ptr_array_add (argv, g_strdup ("--sync"));
+      g_ptr_array_add (argv, g_strdup (sync));
+      g_free (sync);
+    }
+
+    g_ptr_array_add (argv, g_strdup ("--novideo"));
+    g_ptr_array_add (argv, g_strdup ("--notext"));
+
+    g_ptr_array_add (argv, g_strdup (filename));
   }
-
-  sync = ogmrip_ogg_get_sync (ogg);
-  if (sync)
-  {
-    g_ptr_array_add (argv, g_strdup ("--sync"));
-    g_ptr_array_add (argv, g_strdup (sync));
-    g_free (sync);
-  }
-
-  g_ptr_array_add (argv, g_strdup ("--novideo"));
-  g_ptr_array_add (argv, g_strdup ("--notext"));
-
-  g_ptr_array_add (argv, g_strdup (filename));
 }
 
 static void
 ogmrip_ogg_merge_append_subp_file (OGMRipContainer *ogg, 
     const gchar *filename, guint demuxer, gint language, GPtrArray *argv)
 {
-  if (demuxer != OGMRIP_SUBP_DEMUXER_VOBSUB)
+  struct stat buf;
+
+  if (g_stat (filename, &buf) == 0 && buf.st_size > 0)
   {
-    if (language > -1)
+    if (demuxer != OGMRIP_SUBP_DEMUXER_VOBSUB)
     {
-      g_ptr_array_add (argv, g_strdup ("-c"));
-      g_ptr_array_add (argv, g_strdup_printf ("LANGUAGE=%s",
-            g_strdup (ogmdvd_get_language_label (language))));
+      if (language > -1)
+      {
+        g_ptr_array_add (argv, g_strdup ("-c"));
+        g_ptr_array_add (argv, g_strdup_printf ("LANGUAGE=%s",
+              g_strdup (ogmdvd_get_language_label (language))));
+      }
+
+      g_ptr_array_add (argv, g_strdup ("--novideo"));
+      g_ptr_array_add (argv, g_strdup ("--noaudio"));
+
+      g_ptr_array_add (argv, g_strdup (filename));
     }
-
-    g_ptr_array_add (argv, g_strdup ("--novideo"));
-    g_ptr_array_add (argv, g_strdup ("--noaudio"));
-
-    g_ptr_array_add (argv, g_strdup (filename));
   }
 }
 
@@ -160,19 +173,23 @@ ogmrip_ogg_merge_foreach_chapters (OGMRipContainer *ogg,
     OGMRipCodec *codec, guint demuxer, gint language, GPtrArray *argv)
 {
   const gchar *input;
-
-  if (language > -1)
-  {
-    g_ptr_array_add (argv, g_strdup ("-c"));
-    g_ptr_array_add (argv, g_strdup_printf ("LANGUAGE=%s",
-          g_strdup (ogmdvd_get_language_label (language))));
-  }
-
-  g_ptr_array_add (argv, g_strdup ("--novideo"));
-  g_ptr_array_add (argv, g_strdup ("--noaudio"));
+  struct stat buf;
 
   input = ogmrip_codec_get_output (codec);
-  g_ptr_array_add (argv, g_strdup (input));
+  if (g_stat (input, &buf) == 0 && buf.st_size > 0)
+  {
+    if (language > -1)
+    {
+      g_ptr_array_add (argv, g_strdup ("-c"));
+      g_ptr_array_add (argv, g_strdup_printf ("LANGUAGE=%s",
+            g_strdup (ogmdvd_get_language_label (language))));
+    }
+
+    g_ptr_array_add (argv, g_strdup ("--novideo"));
+    g_ptr_array_add (argv, g_strdup ("--noaudio"));
+
+    g_ptr_array_add (argv, g_strdup (input));
+  }
 }
 #endif
 
@@ -208,7 +225,7 @@ static gchar **
 ogmrip_ogg_merge_command (OGMRipContainer *ogg, const gchar *output)
 {
   GPtrArray *argv;
-  OGMRipVideo *video;
+  OGMRipVideoCodec *video;
   const gchar *label, *fourcc, *filename;
 
   g_return_val_if_fail (OGMRIP_IS_OGG (ogg), NULL);
@@ -326,7 +343,7 @@ ogmrip_ogg_run (OGMJobSpawn *spawn)
   ogmrip_container_get_split (OGMRIP_CONTAINER (spawn), &tnumber, NULL);
   if (tnumber > 1)
   {
-    OGMRipVideo *video;
+    OGMRipVideoCodec *video;
     const gchar *tmpname;
     gchar *dirname;
 
@@ -402,7 +419,7 @@ ogmrip_ogg_new (const gchar *output)
   return g_object_new (OGMRIP_TYPE_OGG, "output", output, NULL);
 }
 
-static OGMRipPluginContainer ogg_plugin =
+static OGMRipContainerPlugin ogg_plugin =
 {
   NULL,
   G_TYPE_NONE,
@@ -427,9 +444,21 @@ static gint formats[] =
   -1
 };
 
-OGMRipPluginContainer *
+OGMRipContainerPlugin *
 ogmrip_init_plugin (void)
 {
+  gchar *fullname;
+
+  fullname = g_find_program_in_path ("ogmmerge");
+  if (!fullname)
+    return NULL;
+  g_free (fullname);
+
+  fullname = g_find_program_in_path ("ogmsplit");
+  if (!fullname)
+    return NULL;
+  g_free (fullname);
+
   ogg_plugin.type = OGMRIP_TYPE_OGG;
   ogg_plugin.formats = formats;
 
