@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -30,14 +30,11 @@ G_BEGIN_DECLS
 #define OGMRIP_IS_OGG_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_OGG))
 
 typedef struct _OGMRipOgg      OGMRipOgg;
-typedef struct _OGMRipOggPriv  OGMRipOggPriv;
 typedef struct _OGMRipOggClass OGMRipOggClass;
 
 struct _OGMRipOgg
 {
   OGMRipContainer parent_instance;
-
-  OGMRipOggPriv *priv;
 };
 
 struct _OGMRipOggClass
