@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
 
 #include "ogmrip-plugin.h"
 #include "ogmrip-container.h"
-#include "ogmrip-audio.h"
-#include "ogmrip-video.h"
-#include "ogmrip-subp.h"
+#include "ogmrip-audio-codec.h"
+#include "ogmrip-video-codec.h"
+#include "ogmrip-subp-codec.h"
 
 #include "ogmjob-log.h"
 
@@ -56,10 +56,10 @@ struct _OGMRipPluginCodec
 
 typedef OGMRipPlugin * (* OGMRipPluginInit) (void);
 
-GSList *video_codecs = NULL;
-GSList *audio_codecs = NULL;
-GSList *subp_codecs  = NULL;
-GSList *containers   = NULL;
+static GSList *video_plugins = NULL;
+static GSList *audio_plugins = NULL;
+static GSList *subp_plugins  = NULL;
+static GSList *container_plugins   = NULL;
 
 static gint
 ogmrip_plugin_compare (OGMRipPlugin *plugin1, OGMRipPlugin *plugin2)
@@ -127,7 +127,7 @@ ogmrip_plugin_load (const gchar *dirname, GType type)
       plugin = (* init) ();
       if (!plugin)
       {
-        g_warning ("Failed to initialize module %s", filename);
+        g_print ("Plugin %s disabled, some requirements are not available\n", filename);
         g_module_close (module);
         continue;
       }
@@ -158,17 +158,23 @@ ogmrip_plugin_load (const gchar *dirname, GType type)
 void
 ogmrip_plugin_init (void)
 {
-  if (!video_codecs)
-    video_codecs = ogmrip_plugin_load (OGMRIP_LIB_DIR "/ogmrip/video-codecs", OGMRIP_TYPE_VIDEO);
+  if (!video_plugins)
+    video_plugins = ogmrip_plugin_load (OGMRIP_LIB_DIR "/ogmrip/video-plugins", OGMRIP_TYPE_VIDEO_CODEC);
 
-  if (!audio_codecs)
-    audio_codecs = ogmrip_plugin_load (OGMRIP_LIB_DIR "/ogmrip/audio-codecs", OGMRIP_TYPE_AUDIO);
+  if (!audio_plugins)
+    audio_plugins = ogmrip_plugin_load (OGMRIP_LIB_DIR "/ogmrip/audio-plugins", OGMRIP_TYPE_AUDIO_CODEC);
 
-  if (!subp_codecs)
-    subp_codecs = ogmrip_plugin_load (OGMRIP_LIB_DIR "/ogmrip/subp-codecs", OGMRIP_TYPE_SUBP);
+  if (!subp_plugins)
+    subp_plugins = ogmrip_plugin_load (OGMRIP_LIB_DIR "/ogmrip/subp-plugins", OGMRIP_TYPE_SUBP_CODEC);
 
-  if (!containers)
-    containers = ogmrip_plugin_load (OGMRIP_LIB_DIR "/ogmrip/containers", OGMRIP_TYPE_CONTAINER);
+  if (!container_plugins)
+    container_plugins = ogmrip_plugin_load (OGMRIP_LIB_DIR "/ogmrip/container-plugins", OGMRIP_TYPE_CONTAINER);
+}
+
+static void
+ogmrip_plugin_close_module (OGMRipPlugin *plugin)
+{
+  g_module_close (plugin->module);
 }
 
 /**
@@ -179,20 +185,20 @@ ogmrip_plugin_init (void)
 void
 ogmrip_plugin_uninit (void)
 {
-  g_slist_foreach (video_codecs, (GFunc) g_module_close, NULL);
-  g_slist_foreach (audio_codecs, (GFunc) g_module_close, NULL);
-  g_slist_foreach (subp_codecs,  (GFunc) g_module_close, NULL);
-  g_slist_foreach (containers,   (GFunc) g_module_close, NULL);
+  g_slist_foreach (video_plugins, (GFunc) ogmrip_plugin_close_module, NULL);
+  g_slist_foreach (audio_plugins, (GFunc) ogmrip_plugin_close_module, NULL);
+  g_slist_foreach (subp_plugins,  (GFunc) ogmrip_plugin_close_module, NULL);
+  g_slist_foreach (container_plugins,   (GFunc) ogmrip_plugin_close_module, NULL);
 }
 
-static OGMRipPluginContainer *
+static OGMRipContainerPlugin *
 ogmrip_plugin_find_container_by_type (GSList *list, GType type)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
 
   while (list)
   {
-    plugin = (OGMRipPluginContainer *) list->data;
+    plugin = (OGMRipContainerPlugin *) list->data;
     if (plugin->type == type)
       return plugin;
     list = list->next;
@@ -216,6 +222,24 @@ ogmrip_plugin_get_nth_codec (GSList *list, guint n)
   return plugin->type;
 }
 
+static GType
+ogmrip_plugin_get_type_by_name (GSList *list, const gchar *name)
+{
+  OGMRipPlugin *plugin;
+  GSList *link;
+
+  g_return_val_if_fail (name != NULL, G_TYPE_NONE);
+
+  for (link = list; link; link = link->next)
+  {
+    plugin = link->data;
+    if (g_str_equal (plugin->name, name))
+      return plugin->type;
+  }
+
+  return G_TYPE_NONE;
+}
+
 static gint
 ogmrip_plugin_get_codec_index (GSList *list, GType type)
 {
@@ -314,7 +338,7 @@ ogmrip_plugin_find_codec (GSList *list, OGMRipPluginCmpFunc func, gconstpointer
 gint
 ogmrip_plugin_get_n_containers (void)
 {
-  return g_slist_length (containers);
+  return g_slist_length (container_plugins);
 }
 
 /**
@@ -327,12 +351,12 @@ ogmrip_plugin_get_n_containers (void)
 void
 ogmrip_plugin_foreach_container (OGMRipPluginFunc func, gpointer data)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
   GSList *link;
 
   g_return_if_fail (func != NULL);
 
-  for (link = containers; link; link = link->next)
+  for (link = container_plugins; link; link = link->next)
   {
     plugin = link->data;
     func (plugin->type, (const gchar *) plugin->name, (const gchar *) plugin->description, data);
@@ -352,12 +376,12 @@ ogmrip_plugin_foreach_container (OGMRipPluginFunc func, gpointer data)
 GType
 ogmrip_plugin_find_container (OGMRipPluginCmpFunc func, gconstpointer data)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
   GSList *link;
 
   g_return_val_if_fail (func != NULL, G_TYPE_NONE);
 
-  for (link = containers; link; link = link->next)
+  for (link = container_plugins; link; link = link->next)
   {
     plugin = link->data;
     if (func (plugin->type, (gchar *) plugin->name, (gchar *) plugin->description, data) == 0)
@@ -378,18 +402,32 @@ ogmrip_plugin_find_container (OGMRipPluginCmpFunc func, gconstpointer data)
 GType
 ogmrip_plugin_get_nth_container (guint n)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
 
-  if (!containers)
+  if (!container_plugins)
     return G_TYPE_NONE;
 
-  plugin = g_slist_nth_data (containers, n);
+  plugin = g_slist_nth_data (container_plugins, n);
   if (!plugin)
-    plugin = containers->data;
+    plugin = container_plugins->data;
 
   return plugin->type;
 }
 
+/**
+ * ogmrip_plugin_get_container_by_name:
+ * @name: The name of the container
+ *
+ * Gets the container with the given name.
+ *
+ * Returns: The type of the container, or %G_TYPE_NONE
+ */
+GType
+ogmrip_plugin_get_container_by_name (const gchar *name)
+{
+  return ogmrip_plugin_get_type_by_name (container_plugins, name);
+}
+
 /**
  * ogmrip_plugin_get_container_index:
  * @container: A container type
@@ -402,12 +440,12 @@ gint
 ogmrip_plugin_get_container_index (GType container)
 {
   GSList *link;
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
   gint index;
 
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), 0);
 
-  for (index = 0, link = containers; link; index ++, link = link->next)
+  for (index = 0, link = container_plugins; link; index ++, link = link->next)
   {
     plugin = link->data;
     if (plugin->type == container)
@@ -428,11 +466,11 @@ ogmrip_plugin_get_container_index (GType container)
 G_CONST_RETURN gchar *
 ogmrip_plugin_get_container_name (GType container)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
 
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), NULL);
 
-  plugin = ogmrip_plugin_find_container_by_type (containers, container);
+  plugin = ogmrip_plugin_find_container_by_type (container_plugins, container);
   if (plugin)
     return (gchar *) plugin->name;
 
@@ -450,11 +488,11 @@ ogmrip_plugin_get_container_name (GType container)
 gboolean
 ogmrip_plugin_get_container_bframes (GType container)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
 
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), FALSE);
 
-  plugin = ogmrip_plugin_find_container_by_type (containers, container);
+  plugin = ogmrip_plugin_find_container_by_type (container_plugins, container);
   if (plugin)
     return plugin->bframes;
 
@@ -471,7 +509,7 @@ ogmrip_plugin_get_container_bframes (GType container)
 gint
 ogmrip_plugin_get_n_video_codecs (void)
 {
-  return g_slist_length (video_codecs);
+  return g_slist_length (video_plugins);
 }
 
 /**
@@ -486,7 +524,7 @@ ogmrip_plugin_foreach_video_codec (OGMRipPluginFunc func, gpointer data)
 {
   g_return_if_fail (func != NULL);
 
-  ogmrip_plugin_foreach_codec (video_codecs, func, data);
+  ogmrip_plugin_foreach_codec (video_plugins, func, data);
 }
 
 /**
@@ -504,7 +542,7 @@ ogmrip_plugin_find_video_codec (OGMRipPluginCmpFunc func, gconstpointer data)
 {
   g_return_val_if_fail (func != NULL, G_TYPE_NONE);
 
-  return ogmrip_plugin_find_codec (video_codecs, func, data);
+  return ogmrip_plugin_find_codec (video_plugins, func, data);
 }
 
 /**
@@ -518,7 +556,21 @@ ogmrip_plugin_find_video_codec (OGMRipPluginCmpFunc func, gconstpointer data)
 GType
 ogmrip_plugin_get_nth_video_codec (guint n)
 {
-  return ogmrip_plugin_get_nth_codec (video_codecs, n);
+  return ogmrip_plugin_get_nth_codec (video_plugins, n);
+}
+
+/**
+ * ogmrip_plugin_get_video_codec_by_name:
+ * @name: The name of the video codec
+ *
+ * Gets the video codec with the given name.
+ *
+ * Returns: The type of the video codec, or %G_TYPE_NONE
+ */
+GType
+ogmrip_plugin_get_video_codec_by_name (const gchar *name)
+{
+  return ogmrip_plugin_get_type_by_name (video_plugins, name);
 }
 
 /**
@@ -532,7 +584,7 @@ ogmrip_plugin_get_nth_video_codec (guint n)
 gint
 ogmrip_plugin_get_video_codec_index (GType codec)
 {
-  return ogmrip_plugin_get_codec_index (video_codecs, codec);
+  return ogmrip_plugin_get_codec_index (video_plugins, codec);
 }
 
 /**
@@ -546,9 +598,9 @@ ogmrip_plugin_get_video_codec_index (GType codec)
 G_CONST_RETURN gchar *
 ogmrip_plugin_get_video_codec_name (GType codec)
 {
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_VIDEO), NULL);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_VIDEO_CODEC), NULL);
 
-  return ogmrip_plugin_get_codec_name (video_codecs, codec);
+  return ogmrip_plugin_get_codec_name (video_plugins, codec);
 }
 
 /**
@@ -562,9 +614,9 @@ ogmrip_plugin_get_video_codec_name (GType codec)
 gint
 ogmrip_plugin_get_video_codec_format (GType codec)
 {
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_VIDEO), -1);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_VIDEO_CODEC), -1);
 
-  return ogmrip_plugin_get_codec_format (video_codecs, codec);
+  return ogmrip_plugin_get_codec_format (video_plugins, codec);
 }
 
 /**
@@ -580,13 +632,13 @@ ogmrip_plugin_get_video_codec_passes (GType codec)
 {
   OGMRipPlugin *plugin;
 
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_VIDEO), -1);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_VIDEO_CODEC), -1);
 
-  plugin = ogmrip_plugin_find_codec_by_type (video_codecs, codec);
+  plugin = ogmrip_plugin_find_codec_by_type (video_plugins, codec);
   if (!plugin)
     return -1;
 
-  return ((OGMRipPluginVideoCodec *) plugin)->passes;
+  return ((OGMRipVideoPlugin *) plugin)->passes;
 }
 
 /**
@@ -602,13 +654,13 @@ ogmrip_plugin_get_video_codec_threads (GType codec)
 {
   OGMRipPlugin *plugin;
 
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_VIDEO), -1);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_VIDEO_CODEC), -1);
 
-  plugin = ogmrip_plugin_find_codec_by_type (video_codecs, codec);
+  plugin = ogmrip_plugin_find_codec_by_type (video_plugins, codec);
   if (!plugin)
     return -1;
 
-  return ((OGMRipPluginVideoCodec *) plugin)->threads;
+  return ((OGMRipVideoPlugin *) plugin)->threads;
 }
 
 /**
@@ -621,7 +673,7 @@ ogmrip_plugin_get_video_codec_threads (GType codec)
 gint
 ogmrip_plugin_get_n_audio_codecs (void)
 {
-  return g_slist_length (audio_codecs);
+  return g_slist_length (audio_plugins);
 }
 
 /**
@@ -636,7 +688,7 @@ ogmrip_plugin_foreach_audio_codec (OGMRipPluginFunc func, gpointer data)
 {
   g_return_if_fail (func != NULL);
 
-  ogmrip_plugin_foreach_codec (audio_codecs, func, data);
+  ogmrip_plugin_foreach_codec (audio_plugins, func, data);
 }
 
 /**
@@ -654,7 +706,7 @@ ogmrip_plugin_find_audio_codec (OGMRipPluginCmpFunc func, gconstpointer data)
 {
   g_return_val_if_fail (func != NULL, G_TYPE_NONE);
 
-  return ogmrip_plugin_find_codec (audio_codecs, func, data);
+  return ogmrip_plugin_find_codec (audio_plugins, func, data);
 }
 
 /**
@@ -668,7 +720,21 @@ ogmrip_plugin_find_audio_codec (OGMRipPluginCmpFunc func, gconstpointer data)
 GType
 ogmrip_plugin_get_nth_audio_codec (guint n)
 {
-  return ogmrip_plugin_get_nth_codec (audio_codecs, n);
+  return ogmrip_plugin_get_nth_codec (audio_plugins, n);
+}
+
+/**
+ * ogmrip_plugin_get_audio_codec_by_name:
+ * @name: The name of the audio codec
+ *
+ * Gets the audio codec with the given name.
+ *
+ * Returns: The type of the audio codec, or %G_TYPE_NONE
+ */
+GType
+ogmrip_plugin_get_audio_codec_by_name (const gchar *name)
+{
+  return ogmrip_plugin_get_type_by_name (audio_plugins, name);
 }
 
 /**
@@ -682,7 +748,7 @@ ogmrip_plugin_get_nth_audio_codec (guint n)
 gint
 ogmrip_plugin_get_audio_codec_index (GType codec)
 {
-  return ogmrip_plugin_get_codec_index (audio_codecs, codec);
+  return ogmrip_plugin_get_codec_index (audio_plugins, codec);
 }
 
 /**
@@ -696,9 +762,9 @@ ogmrip_plugin_get_audio_codec_index (GType codec)
 G_CONST_RETURN gchar *
 ogmrip_plugin_get_audio_codec_name (GType codec)
 {
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_AUDIO), NULL);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_AUDIO_CODEC), NULL);
 
-  return ogmrip_plugin_get_codec_name (audio_codecs, codec);
+  return ogmrip_plugin_get_codec_name (audio_plugins, codec);
 }
 
 /**
@@ -712,9 +778,9 @@ ogmrip_plugin_get_audio_codec_name (GType codec)
 gint
 ogmrip_plugin_get_audio_codec_format (GType codec)
 {
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_AUDIO), -1);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_AUDIO_CODEC), -1);
 
-  return ogmrip_plugin_get_codec_format (audio_codecs, codec);
+  return ogmrip_plugin_get_codec_format (audio_plugins, codec);
 }
 
 /**
@@ -727,7 +793,7 @@ ogmrip_plugin_get_audio_codec_format (GType codec)
 gint
 ogmrip_plugin_get_n_subp_codecs (void)
 {
-  return g_slist_length (subp_codecs);
+  return g_slist_length (subp_plugins);
 }
 
 /**
@@ -742,7 +808,7 @@ ogmrip_plugin_foreach_subp_codec (OGMRipPluginFunc func, gpointer data)
 {
   g_return_if_fail (func != NULL);
 
-  ogmrip_plugin_foreach_codec (subp_codecs, func, data);
+  ogmrip_plugin_foreach_codec (subp_plugins, func, data);
 }
 
 /**
@@ -760,7 +826,7 @@ ogmrip_plugin_find_subp_codec (OGMRipPluginCmpFunc func, gconstpointer data)
 {
   g_return_val_if_fail (func != NULL, G_TYPE_NONE);
 
-  return ogmrip_plugin_find_codec (subp_codecs, func, data);
+  return ogmrip_plugin_find_codec (subp_plugins, func, data);
 }
 
 /**
@@ -774,7 +840,21 @@ ogmrip_plugin_find_subp_codec (OGMRipPluginCmpFunc func, gconstpointer data)
 GType
 ogmrip_plugin_get_nth_subp_codec (guint n)
 {
-  return ogmrip_plugin_get_nth_codec (subp_codecs, n);
+  return ogmrip_plugin_get_nth_codec (subp_plugins, n);
+}
+
+/**
+ * ogmrip_plugin_get_subp_codec_by_name:
+ * @name: The name of the subp codec
+ *
+ * Gets the subp codec with the given name.
+ *
+ * Returns: The type of the subp codec, or %G_TYPE_NONE
+ */
+GType
+ogmrip_plugin_get_subp_codec_by_name (const gchar *name)
+{
+  return ogmrip_plugin_get_type_by_name (subp_plugins, name);
 }
 
 /**
@@ -788,9 +868,9 @@ ogmrip_plugin_get_nth_subp_codec (guint n)
 gint
 ogmrip_plugin_get_subp_codec_index (GType codec)
 {
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_SUBP), 0);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_SUBP_CODEC), 0);
 
-  return ogmrip_plugin_get_codec_index (subp_codecs, codec);
+  return ogmrip_plugin_get_codec_index (subp_plugins, codec);
 }
 
 /**
@@ -804,9 +884,9 @@ ogmrip_plugin_get_subp_codec_index (GType codec)
 G_CONST_RETURN gchar *
 ogmrip_plugin_get_subp_codec_name (GType codec)
 {
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_SUBP), NULL);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_SUBP_CODEC), NULL);
 
-  return ogmrip_plugin_get_codec_name (subp_codecs, codec);
+  return ogmrip_plugin_get_codec_name (subp_plugins, codec);
 }
 
 /**
@@ -820,9 +900,9 @@ ogmrip_plugin_get_subp_codec_name (GType codec)
 gint
 ogmrip_plugin_get_subp_codec_format (GType codec)
 {
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_SUBP), -1);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_SUBP_CODEC), -1);
 
-  return ogmrip_plugin_get_codec_format (subp_codecs, codec);
+  return ogmrip_plugin_get_codec_format (subp_plugins, codec);
 }
 
 /**
@@ -838,13 +918,13 @@ ogmrip_plugin_get_subp_codec_text (GType codec)
 {
   OGMRipPlugin *plugin;
 
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_SUBP), FALSE);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_SUBP_CODEC), FALSE);
 
-  plugin = ogmrip_plugin_find_codec_by_type (subp_codecs, codec);
+  plugin = ogmrip_plugin_find_codec_by_type (subp_plugins, codec);
   if (!plugin)
     return FALSE;
 
-  return ((OGMRipPluginSubpCodec *) plugin)->text;
+  return ((OGMRipSubpPlugin *) plugin)->text;
 }
 
 /**
@@ -859,12 +939,12 @@ ogmrip_plugin_get_subp_codec_text (GType codec)
 gboolean
 ogmrip_plugin_can_contain_format (GType container, OGMRipFormatType format)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
   gint i;
 
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), FALSE);
 
-  plugin = ogmrip_plugin_find_container_by_type (containers, container);
+  plugin = ogmrip_plugin_find_container_by_type (container_plugins, container);
   if (!plugin || !plugin->formats)
     return FALSE;
 
@@ -895,9 +975,9 @@ gboolean
 ogmrip_plugin_can_contain_video (GType container, GType codec)
 {
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), FALSE);
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_VIDEO), FALSE);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_VIDEO_CODEC), FALSE);
 
-  return ogmrip_plugin_can_contain_codec (container, video_codecs, codec);
+  return ogmrip_plugin_can_contain_codec (container, video_plugins, codec);
 }
 
 /**
@@ -913,9 +993,9 @@ gboolean
 ogmrip_plugin_can_contain_audio (GType container, GType codec)
 {
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), FALSE);
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_AUDIO), FALSE);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_AUDIO_CODEC), FALSE);
 
-  return ogmrip_plugin_can_contain_codec (container, audio_codecs, codec);
+  return ogmrip_plugin_can_contain_codec (container, audio_plugins, codec);
 }
 
 /**
@@ -931,9 +1011,9 @@ gboolean
 ogmrip_plugin_can_contain_subp (GType container, GType codec)
 {
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), FALSE);
-  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_SUBP), FALSE);
+  g_return_val_if_fail (g_type_is_a (codec, OGMRIP_TYPE_SUBP_CODEC), FALSE);
 
-  return ogmrip_plugin_can_contain_codec (container, subp_codecs, codec);
+  return ogmrip_plugin_can_contain_codec (container, subp_plugins, codec);
 }
 
 /**
@@ -948,11 +1028,11 @@ ogmrip_plugin_can_contain_subp (GType container, GType codec)
 gboolean
 ogmrip_plugin_can_contain_n_audio (GType container, guint ncodec)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
 
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), FALSE);
 
-  plugin = ogmrip_plugin_find_container_by_type (containers, container);
+  plugin = ogmrip_plugin_find_container_by_type (container_plugins, container);
   if (!plugin)
     return FALSE;
 
@@ -971,11 +1051,11 @@ ogmrip_plugin_can_contain_n_audio (GType container, guint ncodec)
 gboolean
 ogmrip_plugin_can_contain_n_subp (GType container, guint ncodec)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
 
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), FALSE);
 
-  plugin = ogmrip_plugin_find_container_by_type (containers, container);
+  plugin = ogmrip_plugin_find_container_by_type (container_plugins, container);
   if (!plugin)
     return FALSE;
 
@@ -993,11 +1073,11 @@ ogmrip_plugin_can_contain_n_subp (GType container, guint ncodec)
 gint
 ogmrip_plugin_get_container_max_audio (GType container)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
 
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), -1);
 
-  plugin = ogmrip_plugin_find_container_by_type (containers, container);
+  plugin = ogmrip_plugin_find_container_by_type (container_plugins, container);
   if (!plugin)
     return FALSE;
 
@@ -1015,11 +1095,11 @@ ogmrip_plugin_get_container_max_audio (GType container)
 gint
 ogmrip_plugin_get_container_max_subp (GType container)
 {
-  OGMRipPluginContainer *plugin;
+  OGMRipContainerPlugin *plugin;
 
   g_return_val_if_fail (g_type_is_a (container, OGMRIP_TYPE_CONTAINER), -1);
 
-  plugin = ogmrip_plugin_find_container_by_type (containers, container);
+  plugin = ogmrip_plugin_find_container_by_type (container_plugins, container);
   if (!plugin)
     return FALSE;
 
