@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,9 +20,11 @@
 #include "config.h"
 #endif
 
+#include "ogmrip-fs.h"
 #include "ogmrip-srt.h"
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
+#include "ogmrip-version.h"
 
 #include "ogmjob-queue.h"
 #include "ogmjob-exec.h"
@@ -32,67 +34,106 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#define OGMRIP_SRT_GET_PRIVATE(o) \
+    (G_TYPE_INSTANCE_GET_PRIVATE ((o), OGMRIP_TYPE_SRT, OGMRipSrtPriv))
+
+struct _OGMRipSrtPriv
+{
+  guint files;
+  guint index;
+};
+
 static gint ogmrip_srt_run (OGMJobSpawn *spawn);
 
+static gboolean use_gocr      = FALSE;
+static gboolean use_ocrad     = FALSE;
+static gboolean use_tesseract = FALSE;
+
 static gdouble
-ogmrip_pgm_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSubp *subp)
+ogmrip_subp2pgm_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSrt *srt)
 {
   guint files;
 
   if (sscanf (buffer, "%u files generated", &files) == 1)
   {
-    g_object_set_data (G_OBJECT (subp), "__ogmrip_srt_index__", GUINT_TO_POINTER (0));
-    g_object_set_data (G_OBJECT (subp), "__ogmrip_srt_files__", GUINT_TO_POINTER (files));
+    srt->priv->files = files;
+    srt->priv->index = 0;
   }
 
   return -1.0;
 }
 
 static gdouble
-ogmrip_ocr_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSubp *subp)
+ogmrip_gocr_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSrt *srt)
 {
   if (strncmp (buffer, "Elapsed time:", 13) == 0)
   {
-    guint index, files;
+    srt->priv->index ++;
 
-    index = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (subp), "__ogmrip_srt_index__"));
-    files = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (subp), "__ogmrip_srt_files__"));
+    return 0.98 + 0.02 * (srt->priv->index + 1) / (gdouble) srt->priv->files;
+  }
 
-    g_object_set_data (G_OBJECT (subp), "__ogmrip_srt_index__", GUINT_TO_POINTER (index + 1));
+  return -1.0;
+}
 
-    return 0.98 + 0.02 * (index + 1) / (gdouble) files;
+static gdouble
+ogmrip_ocrad_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSrt *srt)
+{
+  if (strncmp (buffer, "number of text blocks =", 23) == 0)
+  {
+    srt->priv->index ++;
+
+    return 0.98 + 0.02 * (srt->priv->index + 1) / (gdouble) srt->priv->files;
+  }
+
+  return -1.0;
+}
+
+static gdouble
+ogmrip_tesseract_watch (OGMJobExec *exec, const gchar *buffer, OGMRipSrt *srt)
+{
+  if (strncmp (buffer, "Tesseract Open Source OCR Engine", 32) == 0)
+  {
+    srt->priv->index ++;
+
+    return 0.98 + 0.02 * (srt->priv->index + 1) / (gdouble) srt->priv->files;
   }
 
   return -1.0;
 }
 
 static gchar **
-ogmrip_pgm_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
+ogmrip_subp2pgm_command (OGMRipSubpCodec *subp, const gchar *input)
 {
   GPtrArray *argv;
 
-  g_return_val_if_fail (OGMRIP_IS_SUBP (subp), NULL);
+  g_return_val_if_fail (OGMRIP_IS_SUBP_CODEC (subp), NULL);
   g_return_val_if_fail (input != NULL, NULL);
 
   argv = g_ptr_array_new ();
-  g_ptr_array_add (argv, g_strdup ("subp2pgm"));
 
-  if (ogmrip_subp_get_forced_only (subp))
+  if (use_tesseract)
+    g_ptr_array_add (argv, g_strdup ("subp2tiff"));
+  else
+    g_ptr_array_add (argv, g_strdup ("subp2pgm"));
+
+  if (ogmrip_subp_codec_get_forced_only (subp))
     g_ptr_array_add (argv, g_strdup ("--forced"));
 
+  g_ptr_array_add (argv, g_strdup ("--normalize"));
+
   g_ptr_array_add (argv, g_strdup (input));
   g_ptr_array_add (argv, NULL);
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
 
-#ifdef HAVE_GOCR_SUPPORT
 static gchar **
-ogmrip_ocr_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
+ogmrip_gocr_command (OGMRipSubpCodec *subp, const gchar *input)
 {
   GPtrArray *argv;
 
-  g_return_val_if_fail (OGMRIP_IS_SUBP (subp), NULL);
+  g_return_val_if_fail (OGMRIP_IS_SUBP_CODEC (subp), NULL);
   g_return_val_if_fail (input != NULL, NULL);
 
   argv = g_ptr_array_new ();
@@ -101,7 +142,7 @@ ogmrip_ocr_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
   g_ptr_array_add (argv, g_strdup ("1"));
   g_ptr_array_add (argv, g_strdup ("-f"));
 
-  switch (ogmrip_subp_get_charset (subp))
+  switch (ogmrip_subp_codec_get_charset (subp))
   {
     case OGMRIP_CHARSET_UTF8:
       g_ptr_array_add (argv, g_strdup ("UTF8"));
@@ -125,13 +166,13 @@ ogmrip_ocr_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
-#else
+
 static gchar **
-ogmrip_ocr_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
+ogmrip_ocrad_command (OGMRipSubpCodec *subp, const gchar *input)
 {
   GPtrArray *argv;
 
-  g_return_val_if_fail (OGMRIP_IS_SUBP (subp), NULL);
+  g_return_val_if_fail (OGMRIP_IS_SUBP_CODEC (subp), NULL);
   g_return_val_if_fail (input != NULL, NULL);
 
   argv = g_ptr_array_new ();
@@ -140,7 +181,7 @@ ogmrip_ocr_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
   g_ptr_array_add (argv, g_strdup ("-f"));
   g_ptr_array_add (argv, g_strdup ("-F"));
 
-  switch (ogmrip_subp_get_charset (subp))
+  switch (ogmrip_subp_codec_get_charset (subp))
   {
     case OGMRIP_CHARSET_UTF8:
       g_ptr_array_add (argv, g_strdup ("utf8"));
@@ -160,14 +201,47 @@ ogmrip_ocr_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
-#endif
 
 static gchar **
-ogmrip_srt_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
+ogmrip_tesseract_command (OGMRipSubpCodec *subp, const gchar *input, gboolean lang)
 {
   GPtrArray *argv;
 
-  g_return_val_if_fail (OGMRIP_IS_SUBP (subp), NULL);
+  g_return_val_if_fail (input != NULL, NULL);
+
+  argv = g_ptr_array_new ();
+  g_ptr_array_add (argv, g_strdup ("tesseract"));
+  g_ptr_array_add (argv, g_strdup (input));
+  g_ptr_array_add (argv, g_strdup (input));
+
+  if (lang)
+  {
+    OGMDvdSubpStream *stream;
+    const gchar *language;
+
+    stream = ogmrip_subp_codec_get_dvd_subp_stream (subp);
+    language = ogmdvd_get_language_iso639_2 (ogmdvd_subp_stream_get_language (stream));
+
+    if (g_str_equal (language, "fre"))
+      language = "fra";
+    else if (g_str_equal (language, "ger"))
+      language = "deu";
+
+    g_ptr_array_add (argv, g_strdup ("-l"));
+    g_ptr_array_add (argv, g_strdup (language));
+  }
+
+  g_ptr_array_add (argv, NULL);
+
+  return (gchar **) g_ptr_array_free (argv, FALSE);
+}
+
+static gchar **
+ogmrip_srt_command (OGMRipSubpCodec *subp, const gchar *input, const gchar *output)
+{
+  GPtrArray *argv;
+
+  g_return_val_if_fail (OGMRIP_IS_SUBP_CODEC (subp), NULL);
   g_return_val_if_fail (input != NULL, NULL);
 
   if (!output)
@@ -175,17 +249,18 @@ ogmrip_srt_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
   g_return_val_if_fail (output != NULL, NULL);
 
   argv = g_ptr_array_new ();
-  g_ptr_array_add (argv, g_strdup ("srtutil"));
+  g_ptr_array_add (argv, g_strdup ("subptools"));
   g_ptr_array_add (argv, g_strdup ("-s"));
+
+  g_ptr_array_add (argv, g_strdup ("-t"));
+  g_ptr_array_add (argv, g_strdup ("srt"));
 /*
-  g_ptr_array_add (argv, g_strdup ("-w"));
-*/
-  if (ogmrip_subp_get_eol_style (OGMRIP_SUBP (subp)))
+  if (ogmrip_subp_codec_get_eol_style (OGMRIP_SUBP_CODEC (subp)))
   {
     g_ptr_array_add (argv, g_strdup ("-f"));
     g_ptr_array_add (argv, g_strdup ("dos"));
   }
-
+*/
   g_ptr_array_add (argv, g_strdup ("-i"));
   g_ptr_array_add (argv, g_strdup (input));
   g_ptr_array_add (argv, g_strdup ("-o"));
@@ -196,17 +271,48 @@ ogmrip_srt_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
 }
 
 static gchar **
-ogmrip_vobsub_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
+ogmrip_vobsub_command (OGMRipSubpCodec *subp, const gchar *input, const gchar *output)
 {
   GPtrArray *argv;
 
-  argv = ogmrip_mencoder_vobsub_command (subp, NULL, output);
-  g_ptr_array_add (argv, NULL);
+  argv = ogmrip_mencoder_vobsub_command (subp, output);
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
 
-G_DEFINE_TYPE (OGMRipSrt, ogmrip_srt, OGMRIP_TYPE_SUBP)
+static OGMJobSpawn *
+ogmrip_srt_ocr (OGMJobSpawn *spawn, const gchar *filename, gboolean lang)
+{
+  OGMJobSpawn *child;
+  gchar **argv;
+
+  if (use_tesseract)
+    argv = ogmrip_tesseract_command (OGMRIP_SUBP_CODEC (spawn), filename, lang);
+  else if (use_ocrad)
+    argv = ogmrip_ocrad_command (OGMRIP_SUBP_CODEC (spawn), filename);
+  else
+    argv = ogmrip_gocr_command (OGMRIP_SUBP_CODEC (spawn), filename);
+
+  if (!argv)
+    return NULL;
+
+  child = ogmjob_exec_newv (argv);
+
+  if (use_tesseract)
+    ogmjob_exec_add_watch_full (OGMJOB_EXEC (child),
+        (OGMJobWatch) ogmrip_tesseract_watch, spawn, FALSE, TRUE, TRUE);
+  else if (use_ocrad)
+    ogmjob_exec_add_watch_full (OGMJOB_EXEC (child),
+        (OGMJobWatch) ogmrip_ocrad_watch, spawn, FALSE, TRUE, TRUE);
+  else
+    ogmjob_exec_add_watch_full (OGMJOB_EXEC (child),
+        (OGMJobWatch) ogmrip_gocr_watch, spawn, FALSE, TRUE, TRUE);
+
+  return child;
+}
+
+
+G_DEFINE_TYPE (OGMRipSrt, ogmrip_srt, OGMRIP_TYPE_SUBP_CODEC)
 
 static void
 ogmrip_srt_class_init (OGMRipSrtClass *klass)
@@ -216,38 +322,39 @@ ogmrip_srt_class_init (OGMRipSrtClass *klass)
   spawn_class = OGMJOB_SPAWN_CLASS (klass);
 
   spawn_class->run = ogmrip_srt_run;
+
+  g_type_class_add_private (klass, sizeof (OGMRipSrtPriv));
 }
 
 static void
 ogmrip_srt_init (OGMRipSrt *srt)
 {
+  srt->priv = OGMRIP_SRT_GET_PRIVATE (srt);
 }
 
 static gint
 ogmrip_srt_run (OGMJobSpawn *spawn)
 {
   OGMJobSpawn *child;
-  gint result, fd;
-  gchar **argv;
-
-  GDir *dir;
   GPatternSpec *pspec;
-  gchar *pattern, *str;
-  const gchar *name;
+  GDir *dir;
 
-  gchar *tmp_file, *srtx_file;
+  gboolean have_sub_files = FALSE;
+  gchar **argv, *pattern, *str, *tmp_file, *xml_file;
+  const gchar *name;
+  gint result, fd;
 
   result = OGMJOB_RESULT_ERROR;
 
-  fd = g_file_open_tmp ("sub.XXXXXX", &tmp_file, NULL);
+  fd = ogmrip_fs_open_tmp ("sub.XXXXXX", &tmp_file, NULL);
   if (fd < 0)
     return OGMJOB_RESULT_ERROR;
   g_unlink (tmp_file);
   close (fd);
 
-  srtx_file = g_strconcat (tmp_file, ".srtx", NULL);
+  xml_file = g_strconcat (tmp_file, ".xml", NULL);
 
-  argv = ogmrip_vobsub_command (OGMRIP_SUBP (spawn), NULL, tmp_file);
+  argv = ogmrip_vobsub_command (OGMRIP_SUBP_CODEC (spawn), NULL, tmp_file);
   if (argv)
   {
     child = ogmjob_exec_newv (argv);
@@ -264,11 +371,11 @@ ogmrip_srt_run (OGMJobSpawn *spawn)
   {
     result = OGMJOB_RESULT_ERROR;
 
-    argv = ogmrip_pgm_command (OGMRIP_SUBP (spawn), tmp_file, NULL);
+    argv = ogmrip_subp2pgm_command (OGMRIP_SUBP_CODEC (spawn), tmp_file);
     if (argv)
     {
       child = ogmjob_exec_newv (argv);
-      ogmjob_exec_add_watch_full (OGMJOB_EXEC (child), (OGMJobWatch) ogmrip_pgm_watch, spawn, TRUE, FALSE, FALSE);
+      ogmjob_exec_add_watch_full (OGMJOB_EXEC (child), (OGMJobWatch) ogmrip_subp2pgm_watch, spawn, TRUE, FALSE, FALSE);
       result = ogmjob_spawn_run (child, NULL);
       g_object_unref (child);
     }
@@ -276,15 +383,16 @@ ogmrip_srt_run (OGMJobSpawn *spawn)
 
   if (result == OGMJOB_RESULT_COMPLETED)
   {
-    result = OGMJOB_RESULT_ERROR;
-
-    dir = g_dir_open (g_get_tmp_dir (), 0, NULL);
+    dir = g_dir_open (ogmrip_fs_get_tmp_dir (), 0, NULL);
     if (dir)
     {
       gchar *basename;
 
       basename = g_path_get_basename (tmp_file);
-      pattern = g_strconcat (basename, "*.pgm", NULL);
+      if (use_tesseract)
+        pattern = g_strconcat (basename, "*.tif", NULL);
+      else
+        pattern = g_strconcat (basename, "*.pgm", NULL);
       pspec = g_pattern_spec_new (pattern);
       g_free (basename);
       g_free (pattern);
@@ -293,20 +401,29 @@ ogmrip_srt_run (OGMJobSpawn *spawn)
       {
         if (g_pattern_match (pspec, strlen (name), name, NULL))
         {
-          str = g_build_filename (g_get_tmp_dir (), name, NULL);
-          argv = ogmrip_ocr_command (OGMRIP_SUBP (spawn), str, NULL);
-
-          if (argv)
+          str = g_build_filename (ogmrip_fs_get_tmp_dir (), name, NULL);
+          if ((child = ogmrip_srt_ocr (spawn, str, TRUE)))
           {
-            child = ogmjob_exec_newv (argv);
-            ogmjob_exec_add_watch_full (OGMJOB_EXEC (child), (OGMJobWatch) ogmrip_ocr_watch, spawn, FALSE, TRUE, TRUE);
             result = ogmjob_spawn_run (child, NULL);
             g_object_unref (child);
 
             if (result != OGMJOB_RESULT_COMPLETED)
-              break;
-          }
+            {
+              if (!use_tesseract)
+                break;
 
+              if ((child = ogmrip_srt_ocr (spawn, str, FALSE)))
+              {
+                result = ogmjob_spawn_run (child, NULL);
+                g_object_unref (child);
+
+                if (result != OGMJOB_RESULT_COMPLETED)
+                  break;
+              }
+            }
+
+            have_sub_files = TRUE;
+          }
           g_unlink (str);
           g_free (str);
         }
@@ -319,38 +436,44 @@ ogmrip_srt_run (OGMJobSpawn *spawn)
 
   if (result == OGMJOB_RESULT_COMPLETED)
   {
-    result = OGMJOB_RESULT_ERROR;
-
-    argv = ogmrip_srt_command (OGMRIP_SUBP (spawn), srtx_file, NULL);
-    if (argv)
+    if (have_sub_files && g_file_test (xml_file, G_FILE_TEST_EXISTS))
     {
-      child = ogmjob_exec_newv (argv);
-      result = ogmjob_spawn_run (child, NULL);
-      g_object_unref (child);
+      result = OGMJOB_RESULT_ERROR;
+
+      argv = ogmrip_srt_command (OGMRIP_SUBP_CODEC (spawn), xml_file, NULL);
+      if (argv)
+      {
+        child = ogmjob_exec_newv (argv);
+        result = ogmjob_spawn_run (child, NULL);
+        g_object_unref (child);
+      }
     }
   }
 
-  if (g_file_test (srtx_file, G_FILE_TEST_EXISTS))
-    g_unlink (srtx_file);
-  g_free (srtx_file);
+  if (g_file_test (xml_file, G_FILE_TEST_EXISTS))
+    g_unlink (xml_file);
+  g_free (xml_file);
 
-  srtx_file = g_strconcat (tmp_file, ".idx", NULL);
-  if (g_file_test (srtx_file, G_FILE_TEST_EXISTS))
-    g_unlink (srtx_file);
-  g_free (srtx_file);
+  xml_file = g_strconcat (tmp_file, ".idx", NULL);
+  if (g_file_test (xml_file, G_FILE_TEST_EXISTS))
+    g_unlink (xml_file);
+  g_free (xml_file);
 
-  srtx_file = g_strconcat (tmp_file, ".sub", NULL);
-  if (g_file_test (srtx_file, G_FILE_TEST_EXISTS))
-    g_unlink (srtx_file);
-  g_free (srtx_file);
+  xml_file = g_strconcat (tmp_file, ".sub", NULL);
+  if (g_file_test (xml_file, G_FILE_TEST_EXISTS))
+    g_unlink (xml_file);
+  g_free (xml_file);
 
-  dir = g_dir_open (g_get_tmp_dir (), 0, NULL);
+  dir = g_dir_open (ogmrip_fs_get_tmp_dir (), 0, NULL);
   if (dir)
   {
     gchar *basename;
 
     basename = g_path_get_basename (tmp_file);
-    pattern = g_strconcat (basename, "*.pgm*", NULL);
+    if (use_tesseract)
+      pattern = g_strconcat (basename, "*.tif.txt", NULL);
+    else
+      pattern = g_strconcat (basename, "*.pgm.txt", NULL);
     pspec = g_pattern_spec_new (pattern);
     g_free (basename);
     g_free (pattern);
@@ -359,7 +482,7 @@ ogmrip_srt_run (OGMJobSpawn *spawn)
     {
       if (g_pattern_match (pspec, strlen (name), name, NULL))
       {
-        str = g_build_filename (g_get_tmp_dir (), name, NULL);
+        str = g_build_filename (ogmrip_fs_get_tmp_dir (), name, NULL);
         g_unlink (str);
         g_free (str);
       }
@@ -392,7 +515,7 @@ ogmrip_srt_new (OGMDvdSubpStream *subp, const gchar *output)
   return g_object_new (OGMRIP_TYPE_SRT, "stream", subp, "output", output, NULL);
 }
 
-static OGMRipPluginContainer srt_plugin =
+static OGMRipSubpPlugin srt_plugin =
 {
   NULL,
   G_TYPE_NONE,
@@ -402,9 +525,50 @@ static OGMRipPluginContainer srt_plugin =
   TRUE
 };
 
-OGMRipPluginContainer *
+OGMRipSubpPlugin *
 ogmrip_init_plugin (void)
 {
+#if defined(HAVE_GOCR_SUPPORT) || defined(HAVE_OCRAD_SUPPORT) || defined(HAVE_TESSERACT_SUPPORT)
+  gchar *fullname;
+#endif
+
+  if (!ogmrip_check_mencoder ())
+    return NULL;
+
+#ifdef HAVE_TESSERACT_SUPPORT
+  fullname = g_find_program_in_path ("tesseract");
+  use_tesseract = fullname != NULL;
+  g_free (fullname);
+
+  if (use_tesseract)
+  {
+    fullname = g_find_program_in_path ("subp2tiff");
+    use_tesseract = fullname != NULL;
+    g_free (fullname);
+  }
+#endif
+
+#ifdef HAVE_GOCR_SUPPORT
+  if (!use_tesseract)
+  {
+    fullname = g_find_program_in_path ("gocr");
+    use_gocr = fullname != NULL;
+    g_free (fullname);
+  }
+#endif
+
+#ifdef HAVE_OCRAD_SUPPORT
+  if (!use_gocr && !use_tesseract)
+  {
+    fullname = g_find_program_in_path ("ocrad");
+    use_ocrad = fullname != NULL;
+    g_free (fullname);
+  }
+#endif
+
+  if (!use_gocr && !use_ocrad && !use_tesseract)
+    return NULL;
+
   srt_plugin.type = OGMRIP_TYPE_SRT;
 
   return &srt_plugin;
