@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,7 +19,7 @@
 #ifndef __OGMRIP_SRT_H__
 #define __OGMRIP_SRT_H__
 
-#include <ogmrip-subp.h>
+#include <ogmrip-subp-codec.h>
 
 G_BEGIN_DECLS
 
@@ -30,19 +30,19 @@ G_BEGIN_DECLS
 #define OGMRIP_IS_SRT_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_SRT))
 
 typedef struct _OGMRipSrt      OGMRipSrt;
-typedef struct _OGMRipSrtPriv  OGMRipSrtPriv;
 typedef struct _OGMRipSrtClass OGMRipSrtClass;
+typedef struct _OGMRipSrtPriv  OGMRipSrtPriv;
 
 struct _OGMRipSrt
 {
-  OGMRipSubp parent_instance;
+  OGMRipSubpCodec parent_instance;
 
   OGMRipSrtPriv *priv;
 };
 
 struct _OGMRipSrtClass
 {
-  OGMRipSubpClass parent_class;
+  OGMRipSubpCodecClass parent_class;
 };
 
 GType         ogmrip_srt_get_type  (void);
