@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -34,16 +34,18 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#define PROGRAM "theoraenc"
+
 static gint ogmrip_theora_run (OGMJobSpawn *spawn);
 
 static gchar **
-ogmrip_yuv4mpeg_command (OGMRipVideo *video, const gchar *input, const gchar *output, const gchar *logf)
+ogmrip_yuv4mpeg_command (OGMRipVideoCodec *video, const gchar *input, const gchar *output, const gchar *logf)
 {
   OGMDvdTitle *title;
   GPtrArray *argv;
   gint vid;
 
-  g_return_val_if_fail (OGMRIP_IS_VIDEO (video), NULL);
+  g_return_val_if_fail (OGMRIP_IS_VIDEO_CODEC (video), NULL);
 
   if (!output)
     output = ogmrip_codec_get_output (OGMRIP_CODEC (video));
@@ -52,23 +54,23 @@ ogmrip_yuv4mpeg_command (OGMRipVideo *video, const gchar *input, const gchar *ou
   title = ogmrip_codec_get_input (OGMRIP_CODEC (video));
   g_return_val_if_fail (title != NULL, NULL);
 
-  argv = ogmrip_mplayer_video_command (video, title, output);
+  argv = ogmrip_mplayer_video_command (video, output);
 
   g_ptr_array_add (argv, g_strdup ("-vo"));
-#if MPLAYER_CHECK_VERSION(1,0,0,6)
-  g_ptr_array_add (argv, g_strdup_printf ("yuv4mpeg:file=%s", output));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,6) */
-  g_ptr_array_add (argv, g_strdup ("yuv4mpeg"));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,6) */
+  if (MPLAYER_CHECK_VERSION (1,0,0,6))
+    g_ptr_array_add (argv, g_strdup_printf ("yuv4mpeg:file=%s", output));
+  else
+    g_ptr_array_add (argv, g_strdup ("yuv4mpeg"));
 
   vid = ogmdvd_title_get_nr (title);
 
-#if MPLAYER_CHECK_VERSION(1,0,0,1)
-  g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,1) */
-  g_ptr_array_add (argv, g_strdup ("-dvd"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,1) */
+  if (MPLAYER_CHECK_VERSION (1,0,0,1))
+    g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
+  else
+  {
+    g_ptr_array_add (argv, g_strdup ("-dvd"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
+  }
 
   g_ptr_array_add (argv, NULL);
 
@@ -76,12 +78,12 @@ ogmrip_yuv4mpeg_command (OGMRipVideo *video, const gchar *input, const gchar *ou
 }
 
 static gchar **
-ogmrip_theora_command (OGMRipVideo *video, const gchar *input, const gchar *output, const gchar *logf)
+ogmrip_theora_command (OGMRipVideoCodec *video, const gchar *input, const gchar *output, const gchar *logf)
 {
   GPtrArray *argv;
   gint bitrate;
 
-  g_return_val_if_fail (OGMRIP_IS_VIDEO (video), NULL);
+  g_return_val_if_fail (OGMRIP_IS_VIDEO_CODEC (video), NULL);
   g_return_val_if_fail (input != NULL, NULL);
 
   if (!output)
@@ -90,12 +92,12 @@ ogmrip_theora_command (OGMRipVideo *video, const gchar *input, const gchar *outp
 
   argv = g_ptr_array_new ();
 
-  g_ptr_array_add (argv, g_strdup ("theoraenc"));
+  g_ptr_array_add (argv, g_strdup (PROGRAM));
 
   g_ptr_array_add (argv, g_strdup ("-o"));
   g_ptr_array_add (argv, g_strdup (output));
 
-  bitrate = ogmrip_video_get_bitrate (video);
+  bitrate = ogmrip_video_codec_get_bitrate (video);
   if (bitrate > 0)
   {
     bitrate /= 1000;
@@ -106,7 +108,7 @@ ogmrip_theora_command (OGMRipVideo *video, const gchar *input, const gchar *outp
   {
     gint quantizer;
 
-    quantizer = ogmrip_video_get_quantizer (video);
+    quantizer = ogmrip_video_codec_get_quantizer (video);
     g_ptr_array_add (argv, g_strdup ("-q"));
     g_ptr_array_add (argv, g_strdup_printf ("%u", (31 - quantizer) / 3));
   }
@@ -118,7 +120,7 @@ ogmrip_theora_command (OGMRipVideo *video, const gchar *input, const gchar *outp
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
 
-G_DEFINE_TYPE (OGMRipTheora, ogmrip_theora, OGMRIP_TYPE_VIDEO)
+G_DEFINE_TYPE (OGMRipTheora, ogmrip_theora, OGMRIP_TYPE_VIDEO_CODEC)
 
 static void
 ogmrip_theora_class_init (OGMRipTheoraClass *klass)
@@ -138,6 +140,7 @@ ogmrip_theora_init (OGMRipTheora *theora)
 static gint
 ogmrip_theora_run (OGMJobSpawn *spawn)
 {
+  GError *error = NULL;
   OGMJobSpawn *pipeline;
   OGMJobSpawn *child;
   gchar **argv, *fifo;
@@ -145,13 +148,18 @@ ogmrip_theora_run (OGMJobSpawn *spawn)
 
   result = OGMJOB_RESULT_ERROR;
 
-  fifo = ogmrip_fs_mkftemp ("fifo.XXXXXX", NULL);
+  fifo = ogmrip_fs_mkftemp ("fifo.XXXXXX", &error);
+  if (!fifo)
+  {
+    ogmjob_spawn_propagate_error (spawn, error);
+    return OGMJOB_RESULT_ERROR;
+  }
 
   pipeline = ogmjob_pipeline_new ();
   ogmjob_container_add (OGMJOB_CONTAINER (spawn), pipeline);
   g_object_unref (pipeline);
 
-  argv = ogmrip_yuv4mpeg_command (OGMRIP_VIDEO (spawn), NULL, fifo, NULL);
+  argv = ogmrip_yuv4mpeg_command (OGMRIP_VIDEO_CODEC (spawn), NULL, fifo, NULL);
   if (argv)
   {
     child = ogmjob_exec_newv (argv);
@@ -159,7 +167,7 @@ ogmrip_theora_run (OGMJobSpawn *spawn)
     ogmjob_container_add (OGMJOB_CONTAINER (pipeline), child);
     g_object_unref (child);
 
-    argv = ogmrip_theora_command (OGMRIP_VIDEO (spawn), fifo, NULL, NULL);
+    argv = ogmrip_theora_command (OGMRIP_VIDEO_CODEC (spawn), fifo, NULL, NULL);
     if (argv)
     {
       child = ogmjob_exec_newv (argv);
@@ -197,7 +205,7 @@ ogmrip_theora_new (OGMDvdTitle *title, const gchar *output)
   return g_object_new (OGMRIP_TYPE_THEORA, "input", title, "output", output, NULL);
 }
 
-static OGMRipPluginVideoCodec theora_plugin =
+static OGMRipVideoPlugin theora_plugin =
 {
   NULL,
   G_TYPE_NONE,
@@ -208,9 +216,19 @@ static OGMRipPluginVideoCodec theora_plugin =
   1
 };
 
-OGMRipPluginVideoCodec *
+OGMRipVideoPlugin *
 ogmrip_init_plugin (void)
 {
+  gchar *fullname;
+
+  if (!ogmrip_check_mplayer ())
+    return NULL;
+
+  fullname = g_find_program_in_path (PROGRAM);
+  if (!fullname)
+    return NULL;
+  g_free (fullname);
+
   theora_plugin.type = OGMRIP_TYPE_THEORA;
 
   return &theora_plugin;
