@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,7 +19,7 @@
 #ifndef __OGMRIP_THEORA_H__
 #define __OGMRIP_THEORA_H__
 
-#include <ogmrip-video.h>
+#include <ogmrip-video-codec.h>
 
 G_BEGIN_DECLS
 
@@ -30,19 +30,16 @@ G_BEGIN_DECLS
 #define OGMRIP_IS_THEORA_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_THEORA))
 
 typedef struct _OGMRipTheora      OGMRipTheora;
-typedef struct _OGMRipTheoraPriv  OGMRipTheoraPriv;
 typedef struct _OGMRipTheoraClass OGMRipTheoraClass;
 
 struct _OGMRipTheora
 {
-  OGMRipVideo parent_instance;
-
-  OGMRipTheoraPriv *priv;
+  OGMRipVideoCodec parent_instance;
 };
 
 struct _OGMRipTheoraClass
 {
-  OGMRipVideoClass parent_class;
+  OGMRipVideoCodecClass parent_class;
 };
 
 GType         ogmrip_theora_get_type (void);
