@@ -1,6 +1,10 @@
 #ifndef __OGMRIP_VERSION_H__
 #define __OGMRIP_VERSION_H__
 
+#include <glib.h>
+
+G_BEGIN_DECLS
+
 /**
  * OGMRIP_MAJOR_VERSION:
  *
@@ -13,42 +17,14 @@
  *
  * Compile time minor version of OGMRip
  */
-#define OGMRIP_MINOR_VERSION       (11)
+#define OGMRIP_MINOR_VERSION       (12)
 
 /**
  * OGMRIP_MICRO_VERSION:
  *
  * Compile time micro version of OGMRip
  */
-#define OGMRIP_MICRO_VERSION       (1)
-
-/**
- * MPLAYER_MAJOR_VERSION:
- *
- * Compile time major version of MPlayer
- */
-#define MPLAYER_MAJOR_VERSION      (99)
-
-/**
- * MPLAYER_MINOR_VERSION:
- *
- * Compile time minor version of MPlayer
- */
-#define MPLAYER_MINOR_VERSION      (99)
-
-/**
- * MPLAYER_PRE_VERSION:
- *
- * Compile time pre version of MPlayer
- */
-#define MPLAYER_PRE_VERSION        (99)
-
-/**
- * MPLAYER_RC_VERSION:
- *
- * Compile time rc version of MPlayer
- */
-#define MPLAYER_RC_VERSION         (99)
+#define OGMRIP_MICRO_VERSION       (2)
 
 /**
  * OGMRIP_CHECK_VERSION:
@@ -74,14 +50,19 @@
  * Check if version is equal or greather than major.minor, major.minor-rc or
  * major.minor-pre, in that order
  */
-
 #define MPLAYER_CHECK_VERSION(major,minor,rc,pre) \
-  ((MPLAYER_MAJOR_VERSION > (major)) || \
-   (MPLAYER_MAJOR_VERSION == (major) && MPLAYER_MINOR_VERSION > (minor)) || \
-   (MPLAYER_MAJOR_VERSION == (major) && MPLAYER_MINOR_VERSION == (minor) && \
-    ((MPLAYER_RC_VERSION == 0 && MPLAYER_PRE_VERSION == 0) || \
-     ((MPLAYER_RC_VERSION != 0 || MPLAYER_PRE_VERSION != 0) && ((rc) != 0 || (pre) != 0) && (MPLAYER_RC_VERSION > (rc))) || \
-     ((MPLAYER_RC_VERSION != 0 || MPLAYER_PRE_VERSION != 0) && ((rc) != 0 || (pre) != 0) && MPLAYER_RC_VERSION == (rc) && MPLAYER_PRE_VERSION >= (pre)))))
+  (ogmrip_check_mplayer_version (major, minor, rc, pre))
+
+gboolean ogmrip_check_mplayer         (void);
+gboolean ogmrip_check_mencoder        (void);
+
+gboolean ogmrip_check_mplayer_version (gint major,
+                                       gint minor,
+                                       gint rc,
+                                       gint pre);
+gboolean ogmrip_check_mplayer_dts     (void);
+
+G_END_DECLS
 
 #endif /* __OGMRIP_VERSION_H__ */
 
