@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,10 +23,12 @@
 #include "ogmrip-vobsub.h"
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
+#include "ogmrip-version.h"
 
 #include "ogmjob-queue.h"
 #include "ogmjob-exec.h"
 
+#include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include <string.h>
@@ -37,15 +39,14 @@
 static gint ogmrip_vobsub_run      (OGMJobSpawn *spawn);
 static void ogmrip_vobsub_finalize (GObject     *gobject);
 
-G_DEFINE_TYPE (OGMRipVobSub, ogmrip_vobsub, OGMRIP_TYPE_SUBP)
+G_DEFINE_TYPE (OGMRipVobSub, ogmrip_vobsub, OGMRIP_TYPE_SUBP_CODEC)
 
 static gchar **
-ogmrip_vobsub_command (OGMRipSubp *subp, const gchar *input, const gchar *output)
+ogmrip_vobsub_command (OGMRipSubpCodec *subp, const gchar *input, const gchar *output)
 {
   GPtrArray *argv;
 
-  argv = ogmrip_mencoder_vobsub_command (subp, NULL, output);
-  g_ptr_array_add (argv, NULL);
+  argv = ogmrip_mencoder_vobsub_command (subp, output);
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
@@ -95,6 +96,108 @@ ogmrip_vobsub_finalize (GObject *gobject)
   G_OBJECT_CLASS (ogmrip_vobsub_parent_class)->finalize (gobject);
 }
 
+static gboolean
+ogmrip_vobsub_set_foo (OGMJobSpawn *spawn, const gchar *filename)
+{
+  GError *error;
+  gssize w;
+  gint fd;
+
+  fd = g_open (filename, O_WRONLY);
+  if (fd < 0)
+  {
+    error = g_error_new (G_FILE_ERROR, g_file_error_from_errno (errno),
+        "Cannot open file '%s': %s", filename, g_strerror (errno));
+    ogmjob_spawn_propagate_error (spawn, error);
+
+    return FALSE;
+  }
+
+  w = write (fd, "foo", 3);
+  close (fd);
+
+  if (w != 3)
+  {
+    error = g_error_new (G_FILE_ERROR, g_file_error_from_errno (errno),
+        "Cannot write to file '%s': %s", filename, g_strerror (errno));
+    ogmjob_spawn_propagate_error (spawn, error);
+
+    return FALSE;
+  }
+
+  return TRUE;
+}
+
+#define FORCED_SUBS_LINE "forced subs: ON"
+
+static gboolean
+ogmrip_vobsub_set_forced (OGMJobSpawn *spawn, const gchar *filename)
+{
+  GError *error = NULL;
+  gchar *content, **vline;
+
+  if (!g_file_get_contents (filename, &content, NULL, &error))
+  {
+    ogmjob_spawn_propagate_error (spawn, error);
+
+    return FALSE;
+  }
+
+  vline = g_strsplit_set (content, "\r\n", -1);
+  g_free (content);
+
+  if (vline)
+  {
+    gint fd, i, w, len;
+
+  g_message ("Set forced !");
+
+    fd = g_open (filename, O_WRONLY);
+    if (fd < 0)
+    {
+      error = g_error_new (G_FILE_ERROR, g_file_error_from_errno (errno),
+          "Cannot open file '%s': %s", filename, g_strerror (errno));
+      ogmjob_spawn_propagate_error (spawn, error);
+
+      return FALSE;
+    }
+
+    for (i = 0; vline[i]; i++)
+    {
+      g_message (">>%s<<\n", vline[i]);
+
+      if (g_ascii_strncasecmp (vline[i], "forced subs:", 12) == 0)
+      {
+        len = strlen (FORCED_SUBS_LINE);
+        w = write (fd, FORCED_SUBS_LINE, len);
+      }
+      else
+      {
+        len = strlen (vline[i]);
+        w = write (fd, vline[i], len);
+      }
+
+      if (w != len || write (fd, "\n", 1) != 1)
+      {
+        close (fd);
+        g_strfreev (vline);
+
+        error = g_error_new (G_FILE_ERROR, g_file_error_from_errno (errno),
+            "Cannot write to file '%s': %s", filename, g_strerror (errno));
+        ogmjob_spawn_propagate_error (spawn, error);
+
+        return FALSE;
+      }
+    }
+
+    close (fd);
+
+    g_strfreev (vline);
+  }
+
+  return TRUE;
+}
+
 static gint
 ogmrip_vobsub_run (OGMJobSpawn *spawn)
 {
@@ -102,7 +205,7 @@ ogmrip_vobsub_run (OGMJobSpawn *spawn)
   gchar **argv;
   gint result;
 
-  argv = ogmrip_vobsub_command (OGMRIP_SUBP (spawn), NULL, NULL);
+  argv = ogmrip_vobsub_command (OGMRIP_SUBP_CODEC (spawn), NULL, NULL);
   if (!argv)
     return OGMJOB_RESULT_ERROR;
 
@@ -122,14 +225,17 @@ ogmrip_vobsub_run (OGMJobSpawn *spawn)
     idxname = g_strconcat (basename, ".idx", NULL);
     subname = g_strconcat (basename, ".sub", NULL);
 
-    if ((g_file_test (idxname, G_FILE_TEST_IS_REGULAR) && g_stat (idxname, &buf) == 0 && buf.st_size > 0) &&
-        (g_file_test (subname, G_FILE_TEST_IS_REGULAR) && g_stat (subname, &buf) == 0 && buf.st_size > 0))
+    if ((g_file_test (idxname, G_FILE_TEST_IS_REGULAR) &&
+         g_stat (idxname, &buf) == 0 && buf.st_size > 0) &&
+        (g_file_test (subname, G_FILE_TEST_IS_REGULAR) &&
+         g_stat (subname, &buf) == 0 && buf.st_size > 0))
     {
-      gint fd;
+      if (!ogmrip_vobsub_set_foo (spawn, basename))
+        return OGMJOB_RESULT_ERROR;
 
-      fd = g_open (basename, O_WRONLY);
-      write (fd, "foo", 3);
-      close (fd);
+      if (ogmrip_subp_codec_get_forced_only (OGMRIP_SUBP_CODEC (spawn)) &&
+          !ogmrip_vobsub_set_forced (spawn, idxname))
+        return OGMJOB_RESULT_ERROR;
     }
 
     g_free (idxname);
@@ -159,7 +265,7 @@ ogmrip_vobsub_new (OGMDvdSubpStream *subp, const gchar *output)
   return g_object_new (OGMRIP_TYPE_VOBSUB, "stream", subp, "output", output, NULL);
 }
 
-static OGMRipPluginContainer vobsub_plugin =
+static OGMRipSubpPlugin vobsub_plugin =
 {
   NULL,
   G_TYPE_NONE,
@@ -169,9 +275,12 @@ static OGMRipPluginContainer vobsub_plugin =
   FALSE
 };
 
-OGMRipPluginContainer *
+OGMRipSubpPlugin *
 ogmrip_init_plugin (void)
 {
+  if (!ogmrip_check_mencoder ())
+    return NULL;
+
   vobsub_plugin.type = OGMRIP_TYPE_VOBSUB;
 
   return &vobsub_plugin;
