@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,7 +19,7 @@
 #ifndef __OGMRIP_VOBSUB_H__
 #define __OGMRIP_VOBSUB_H__
 
-#include <ogmrip-subp.h>
+#include <ogmrip-subp-codec.h>
 
 G_BEGIN_DECLS
 
@@ -30,19 +30,16 @@ G_BEGIN_DECLS
 #define OGMRIP_IS_VOBSUB_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_VOBSUB))
 
 typedef struct _OGMRipVobSub      OGMRipVobSub;
-typedef struct _OGMRipVobSubPriv  OGMRipVobSubPriv;
 typedef struct _OGMRipVobSubClass OGMRipVobSubClass;
 
 struct _OGMRipVobSub
 {
-  OGMRipSubp parent_instance;
-
-  OGMRipVobSubPriv *priv;
+  OGMRipSubpCodec parent_instance;
 };
 
 struct _OGMRipVobSubClass
 {
-  OGMRipSubpClass parent_class;
+  OGMRipSubpCodecClass parent_class;
 };
 
 GType         ogmrip_vobsub_get_type  (void);
