@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,10 +20,11 @@
 #include "config.h"
 #endif
 
-#include "ogmrip-vorbis.h"
+#include "ogmrip-fs.h"
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
-#include "ogmrip-fs.h"
+#include "ogmrip-version.h"
+#include "ogmrip-vorbis.h"
 
 #include "ogmjob-pipeline.h"
 #include "ogmjob-exec.h"
@@ -32,32 +33,41 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#define PROGRAM "oggenc"
+
 static gint ogmrip_vorbis_run (OGMJobSpawn *spawn);
 
 gchar **
-ogmrip_vorbis_command (OGMRipAudio *audio, const gchar *input, const gchar *output)
+ogmrip_vorbis_command (OGMRipAudioCodec *audio, gboolean header, const gchar *input, const gchar *output)
 {
   GPtrArray *argv;
   gint quality;
 
-  g_return_val_if_fail (OGMRIP_IS_AUDIO (audio), NULL);
+  g_return_val_if_fail (OGMRIP_IS_AUDIO_CODEC (audio), NULL);
   g_return_val_if_fail (input != NULL, NULL);
 
   if (!output)
     output = ogmrip_codec_get_output (OGMRIP_CODEC (audio));
   g_return_val_if_fail (output != NULL, NULL);
 
-  quality = ogmrip_audio_get_quality (audio);
+  quality = ogmrip_audio_codec_get_quality (audio);
 
   argv = g_ptr_array_new ();
-  g_ptr_array_add (argv, g_strdup ("oggenc"));
-  g_ptr_array_add (argv, g_strdup ("-r"));
-  g_ptr_array_add (argv, g_strdup ("-R"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_audio_get_sample_rate (audio)));
+  g_ptr_array_add (argv, g_strdup (PROGRAM));
+
+  if (!header)
+  {
+    g_ptr_array_add (argv, g_strdup ("-r"));
+    g_ptr_array_add (argv, g_strdup ("-R"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d",
+          ogmrip_audio_codec_get_sample_rate (audio)));
+    g_ptr_array_add (argv, g_strdup ("-C"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d",
+          ogmrip_audio_codec_get_channels (audio) + 1));
+  }
+
   g_ptr_array_add (argv, g_strdup ("-q"));
   g_ptr_array_add (argv, g_strdup_printf ("%d", quality));
-  g_ptr_array_add (argv, g_strdup ("-C"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", ogmrip_audio_get_channels (audio) + 1));
   g_ptr_array_add (argv, g_strdup ("-o"));
   g_ptr_array_add (argv, g_strdup (output));
   g_ptr_array_add (argv, g_strdup (input));
@@ -67,17 +77,16 @@ ogmrip_vorbis_command (OGMRipAudio *audio, const gchar *input, const gchar *outp
 }
 
 static gchar **
-ogmrip_wav_command (OGMRipAudio *audio, gboolean header, const gchar *input, const gchar *output)
+ogmrip_wav_command (OGMRipAudioCodec *audio, gboolean header, const gchar *input, const gchar *output)
 {
   GPtrArray *argv;
 
-  argv = ogmrip_mplayer_wav_command (audio, FALSE, NULL, output);
-  g_ptr_array_add (argv, NULL);
+  argv = ogmrip_mplayer_wav_command (audio, header, output);
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
 
-G_DEFINE_TYPE (OGMRipVorbis, ogmrip_vorbis, OGMRIP_TYPE_AUDIO)
+G_DEFINE_TYPE (OGMRipVorbis, ogmrip_vorbis, OGMRIP_TYPE_AUDIO_CODEC)
 
 static void
 ogmrip_vorbis_class_init (OGMRipVorbisClass *klass)
@@ -97,6 +106,7 @@ ogmrip_vorbis_init (OGMRipVorbis *vorbis)
 static gint
 ogmrip_vorbis_run (OGMJobSpawn *spawn)
 {
+  GError *error = NULL;
   OGMJobSpawn *pipeline;
   OGMJobSpawn *child;
   gchar **argv, *fifo;
@@ -104,13 +114,18 @@ ogmrip_vorbis_run (OGMJobSpawn *spawn)
 
   result = OGMJOB_RESULT_ERROR;
 
-  fifo = ogmrip_fs_mkftemp ("fifo.XXXXXX", NULL);
+  fifo = ogmrip_fs_mkftemp ("fifo.XXXXXX", &error);
+  if (!fifo)
+  {
+    ogmjob_spawn_propagate_error (spawn, error);
+    return OGMJOB_RESULT_ERROR;
+  }
 
   pipeline = ogmjob_pipeline_new ();
   ogmjob_container_add (OGMJOB_CONTAINER (spawn), pipeline);
   g_object_unref (pipeline);
 
-  argv = ogmrip_wav_command (OGMRIP_AUDIO (spawn), FALSE, NULL, fifo);
+  argv = ogmrip_wav_command (OGMRIP_AUDIO_CODEC (spawn), TRUE, NULL, fifo);
   if (argv)
   {
     child = ogmjob_exec_newv (argv);
@@ -118,7 +133,7 @@ ogmrip_vorbis_run (OGMJobSpawn *spawn)
     ogmjob_container_add (OGMJOB_CONTAINER (pipeline), child);
     g_object_unref (child);
 
-    argv = ogmrip_vorbis_command (OGMRIP_AUDIO (spawn), fifo, NULL);
+    argv = ogmrip_vorbis_command (OGMRIP_AUDIO_CODEC (spawn), TRUE, fifo, NULL);
     if (argv)
     {
       child = ogmjob_exec_newv (argv);
@@ -156,7 +171,7 @@ ogmrip_vorbis_new (OGMDvdAudioStream *audio, const gchar *output)
   return g_object_new (OGMRIP_TYPE_VORBIS, "stream", audio, "output", output, NULL);
 }
 
-static OGMRipPluginAudioCodec vorbis_plugin =
+static OGMRipAudioPlugin vorbis_plugin =
 {
   NULL,
   G_TYPE_NONE,
@@ -165,9 +180,19 @@ static OGMRipPluginAudioCodec vorbis_plugin =
   OGMRIP_FORMAT_VORBIS
 };
 
-OGMRipPluginAudioCodec *
+OGMRipAudioPlugin *
 ogmrip_init_plugin (void)
 {
+  gchar *fullname;
+
+  if (!ogmrip_check_mplayer ())
+    return NULL;
+
+  fullname = g_find_program_in_path (PROGRAM);
+  if (!fullname)
+    return NULL;
+  g_free (fullname);
+
   vorbis_plugin.type = OGMRIP_TYPE_VORBIS;
 
   return &vorbis_plugin;
