@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,9 +20,10 @@
 #include "config.h"
 #endif
 
-#include "ogmrip-wav.h"
 #include "ogmrip-mplayer.h"
 #include "ogmrip-plugin.h"
+#include "ogmrip-version.h"
+#include "ogmrip-wav.h"
 
 #include "ogmjob-exec.h"
 
@@ -39,15 +40,14 @@ struct _OGMRipWavPriv
 
 static gint ogmrip_wav_run (OGMJobSpawn *spawn);
 
-G_DEFINE_TYPE (OGMRipWav, ogmrip_wav, OGMRIP_TYPE_AUDIO)
+G_DEFINE_TYPE (OGMRipWav, ogmrip_wav, OGMRIP_TYPE_AUDIO_CODEC)
 
 static gchar **
-ogmrip_wav_command (OGMRipAudio *audio, gboolean header, const gchar *input, const gchar *output)
+ogmrip_wav_command (OGMRipAudioCodec *audio, gboolean header, const gchar *input, const gchar *output)
 {
   GPtrArray *argv;
 
-  argv = ogmrip_mplayer_wav_command (audio, FALSE, NULL, output);
-  g_ptr_array_add (argv, NULL);
+  argv = ogmrip_mplayer_wav_command (audio, FALSE, output);
 
   return (gchar **) g_ptr_array_free (argv, FALSE);
 }
@@ -78,7 +78,7 @@ ogmrip_wav_run (OGMJobSpawn *spawn)
   gchar **argv;
   gint result;
 
-  argv = ogmrip_wav_command (OGMRIP_AUDIO (spawn), 
+  argv = ogmrip_wav_command (OGMRIP_AUDIO_CODEC (spawn), 
       OGMRIP_WAV (spawn)->priv->header, NULL, NULL);
   if (!argv)
     return OGMJOB_RESULT_ERROR;
@@ -144,7 +144,7 @@ ogmrip_wav_get_header (OGMRipWav *wav)
   return wav->priv->header;
 }
 
-static OGMRipPluginAudioCodec wav_plugin =
+static OGMRipAudioPlugin wav_plugin =
 {
   NULL,
   G_TYPE_NONE,
@@ -153,9 +153,12 @@ static OGMRipPluginAudioCodec wav_plugin =
   OGMRIP_FORMAT_PCM
 };
 
-OGMRipPluginAudioCodec *
+OGMRipAudioPlugin *
 ogmrip_init_plugin (void)
 {
+  if (!ogmrip_check_mplayer ())
+    return NULL;
+
   wav_plugin.type = OGMRIP_TYPE_WAV;
 
   return &wav_plugin;
