@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,7 +19,7 @@
 #ifndef __OGMRIP_WAV_H__
 #define __OGMRIP_WAV_H__
 
-#include <ogmrip-audio.h>
+#include <ogmrip-audio-codec.h>
 
 G_BEGIN_DECLS
 
@@ -35,14 +35,14 @@ typedef struct _OGMRipWavClass OGMRipWavClass;
 
 struct _OGMRipWav
 {
-  OGMRipAudio parent_instance;
+  OGMRipAudioCodec parent_instance;
 
   OGMRipWavPriv *priv;
 };
 
 struct _OGMRipWavClass
 {
-  OGMRipAudioClass parent_class;
+  OGMRipAudioCodecClass parent_class;
 };
 
 GType         ogmrip_wav_get_type   (void);
