@@ -1,5 +1,5 @@
 /* OGMRip - A library for DVD ripping and encoding
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,7 +19,7 @@
 #ifndef __OGMRIP_X264_H__
 #define __OGMRIP_X264_H__
 
-#include <ogmrip-video.h>
+#include <ogmrip-video-codec.h>
 
 G_BEGIN_DECLS
 
@@ -35,14 +35,14 @@ typedef struct _OGMRipX264Class OGMRipX264Class;
 
 struct _OGMRipX264
 {
-  OGMRipVideo parent_instance;
+  OGMRipVideoCodec parent_instance;
 
   OGMRipX264Priv *priv;
 };
 
 struct _OGMRipX264Class
 {
-  OGMRipVideoClass parent_class;
+  OGMRipVideoCodecClass parent_class;
 };
 
 GType         ogmrip_x264_get_type   (void);
