@@ -19,7 +19,7 @@
 #ifndef __OGMRIP_H__
 #define __OGMRIP_H__
 
-#include <ogmrip-audio.h>
+#include <ogmrip-audio-codec.h>
 #include <ogmrip-chapters.h>
 #include <ogmrip-container.h>
 #include <ogmrip-dvdcpy.h>
@@ -28,8 +28,8 @@
 #include <ogmrip-file.h>
 #include <ogmrip-fs.h>
 #include <ogmrip-plugin.h>
-#include <ogmrip-subp.h>
+#include <ogmrip-subp-codec.h>
 #include <ogmrip-version.h>
-#include <ogmrip-video.h>
+#include <ogmrip-video-codec.h>
 
 #endif /* __OGMRIP_H__ */
