@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -90,40 +90,12 @@ ogmrip_crop_dialog_crop_frame (OGMRipCropDialog *dialog)
   }
 }
 
-static gint
-ogmrip_crop_dialog_get_chapter (OGMDvdTitle *title, gulong *frame)
-{
-  gdouble framerate;
-  guint numerator, denominator;
-  gint i, last_chapter;
-  gulong length;
-
-  g_return_val_if_fail (title != NULL, -1);
-
-  ogmdvd_title_get_framerate (title, &numerator, &denominator);
-  framerate = numerator / (gdouble) denominator;
-
-  last_chapter = ogmdvd_title_get_n_chapters (title);
-
-  for (i = 0; i < last_chapter; i++)
-  {
-    length = ogmdvd_title_get_chapters_length (title, i, i, NULL) * framerate;
-
-    if (length >= *frame)
-      return i + 1;
-
-    *frame -= length;
-  }
-
-  return i;
-}
-
 static gchar **
 ogmrip_crop_dialog_grab_command (OGMRipCropDialog *dialog, gulong frame)
 {
   GPtrArray *argv;
   const gchar *device;
-  gint chap, vid, time_;
+  gint vid, time_;
 
   argv = g_ptr_array_new ();
   g_ptr_array_add (argv, g_strdup ("mplayer"));
@@ -134,25 +106,32 @@ ogmrip_crop_dialog_grab_command (OGMRipCropDialog *dialog, gulong frame)
 
   g_ptr_array_add (argv, g_strdup ("-vo"));
 
-#if MPLAYER_CHECK_VERSION(1,0,0,6)
-  g_ptr_array_add (argv, g_strdup_printf ("jpeg:outdir=%s", ogmrip_fs_get_tmp_dir ()));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,6) */
-  g_ptr_array_add (argv, g_strdup ("jpeg"));
-  g_ptr_array_add (argv, g_strdup ("-jpeg"));
-  g_ptr_array_add (argv, g_strdup_printf ("outdir=%s", ogmrip_fs_get_tmp_dir ()));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,6) */
+  if (MPLAYER_CHECK_VERSION (1,0,0,6))
+    g_ptr_array_add (argv, g_strdup_printf ("jpeg:outdir=%s", ogmrip_fs_get_tmp_dir ()));
+  else
+  {
+    g_ptr_array_add (argv, g_strdup ("jpeg"));
+    g_ptr_array_add (argv, g_strdup ("-jpeg"));
+    g_ptr_array_add (argv, g_strdup_printf ("outdir=%s", ogmrip_fs_get_tmp_dir ()));
+  }
 
-#if MPLAYER_CHECK_VERSION(1,0,0,8)
-  g_ptr_array_add (argv, g_strdup ("-vc"));
-  g_ptr_array_add (argv, g_strdup ("ffmpeg12"));
-  g_ptr_array_add (argv, g_strdup ("-frames"));
-  g_ptr_array_add (argv, g_strdup ("1"));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,8) */
-  g_ptr_array_add (argv, g_strdup ("-frames"));
-  g_ptr_array_add (argv, g_strdup ("3"));
-  g_ptr_array_add (argv, g_strdup ("-sstep"));
-  g_ptr_array_add (argv, g_strdup ("1"));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
+  if (MPLAYER_CHECK_VERSION (1,0,0,8))
+  {
+    g_ptr_array_add (argv, g_strdup ("-vc"));
+    g_ptr_array_add (argv, g_strdup ("ffmpeg12"));
+    g_ptr_array_add (argv, g_strdup ("-frames"));
+    g_ptr_array_add (argv, g_strdup ("1"));
+  }
+  else
+  {
+    g_ptr_array_add (argv, g_strdup ("-frames"));
+    g_ptr_array_add (argv, g_strdup ("3"));
+    g_ptr_array_add (argv, g_strdup ("-sstep"));
+    g_ptr_array_add (argv, g_strdup ("1"));
+  }
+
+  g_ptr_array_add (argv, g_strdup ("-speed"));
+  g_ptr_array_add (argv, g_strdup ("100"));
 
   if (dialog->priv->deint)
   {
@@ -160,10 +139,6 @@ ogmrip_crop_dialog_grab_command (OGMRipCropDialog *dialog, gulong frame)
     g_ptr_array_add (argv, g_strdup ("pp=lb"));
   }
 
-  chap = ogmrip_crop_dialog_get_chapter (dialog->priv->title, &frame);
-  g_ptr_array_add (argv, g_strdup ("-chapter"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", chap));
-
   time_ = (gint) (frame * dialog->priv->rate_denominator / (gdouble) dialog->priv->rate_numerator);
   g_ptr_array_add (argv, g_strdup ("-ss"));
   g_ptr_array_add (argv, g_strdup_printf ("%u", time_));
@@ -174,12 +149,13 @@ ogmrip_crop_dialog_grab_command (OGMRipCropDialog *dialog, gulong frame)
 
   vid = ogmdvd_title_get_nr (dialog->priv->title);
 
-#if MPLAYER_CHECK_VERSION(1,0,0,1)
-  g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
-#else /* MPLAYER_CHECK_VERSION(1,0,0,8) */
-  g_ptr_array_add (argv, g_strdup ("-dvd"));
-  g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
+  if (MPLAYER_CHECK_VERSION (1,0,0,1))
+    g_ptr_array_add (argv, g_strdup_printf ("dvd://%d", vid + 1));
+  else
+  {
+    g_ptr_array_add (argv, g_strdup ("-dvd"));
+    g_ptr_array_add (argv, g_strdup_printf ("%d", vid + 1));
+  }
 
   g_ptr_array_add (argv, NULL);
 
@@ -199,19 +175,20 @@ ogmrip_crop_dialog_grab_frame (OGMRipCropDialog *dialog, gulong frame)
   {
     gchar *filename;
 
-#if MPLAYER_CHECK_VERSION(1,0,0,8)
-    filename = g_build_filename (ogmrip_fs_get_tmp_dir (), "00000001.jpg", NULL);
-#else /* MPLAYER_CHECK_VERSION(1,0,0,8) */
-    filename = g_build_filename (ogmrip_fs_get_tmp_dir (), "00000001.jpg", NULL);
-    g_unlink (filename);
-    g_free (filename);
+    if (MPLAYER_CHECK_VERSION (1,0,0,8))
+      filename = g_build_filename (ogmrip_fs_get_tmp_dir (), "00000001.jpg", NULL);
+    else
+    {
+      filename = g_build_filename (ogmrip_fs_get_tmp_dir (), "00000001.jpg", NULL);
+      g_unlink (filename);
+      g_free (filename);
 
-    filename = g_build_filename (ogmrip_fs_get_tmp_dir (), "00000003.jpg", NULL);
-    g_unlink (filename);
-    g_free (filename);
+      filename = g_build_filename (ogmrip_fs_get_tmp_dir (), "00000003.jpg", NULL);
+      g_unlink (filename);
+      g_free (filename);
 
-    filename = g_build_filename (ogmrip_fs_get_tmp_dir (), "00000002.jpg", NULL);
-#endif /* MPLAYER_CHECK_VERSION(1,0,0,8) */
+      filename = g_build_filename (ogmrip_fs_get_tmp_dir (), "00000002.jpg", NULL);
+    }
 
     if (g_file_test (filename, G_FILE_TEST_IS_REGULAR))
     {
