@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,15 +20,20 @@
 
 #include "ogmdvd.h"
 
+#include "ogmrip-gconf.h"
 #include "ogmrip-options.h"
 #include "ogmrip-helper.h"
 #include "ogmrip-plugin.h"
+#include "ogmrip-preferences.h"
+#include "ogmrip-profiles.h"
 #include "ogmrip-crop.h"
 #include "ogmrip-lavc.h"
 
 #include <glib/gi18n.h>
 #include <glade/glade.h>
 
+#include <string.h>
+
 #define OGMRIP_GLADE_FILE "ogmrip/ogmrip-options.glade"
 #define OGMRIP_GLADE_ROOT "root"
 
@@ -37,6 +42,19 @@
 #define OGMRIP_OPTIONS_DIALOG_GET_PRIVATE(o) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((o), OGMRIP_TYPE_OPTIONS_DIALOG, OGMRipOptionsDialogPriv))
 
+enum
+{
+  COL_NAME,
+  COL_KEY,
+  COL_LAST
+};
+
+enum
+{
+  EDIT_CLICKED,
+  LAST_SIGNAL
+};
+
 enum
 {
   OGMRIP_SCALE_NONE,
@@ -53,8 +71,7 @@ struct _OGMRipOptionsDialogPriv
 {
   OGMDvdTitle *title;
 
-  GtkWidget *bitrate_check;
-  GtkWidget *bitrate_spin;
+  GtkWidget *profile_combo;
 
   GtkWidget *crop_check;
   GtkWidget *crop_left_label;
@@ -70,19 +87,228 @@ struct _OGMRipOptionsDialogPriv
   GtkWidget *autoscale_button;
   GtkListStore *scale_store;
 
-  GtkWidget *more_exp;
   GtkWidget *ntsc_frame;
-  GtkWidget *bpp_spin;
   GtkWidget *cartoon_check;
-
-  GtkWidget *deint_combo;
-  GtkWidget *framestep_combo;
   GtkWidget *progressive_check;
-  GtkWidget *pullup_check;
+  GtkWidget *telecine_check;
+  GtkWidget *deint_check;
 };
 
 static void ogmrip_options_dialog_dispose (GObject *gobject);
 
+static int signals[LAST_SIGNAL] = { 0 };
+
+static gboolean
+ogmrip_options_dialog_combo_get_iter (GtkTreeModel *model, GtkTreeIter *iter, const gchar *key)
+{
+  gboolean found = FALSE;
+
+  if (gtk_tree_model_iter_children (model, iter, NULL))
+  {
+    gchar *str;
+
+    do
+    {
+      gtk_tree_model_get (model, iter, COL_KEY, &str, -1);
+      if (g_str_equal (key, str))
+        found = TRUE;
+      g_free (str);
+    }
+    while (!found && gtk_tree_model_iter_next (model, iter));
+  }
+
+  return found;
+}
+
+static void
+ogmrip_options_dialog_combo_set_active (GtkWidget *combo, const gchar *profile)
+{
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+
+  model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+  if (model && gtk_tree_model_iter_children (model, &iter, NULL))
+  {
+    gchar *key;
+    do
+    {
+      gtk_tree_model_get (model, &iter, COL_KEY, &key, -1);
+      if (profile && g_str_has_suffix (key, profile))
+      {
+        gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &iter);
+        g_free (key);
+        break;
+      }
+      g_free (key);
+    }
+    while (gtk_tree_model_iter_next (model, &iter));
+
+    if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter))
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+  }
+}
+
+static GConfValue *
+ogmrip_options_dialog_combo_get_value (GtkWidget *combo)
+{
+  GConfValue *value;
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+  gchar *key;
+
+  if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combo), &iter))
+    return NULL;
+
+  model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+  if (!model)
+    return NULL;
+
+  gtk_tree_model_get (model, &iter, COL_KEY, &key, -1);
+
+  value = gconf_value_new (GCONF_VALUE_STRING);
+  gconf_value_set_string (value, strrchr (key, '/') + 1);
+  g_free (key);
+
+  return value;
+}
+
+static gboolean
+ogmrip_options_dialog_profile_set_value (GtkWidget *combo, GConfValue *value)
+{
+  if (!value)
+    return FALSE;
+
+  ogmrip_options_dialog_combo_set_active (combo,
+      gconf_value_get_string (value));
+
+  return TRUE;
+}
+
+static void
+ogmrip_options_dialog_connect_profile (GtkWidget *widget, const gchar *key, const gchar *def)
+{
+  GConfValue *value;
+
+  value = ogmrip_preferences_get (key);
+  if (value)
+    gconf_value_free (value);
+  else
+    ogmrip_preferences_set_string (key, def);
+
+  if (widget)
+    ogmrip_preferences_connect_combo_custom (widget, key,
+        ogmrip_options_dialog_combo_get_value,
+        ogmrip_options_dialog_profile_set_value);
+}
+
+static gint
+ogmrip_options_dialog_compare_profiles (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, OGMRipProfilesDialog *dialog)
+{
+  gchar *aname, *bname;
+  gint ret;
+
+  gtk_tree_model_get (model, a, COL_NAME, &aname, -1);
+  gtk_tree_model_get (model, b, COL_NAME, &bname, -1);
+
+  ret = g_utf8_collate (aname, bname);
+
+  g_free (aname);
+  g_free (bname);
+
+  return ret;
+}
+
+static void
+ogmrip_options_dialog_construct_profiles_combo (OGMRipOptionsDialog *dialog, GtkWidget *combo)
+{
+  GtkListStore *store;
+  GtkCellRenderer *cell;
+
+  store = gtk_list_store_new (COL_LAST, G_TYPE_STRING, G_TYPE_STRING);
+  gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+  g_object_unref (store);
+
+  cell = gtk_cell_renderer_text_new ();
+  gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), cell, TRUE);
+  gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), cell, "markup", COL_NAME, NULL);
+
+  gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (store), COL_NAME,
+      (GtkTreeIterCompareFunc) ogmrip_options_dialog_compare_profiles, dialog, NULL);
+  gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store),
+      COL_NAME, GTK_SORT_ASCENDING);
+}
+
+void
+ogmrip_options_dialog_clear_profiles (OGMRipOptionsDialog *dialog)
+{
+  GtkTreeModel *model;
+
+  if (dialog->priv)
+  {
+    model = gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->priv->profile_combo));
+    if (model)
+      gtk_list_store_clear (GTK_LIST_STORE (model));
+  }
+}
+
+void
+ogmrip_options_dialog_add_profile (OGMRipOptionsDialog *dialog, const gchar *name, const gchar *key)
+{
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+
+  model = gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->priv->profile_combo));
+  gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+  gtk_list_store_set (GTK_LIST_STORE (model), &iter, COL_NAME, name, COL_KEY, key, -1);
+
+  gtk_combo_box_set_active_iter (GTK_COMBO_BOX (dialog->priv->profile_combo), &iter);
+
+  gtk_widget_set_sensitive (dialog->priv->profile_combo, TRUE);
+}
+
+void
+ogmrip_options_dialog_remove_profile (OGMRipOptionsDialog *dialog, const gchar *name, const gchar *key)
+{
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+
+  model = gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->priv->profile_combo));
+  if (ogmrip_options_dialog_combo_get_iter (model, &iter, key))
+  {
+    gboolean has_child;
+
+    gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+
+    has_child = gtk_tree_model_iter_n_children (model, NULL) > 0;
+    if (!has_child)
+       ogmrip_preferences_set_string (OGMRIP_GCONF_PROFILE, OGMRIP_DEFAULT_PROFILE);
+    else
+    {
+      if (gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->profile_combo)) < 0)
+        gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->profile_combo), 0);
+    }
+
+    gtk_widget_set_sensitive (dialog->priv->profile_combo, has_child);
+  }
+}
+
+void
+ogmrip_options_dialog_rename_profile (OGMRipOptionsDialog *dialog, const gchar *name, const gchar *key)
+{
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+
+  model = gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->priv->profile_combo));
+  if (ogmrip_options_dialog_combo_get_iter (model, &iter, key))
+    gtk_list_store_set (GTK_LIST_STORE (model), &iter, COL_NAME, name, -1);
+}
+
+static void
+ogmrip_options_dialog_edit_profiles_button_clicked (OGMRipOptionsDialog *dialog)
+{
+  g_signal_emit (dialog, signals[EDIT_CLICKED], 0);
+}
+
 static gint
 ogmrip_options_dialog_get_crop_internal (OGMRipOptionsDialog *dialog, guint *x, guint *y, guint *width, guint *height)
 {
@@ -229,21 +455,14 @@ ogmrip_options_dialog_autoscale_clicked (OGMRipOptionsDialog *dialog)
     OGMJobSpawn *spawn;
     guint scale_width, scale_height;
     guint crop_x, crop_y, crop_width, crop_height;
-    guint bitrate;
 
     spawn = g_object_new (codec, "input", dialog->priv->title, NULL);
 
     ogmrip_options_dialog_get_crop_internal (dialog, &crop_x, &crop_y, &crop_width, &crop_height);
-    ogmrip_video_set_crop_size (OGMRIP_VIDEO (spawn), crop_x, crop_y, crop_width, crop_height);
+    ogmrip_video_codec_set_crop_size (OGMRIP_VIDEO_CODEC (spawn), crop_x, crop_y, crop_width, crop_height);
 
-    if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->bitrate_check)))
-    {
-      bitrate = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (dialog->priv->bitrate_spin));
-      ogmrip_video_set_bitrate (OGMRIP_VIDEO (spawn), bitrate);
-    }
-
-    ogmrip_video_autoscale (OGMRIP_VIDEO (spawn));
-    ogmrip_video_get_scale_size (OGMRIP_VIDEO (spawn), &scale_width, &scale_height);
+    ogmrip_video_codec_autoscale (OGMRIP_VIDEO_CODEC (spawn));
+    ogmrip_video_codec_get_scale_size (OGMRIP_VIDEO_CODEC (spawn), &scale_width, &scale_height);
     g_object_unref (spawn);
 
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (dialog->priv->scale_width_spin), (gdouble) scale_width);
@@ -269,8 +488,8 @@ ogmrip_options_dialog_crop_clicked (OGMRipOptionsDialog *dialog)
   g_signal_connect (crop_dialog, "delete-event", G_CALLBACK (gtk_true), NULL);
   g_signal_connect (crop_dialog, "response", G_CALLBACK (gtk_widget_hide), NULL);
 
-  if (gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->deint_combo)))
-    ogmrip_crop_dialog_set_deinterlacer (OGMRIP_CROP_DIALOG (crop_dialog), TRUE);
+  ogmrip_crop_dialog_set_deinterlacer (OGMRIP_CROP_DIALOG (crop_dialog),
+      gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->deint_check)));
 
   if (gtk_dialog_run (GTK_DIALOG (crop_dialog)) == GTK_RESPONSE_OK)
   {
@@ -314,11 +533,14 @@ ogmrip_options_dialog_autocrop_clicked (OGMRipOptionsDialog *dialog)
     gtk_widget_show (msg_dialog);
 
     spawn = g_object_new (codec, "input", dialog->priv->title, NULL);
-    ogmrip_video_set_deinterlacer (OGMRIP_VIDEO (spawn),
-        gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->deint_combo)));
 
-    ogmrip_video_autocrop (OGMRIP_VIDEO (spawn), 0);
-    ogmrip_video_get_crop_size (OGMRIP_VIDEO (spawn), &new_x, &new_y, &new_width, &new_height);
+    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->deint_check)))
+      ogmrip_video_codec_set_deinterlacer (OGMRIP_VIDEO_CODEC (spawn), OGMRIP_DEINT_YADIF);
+    else
+      ogmrip_video_codec_set_deinterlacer (OGMRIP_VIDEO_CODEC (spawn), OGMRIP_DEINT_NONE);
+
+    ogmrip_video_codec_autocrop (OGMRIP_VIDEO_CODEC (spawn), 0);
+    ogmrip_video_codec_get_crop_size (OGMRIP_VIDEO_CODEC (spawn), &new_x, &new_y, &new_width, &new_height);
     g_object_unref (spawn);
 
     gtk_widget_destroy (msg_dialog);
@@ -350,36 +572,61 @@ ogmrip_options_dialog_autocrop_clicked (OGMRipOptionsDialog *dialog)
     }
   }
 }
-
-static void
-ogmrip_options_dialog_ccheck_clicked (OGMRipOptionsDialog *dialog)
-{
-  gtk_dialog_response (GTK_DIALOG (dialog), OGMRIP_OPTIONS_CCHECK);
-}
-
+/*
 static void
 ogmrip_options_dialog_check_toggled (GtkWidget *check, GtkWidget *widget)
 {
-  gtk_widget_set_sensitive (widget, 
-      gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)));
-}
+  gboolean active;
 
+  active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
+
+  g_object_set (G_OBJECT (widget), "visible", active, "sensitive", active, NULL);
+}
+*/
 static void
 ogmrip_options_dialog_check_untoggled (GtkWidget *check, GtkWidget *widget)
 {
-  gtk_widget_set_sensitive (widget, 
-      !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)));
+  gboolean active;
+  
+  active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
+
+  g_object_set (G_OBJECT (widget), "visible", !active, "sensitive", !active, NULL);
 }
 
 static void
-ogmrip_options_dialog_bitrate_or_crop_toggled (OGMRipOptionsDialog *dialog)
+ogmrip_options_dialog_profile_notified (GConfValue *value, OGMRipOptionsDialog *dialog)
 {
-  gboolean active;
+  gchar *dir, *key;
+  gboolean can_scale, can_crop;
 
-  active = (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->bitrate_check)) &
-    !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->crop_check)));
+  if (value)
+    dir = gconf_concat_dir_and_key (OGMRIP_GCONF_PROFILES, gconf_value_get_string (value));
+  else
+  {
+    gchar *profile;
 
-  gtk_widget_set_sensitive (dialog->priv->autoscale_button, active);
+    profile = ogmrip_preferences_get_string (OGMRIP_GCONF_PROFILE, OGMRIP_DEFAULT_PROFILE);
+    dir = gconf_concat_dir_and_key (OGMRIP_GCONF_PROFILES, profile);
+    g_free (profile);
+  }
+
+  key = gconf_concat_dir_and_key (dir, OGMRIP_GCONF_VIDEO_CAN_SCALE);
+  can_scale = ogmrip_preferences_get_bool (key, OGMRIP_DEFAULT_VIDEO_CAN_SCALE);
+  g_free (key);
+
+  gtk_widget_set_sensitive (dialog->priv->scale_check, can_scale);
+  if (!can_scale)
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->scale_check), TRUE);
+
+  key = gconf_concat_dir_and_key (dir, OGMRIP_GCONF_VIDEO_CAN_CROP);
+  can_crop = ogmrip_preferences_get_bool (key, OGMRIP_DEFAULT_VIDEO_CAN_CROP);
+  g_free (key);
+
+  gtk_widget_set_sensitive (dialog->priv->crop_check, can_crop);
+  if (!can_crop)
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->crop_check), TRUE);
+
+  g_free (dir);
 }
 
 G_DEFINE_TYPE (OGMRipOptionsDialog, ogmrip_options_dialog, GTK_TYPE_DIALOG);
@@ -391,6 +638,12 @@ ogmrip_options_dialog_class_init (OGMRipOptionsDialogClass *klass)
 
   gobject_class->dispose = ogmrip_options_dialog_dispose;
 
+  signals[EDIT_CLICKED] = g_signal_new ("edit-clicked", G_TYPE_FROM_CLASS (klass), 
+      G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+      G_STRUCT_OFFSET (OGMRipOptionsDialogClass, edit_clicked), NULL, NULL,
+      g_cclosure_marshal_VOID__VOID,
+      G_TYPE_NONE, 0);
+
   g_type_class_add_private (klass, sizeof (OGMRipOptionsDialogPriv));
 }
 
@@ -415,38 +668,36 @@ ogmrip_options_dialog_init (OGMRipOptionsDialog *dialog)
     return;
   }
 
-  gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+  gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT);
 
   widget = gtk_button_new_with_image (_("E_xtract"), GTK_STOCK_CONVERT);
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), widget, OGMRIP_OPTIONS_EXTRACT);
+  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), widget, GTK_RESPONSE_ACCEPT);
   gtk_widget_show (widget);
 
+  GTK_WIDGET_SET_FLAGS (widget, GTK_CAN_DEFAULT);
+
   gtk_window_set_title (GTK_WINDOW (dialog), _("Options"));
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_PROPERTIES);
 
   widget = glade_xml_get_widget (xml, OGMRIP_GLADE_ROOT);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), widget, TRUE, TRUE, 0);
   gtk_widget_show (widget);
 
-  dialog->priv->bitrate_check = glade_xml_get_widget (xml, "bitrate-check");
-  widget = glade_xml_get_widget (xml,"bitrate-vbox");
-  g_signal_connect (dialog->priv->bitrate_check, "toggled", 
-      G_CALLBACK (ogmrip_options_dialog_check_untoggled), widget);
-  g_signal_connect_swapped (dialog->priv->bitrate_check, "toggled", 
-      G_CALLBACK (ogmrip_options_dialog_bitrate_or_crop_toggled), dialog);
+  dialog->priv->profile_combo = glade_xml_get_widget (xml, "profile-combo");
+  ogmrip_options_dialog_construct_profiles_combo (dialog, dialog->priv->profile_combo);
+  ogmrip_options_dialog_connect_profile (dialog->priv->profile_combo,
+      OGMRIP_GCONF_PROFILE, OGMRIP_DEFAULT_PROFILE);
 
-  dialog->priv->bitrate_spin = glade_xml_get_widget (xml, "bitrate-spin");
+  widget = glade_xml_get_widget (xml, "edit-button");
+  g_signal_connect_swapped (widget, "clicked",
+      G_CALLBACK (ogmrip_options_dialog_edit_profiles_button_clicked), dialog);
 
   dialog->priv->scale_check = glade_xml_get_widget (xml, "scale-check");
-  widget = glade_xml_get_widget (xml,"bpp-hbox");
-  g_signal_connect (dialog->priv->scale_check, "toggled", 
-      G_CALLBACK (ogmrip_options_dialog_check_toggled), widget);
-  widget = glade_xml_get_widget (xml,"scale-vbox");
+  widget = glade_xml_get_widget (xml,"scale-box");
   g_signal_connect (dialog->priv->scale_check, "toggled", 
       G_CALLBACK (ogmrip_options_dialog_check_untoggled), widget);
 
-  dialog->priv->bpp_spin = glade_xml_get_widget (xml, "bpp-spin");
-
   dialog->priv->autoscale_button = glade_xml_get_widget (xml, "autoscale-button");
   g_signal_connect_swapped (dialog->priv->autoscale_button, "clicked", 
       G_CALLBACK (ogmrip_options_dialog_autoscale_clicked), dialog);
@@ -480,11 +731,9 @@ ogmrip_options_dialog_init (OGMRipOptionsDialog *dialog)
   gtk_combo_box_set_model (GTK_COMBO_BOX (dialog->priv->scale_combo), GTK_TREE_MODEL (dialog->priv->scale_store));
 
   dialog->priv->crop_check = glade_xml_get_widget (xml, "crop-check");
-  widget = glade_xml_get_widget (xml,"crop-hbox");
+  widget = glade_xml_get_widget (xml,"crop-box");
   g_signal_connect (dialog->priv->crop_check, "toggled", 
       G_CALLBACK (ogmrip_options_dialog_check_untoggled), widget);
-  g_signal_connect_swapped (dialog->priv->crop_check, "toggled", 
-      G_CALLBACK (ogmrip_options_dialog_bitrate_or_crop_toggled), dialog);
 
   dialog->priv->crop_left_label = glade_xml_get_widget (xml, "crop-left-label");
   dialog->priv->crop_right_label = glade_xml_get_widget (xml, "crop-right-label");
@@ -499,28 +748,17 @@ ogmrip_options_dialog_init (OGMRipOptionsDialog *dialog)
   g_signal_connect_swapped (widget, "clicked", 
       G_CALLBACK (ogmrip_options_dialog_autocrop_clicked), dialog);
 
-  dialog->priv->more_exp = glade_xml_get_widget (xml, "more-expander");
   dialog->priv->ntsc_frame = glade_xml_get_widget (xml, "ntsc-frame");
-
-  dialog->priv->pullup_check = glade_xml_get_widget (xml, "pullup-check");
+  dialog->priv->telecine_check = glade_xml_get_widget (xml, "telecine-check");
   dialog->priv->progressive_check = glade_xml_get_widget (xml, "progressive-check");
-
-  dialog->priv->deint_combo = glade_xml_get_widget (xml, "deint-combo");
-  gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->deint_combo), 0);
-
-  dialog->priv->framestep_combo = glade_xml_get_widget (xml, "framestep-combo");
-  gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->framestep_combo), 0);
-
   dialog->priv->cartoon_check = glade_xml_get_widget (xml, "cartoon-check");
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->cartoon_check), FALSE);
-
-  widget = glade_xml_get_widget (xml, "ccheck-button");
-  g_signal_connect_swapped (widget, "clicked",
-      G_CALLBACK (ogmrip_options_dialog_ccheck_clicked), dialog);
-
-  gtk_widget_hide (widget);
+  dialog->priv->deint_check = glade_xml_get_widget (xml, "deint-check");
 
   g_object_unref (xml);
+
+  ogmrip_options_dialog_profile_notified (NULL, dialog);
+  ogmrip_preferences_add_notify (OGMRIP_GCONF_PROFILE,
+      (GFunc) ogmrip_options_dialog_profile_notified, dialog);
 }
 
 static void
@@ -579,23 +817,16 @@ ogmrip_options_dialog_set_title (OGMRipOptionsDialog *dialog, OGMDvdTitle *title
       ogmdvd_title_unref (dialog->priv->title);
     dialog->priv->title = title;
 
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->bitrate_check), TRUE);
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (dialog->priv->bitrate_spin), 800);
-
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->crop_check), TRUE);
     ogmrip_options_dialog_crop_update (dialog);
 
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->scale_check), TRUE);
-    gtk_spin_button_set_value (GTK_SPIN_BUTTON (dialog->priv->bpp_spin), 0.25);
     ogmrip_options_dialog_scale_update (dialog);
     gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->scale_combo), OGMRIP_SCALE_FULL);
 
-    gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->deint_combo), OGMRIP_DEINT_NONE);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->deint_check), FALSE);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->progressive_check), FALSE);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->pullup_check), FALSE);
-
-    gtk_expander_set_expanded (GTK_EXPANDER (dialog->priv->more_exp), FALSE);
-    gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->framestep_combo), 0);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->telecine_check), FALSE);
 
     if (ogmdvd_title_get_video_format (title) == OGMDVD_VIDEO_FORMAT_NTSC)
       gtk_widget_show (dialog->priv->ntsc_frame);
@@ -604,22 +835,6 @@ ogmrip_options_dialog_set_title (OGMRipOptionsDialog *dialog, OGMDvdTitle *title
   }
 }
 
-gint
-ogmrip_options_dialog_get_bitrate (OGMRipOptionsDialog *dialog, guint *bitrate)
-{
-  gint retval;
-
-  g_return_val_if_fail (OGMRIP_IS_OPTIONS_DIALOG (dialog), -1);
-
-  retval = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->bitrate_check)) ?
-      OGMRIP_OPTIONS_AUTOMATIC : OGMRIP_OPTIONS_MANUAL;
-
-  if (bitrate)
-    *bitrate = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (dialog->priv->bitrate_spin)) * 1000;
-
-  return retval;
-}
-
 gint
 ogmrip_options_dialog_get_scale (OGMRipOptionsDialog *dialog, guint *width, guint *height)
 {
@@ -663,7 +878,10 @@ ogmrip_options_dialog_get_deinterlacer (OGMRipOptionsDialog *dialog)
 {
   g_return_val_if_fail (OGMRIP_IS_OPTIONS_DIALOG (dialog), -1);
 
-  return gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->deint_combo));
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->deint_check)))
+    return OGMRIP_DEINT_YADIF;
+
+  return OGMRIP_DEINT_NONE;
 }
 
 gboolean
@@ -678,16 +896,16 @@ ogmrip_options_dialog_get_progressive (OGMRipOptionsDialog *dialog)
 }
 
 gboolean
-ogmrip_options_dialog_get_pullup (OGMRipOptionsDialog *dialog)
+ogmrip_options_dialog_get_telecine (OGMRipOptionsDialog *dialog)
 {
   g_return_val_if_fail (OGMRIP_IS_OPTIONS_DIALOG (dialog), FALSE);
 
   if (!GTK_WIDGET_VISIBLE (dialog->priv->ntsc_frame))
     return FALSE;
 
-  return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->pullup_check));
+  return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->telecine_check));
 }
-
+/*
 gint
 ogmrip_options_dialog_get_framestep (OGMRipOptionsDialog *dialog)
 {
@@ -707,7 +925,7 @@ ogmrip_options_dialog_get_bits_per_pixel (OGMRipOptionsDialog *dialog)
 
   return gtk_spin_button_get_value (GTK_SPIN_BUTTON (dialog->priv->bpp_spin));
 }
-
+*/
 gboolean
 ogmrip_options_dialog_get_cartoon (OGMRipOptionsDialog *dialog)
 {
