@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,12 +32,6 @@ enum
   OGMRIP_OPTIONS_MANUAL
 };
 
-enum
-{
-  OGMRIP_OPTIONS_EXTRACT = 1,
-  OGMRIP_OPTIONS_CCHECK
-};
-
 #define OGMRIP_TYPE_OPTIONS_DIALOG            (ogmrip_options_dialog_get_type ())
 #define OGMRIP_OPTIONS_DIALOG(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_OPTIONS_DIALOG, OGMRipOptionsDialog))
 #define OGMRIP_OPTIONS_DIALOG_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_OPTIONS_DIALOG, OGMRipOptionsDialogClass))
@@ -58,6 +52,8 @@ struct _OGMRipOptionsDialog
 struct _OGMRipOptionsDialogClass
 {
   GtkDialogClass parent_class;
+
+  void (* edit_clicked) (OGMRipOptionsDialog *dialog);
 };
 
 GType         ogmrip_options_dialog_get_type           (void);
@@ -68,8 +64,6 @@ OGMDvdTitle * ogmrip_options_dialog_get_title          (OGMRipOptionsDialog *dia
 void          ogmrip_options_dialog_set_title          (OGMRipOptionsDialog *dialog,
                                                         OGMDvdTitle         *title);
 
-gint          ogmrip_options_dialog_get_bitrate        (OGMRipOptionsDialog *dialog, 
-                                                        guint               *bitrate);
 gint          ogmrip_options_dialog_get_scale          (OGMRipOptionsDialog *dialog, 
                                                         guint               *width, 
                                                         guint               *height);
@@ -81,10 +75,21 @@ gint          ogmrip_options_dialog_get_crop           (OGMRipOptionsDialog *dia
 gint          ogmrip_options_dialog_get_framestep      (OGMRipOptionsDialog *dialog);
 gint          ogmrip_options_dialog_get_deinterlacer   (OGMRipOptionsDialog *dialog);
 gboolean      ogmrip_options_dialog_get_progressive    (OGMRipOptionsDialog *dialog);
-gboolean      ogmrip_options_dialog_get_pullup         (OGMRipOptionsDialog *dialog);
+gboolean      ogmrip_options_dialog_get_telecine       (OGMRipOptionsDialog *dialog);
 gdouble       ogmrip_options_dialog_get_bits_per_pixel (OGMRipOptionsDialog *dialog);
 gboolean      ogmrip_options_dialog_get_cartoon        (OGMRipOptionsDialog *dialog);
 
+void          ogmrip_options_dialog_clear_profiles     (OGMRipOptionsDialog *dialog);
+void          ogmrip_options_dialog_add_profile        (OGMRipOptionsDialog *dialog,
+                                                        const gchar         *name,
+                                                        const gchar         *key);
+void          ogmrip_options_dialog_remove_profile     (OGMRipOptionsDialog *dialog,
+                                                        const gchar         *name,
+                                                        const gchar         *key);
+void          ogmrip_options_dialog_rename_profile     (OGMRipOptionsDialog *dialog,
+                                                        const gchar         *name,
+                                                        const gchar         *key);
+
 G_END_DECLS
 
 #endif /* __OGMRIP_OPTIONS_H__ */
