@@ -1,5 +1,5 @@
 /* OGMRip - A DVD Encoder for GNOME
- * Copyright (C) 2004-2007 Olivier Rolland <billl@users.sf.net>
+ * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,16 +44,17 @@ struct _OGMRipProgressDialogPriv
   GtkWidget *eta_label;
 
   GtkWidget *stage_progress;
-  GtkWidget *total_progress;
 
   GtkWidget *suspend_button;
   GtkWidget *resume_button;
-
+  GtkWidget *cancel_button;
+  GtkWidget *quit_check;
+/*
   guint stage;
   guint completed;
+*/
   gulong start_time;
   gulong suspend_time;
-  gboolean ccheck;
 
   gchar *title;
   gchar *label;
@@ -175,51 +176,50 @@ ogmrip_progress_dialog_run (OGMRipProgressDialog *dialog)
 static void
 ogmrip_progress_dialog_progress (OGMRipProgressDialog *dialog, gdouble fraction)
 {
-  GTimeVal tv;
-  gulong eta;
-  gchar *str;
-
-  if (!dialog->priv->start_time)
+  if (fraction < 0.0)
+    gtk_progress_bar_pulse (GTK_PROGRESS_BAR (dialog->priv->stage_progress));
+  else
   {
-    g_get_current_time (&tv);
-    dialog->priv->start_time = tv.tv_sec;
-  }
+    GTimeVal tv;
+    gulong eta;
+    gchar *str;
 
-  gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (dialog->priv->stage_progress), fraction);
+    if (!dialog->priv->start_time)
+    {
+      g_get_current_time (&tv);
+      dialog->priv->start_time = tv.tv_sec;
+    }
+
+    gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (dialog->priv->stage_progress), fraction);
 
 #ifdef HAVE_LIBNOTIFY_SUPPORT
-  if (dialog->priv->status_icon)
-  {
-    str = g_strdup_printf (_("%s: %02.0lf%% done"), dialog->priv->label, fraction * 100);
-    gtk_status_icon_set_tooltip (dialog->priv->status_icon, str);
-    g_free (str);
-  }
+    if (dialog->priv->status_icon)
+    {
+      str = g_strdup_printf (_("%s: %02.0lf%% done"), dialog->priv->label, fraction * 100);
+      gtk_status_icon_set_tooltip (dialog->priv->status_icon, str);
+      g_free (str);
+    }
 #endif /* HAVE_LIBNOTIFY_SUPPORT */
 
-  g_get_current_time (&tv);
-  eta = (1.0 - fraction) * (tv.tv_sec - dialog->priv->start_time) / fraction;
+    g_get_current_time (&tv);
+    eta = (1.0 - fraction) * (tv.tv_sec - dialog->priv->start_time) / fraction;
 
-  if (eta >= 3600)
-    str = g_strdup_printf ("%ld hour(s) %ld minute(s)", eta / 3600, (eta % 3600) / 60);
-  else
-    str = g_strdup_printf ("%ld minute(s)", eta / 60);
-
-  gtk_label_set_text (GTK_LABEL (dialog->priv->eta_label), str);
-  g_free (str);
-
-  fraction = (dialog->priv->completed + fraction) / (gdouble) dialog->priv->stage;
-  gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (dialog->priv->total_progress), CLAMP (fraction, 0.0, 1.0));
-
-  if (GTK_WINDOW (dialog)->transient_parent)
-  {
-    gchar *title;
-
-    if (dialog->priv->ccheck)
-      title = g_strdup_printf ("OGMRip: %s: %.0f%%", _("Compressibility Test Progress"), CLAMP (fraction, 0.0, 1.0) * 100);
+    if (eta >= 3600)
+      str = g_strdup_printf ("%ld hour(s) %ld minute(s)", eta / 3600, (eta % 3600) / 60);
     else
-      title = g_strdup_printf ("OGMRip: %s: %.0f%%", _("Encoding Progress"), CLAMP (fraction, 0.0, 1.0) * 100);
-    gtk_window_set_title (GTK_WINDOW (dialog)->transient_parent, title);
-    g_free (title);
+      str = g_strdup_printf ("%ld minute(s)", eta / 60);
+
+    gtk_label_set_text (GTK_LABEL (dialog->priv->eta_label), str);
+    g_free (str);
+
+    if (GTK_WINDOW (dialog)->transient_parent)
+    {
+      gchar *title;
+
+      title = g_strdup_printf ("OGMRip: %s: %.0f%%", dialog->priv->label, CLAMP (fraction, 0.0, 1.0) * 100);
+      gtk_window_set_title (GTK_WINDOW (dialog)->transient_parent, title);
+      g_free (title);
+    }
   }
 }
 
@@ -289,19 +289,20 @@ ogmrip_progress_dialog_init (OGMRipProgressDialog *dialog)
   gtk_size_group_add_widget (group, dialog->priv->suspend_button);
   gtk_widget_show (dialog->priv->suspend_button);
 
-  gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
+  dialog->priv->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 
   gtk_window_set_title (GTK_WINDOW (dialog), _("Progress"));
+  gtk_window_set_default_size (GTK_WINDOW (dialog), 450, -1);
   gtk_window_set_icon_from_stock (GTK_WINDOW (dialog), GTK_STOCK_EXECUTE);
-  gtk_window_set_default_size (GTK_WINDOW (dialog), 400, -1);
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
+  gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
   root = glade_xml_get_widget (xml, OGMRIP_GLADE_ROOT);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), root, TRUE, TRUE, 0);
   gtk_widget_show (root);
-
+/*
   dialog->priv->completed = -1;
-
+*/
 #ifdef HAVE_LIBNOTIFY_SUPPORT
   dialog->priv->status_icon = gtk_status_icon_new_from_file (OGMRIP_DATA_DIR "/" OGMRIP_ICON_FILE);
 
@@ -322,12 +323,10 @@ ogmrip_progress_dialog_init (OGMRipProgressDialog *dialog)
 #endif /* HAVE_LIBNOTIFY_SUPPORT */
 
   dialog->priv->title_label = glade_xml_get_widget (xml, "title-label");
-
   dialog->priv->stage_label = glade_xml_get_widget (xml, "stage-label");
-  dialog->priv->eta_label = glade_xml_get_widget (xml, "eta-label");
-
   dialog->priv->stage_progress = glade_xml_get_widget (xml, "stage-progress");
-  dialog->priv->total_progress = glade_xml_get_widget (xml, "total-progress");
+  dialog->priv->eta_label = glade_xml_get_widget (xml, "eta-label");
+  dialog->priv->quit_check = glade_xml_get_widget (xml, "quit-check");
 
   g_object_unref (xml);
 }
@@ -386,12 +385,8 @@ ogmrip_progress_dialog_response (GtkDialog *dialog, gint response_id)
       case GTK_RESPONSE_NONE:
         break;
       default:
-        if (progress_dialog->priv->ccheck)
-          response_id = ogmrip_message_dialog (GTK_WINDOW (dialog), GTK_MESSAGE_QUESTION,
-              _("Are you sure you want to cancel the compressibility test?"));
-        else
-          response_id = ogmrip_message_dialog (GTK_WINDOW (dialog), GTK_MESSAGE_QUESTION,
-              _("Are you sure you want to cancel the encoding process?"));
+        response_id = ogmrip_message_dialog (GTK_WINDOW (dialog), GTK_MESSAGE_QUESTION,
+            _("Are you sure you want to cancel the encoding process?"));
         if (response_id == GTK_RESPONSE_YES)
           ogmjob_spawn_cancel (progress_dialog->priv->spawn);
         break;
@@ -400,16 +395,19 @@ ogmrip_progress_dialog_response (GtkDialog *dialog, gint response_id)
 }
 
 GtkWidget *
-ogmrip_progress_dialog_new (const gchar *title, gboolean ccheck, guint stage)
+ogmrip_progress_dialog_new (const gchar *title, guint stage)
 {
   OGMRipProgressDialog *dialog;
+  gchar *str;
 
   dialog = g_object_new (OGMRIP_TYPE_PROGRESS_DIALOG, NULL);
   dialog->priv->title = g_strdup (title);
-  dialog->priv->ccheck = ccheck;
+/*
   dialog->priv->stage = stage;
-
-  gtk_label_set_text (GTK_LABEL (dialog->priv->title_label), title);
+*/
+  str = g_strdup_printf ("<big><b>%s</b></big>", title);
+  gtk_label_set_markup (GTK_LABEL (dialog->priv->title_label), str);
+  g_free (str);
 
 #ifdef HAVE_LIBNOTIFY_SUPPORT
   notify_notification_update (dialog->priv->notification, title, "Dummy",
@@ -425,8 +423,9 @@ ogmrip_progress_dialog_set_spawn (OGMRipProgressDialog *dialog, OGMJobSpawn *spa
   if (dialog)
   {
     dialog->priv->start_time = 0;
+/*
     dialog->priv->completed ++;
-
+*/
     if (spawn != dialog->priv->spawn)
     {
       g_object_ref (spawn);
@@ -448,7 +447,7 @@ ogmrip_progress_dialog_set_spawn (OGMRipProgressDialog *dialog, OGMJobSpawn *spa
         g_free (dialog->priv->label);
       dialog->priv->label = g_strdup (label);
 
-      str = g_strdup_printf ("<b>%s</b>", label);
+      str = g_strdup_printf ("<i>%s</i>", label);
       gtk_label_set_markup (GTK_LABEL (dialog->priv->stage_label), str);
       g_free (str);
 
@@ -465,3 +464,9 @@ ogmrip_progress_dialog_set_spawn (OGMRipProgressDialog *dialog, OGMJobSpawn *spa
   }
 }
 
+gboolean
+ogmrip_progress_dialog_get_quit (OGMRipProgressDialog *dialog)
+{
+  return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->quit_check));
+}
+
